////////////////////////////////////////////////////////////////////////////////////////////////////
// Histograms
////////////////////////////////////////////////////////////////////////////////////////////////////
#include <iostream>
#include <iomanip>
#include <string>
#include <cstdio>
#include <cstdlib>
#include <cmath>
#include <fstream>
#include <sstream>
#include <sys/stat.h>
#include "TChain.h"
#include <TApplication.h>
#include <TCanvas.h>
#include <TMultiGraph.h>
#include <TGraph.h>
#include <TFile.h>
#include <TH1D.h>
#include <TH2D.h>
#include <TLegend.h>
#include <TPaveText.h>
#include <TLorentzVector.h>
#include <TStyle.h>
#include <TTree.h>
#include <TTreeReader.h>
#include <TColor.h>

using namespace std;

void set_style();

int main()
{
// Create output folder
    mkdir("histograms", S_IRWXU | S_IRWXG | S_IROTH | S_IXOTH);
//--------------------------------------------------------------------------------------------------
    set_style();
    TCanvas c("c", "c", 3000, 2000);
    const string htitle("");
    c.SetLeftMargin(0.14);
    c.SetRightMargin(0.1);
    c.SetTopMargin(0.12);
    c.SetBottomMargin(0.15);
//--------------------------------------------------------------------------------------------------
// User defined colors
    TColor kColor0(10000, 0, 0, 0);
    TColor kColor1(10001, 1, 0, 0);
    TColor kColor2(10002, 0, 1, 0);
    TColor kColor3(10003, 0, 0, 1);
//--------------------------------------------------------------------------------------------------
    const int LNAME = 50;
//--------------------------------------------------------------------------------------------------
    TFile *fhardvar = new TFile("hardvar.root");
    TTree *thardvar = (TTree*)fhardvar->Get("events_hardvar");
    Double_t weighthardvar[1], hardvar[5];
    thardvar->SetBranchAddress("weight_hardvar",&weighthardvar);
    thardvar->SetBranchAddress("hardvar",&hardvar);
//--------------------------------------------------------------------------------------------------
    int nentrieshardvar = thardvar->GetEntries();
//--------------------------------------------------------------------------------------------------
    const int    binN[5] = { 100, 100, 100, 100, 100};
    const double binL[5] = {  0.,  0.,  0.,  0.,  0.};
    const double binU[5] = {  1.,  1.,  1.,  1.,  1.};

    char xTitle[5][LNAME];

    char nameRoot1d[5][LNAME];
    char namePdf1d[5][LNAME];

    char nameRoot2d[10][LNAME];
    char namePdf2d[10][LNAME];

    for (int i = 0; i < 5; i++) {
	sprintf(xTitle[i], "X%i", i+1);
	sprintf(nameRoot1d[i], "histograms/X%i.root", i+1);
	sprintf(namePdf1d[i], "histograms/X%i.pdf", i+1);
    }

    int k2d = 0;
    for (int i = 0; i < 4; i++) {
	for (int j = i+1; j < 5; j++) {
	    sprintf(nameRoot2d[k2d], "histograms/X%iX%i.root", i+1, j+1);
	    sprintf(namePdf2d[k2d], "histograms/X%iX%i.pdf", i+1, j+1);
	    k2d++;
	}
    }
//--------------------------------------------------------------------------------------------------
    TH1D *hX1d[5];
    TH2D *hX2d[5][5];

    gStyle->SetHistLineColor(10000);
    gStyle->SetHistFillColor(10000);
    gStyle->SetMarkerColor(10000);
    gStyle->SetHistLineWidth(1);

    for (int i = 0; i < 5; i++) {
	hX1d[i] = new TH1D("","",binN[i],binL[i],binU[i]);
	hX1d[i]->Sumw2();
    }

    for (int i = 0; i < 4; i++) {
	for (int j = i+1; j < 5; j++) {
	    hX2d[i][j] = new TH2D("","",binN[i],binL[i],binU[i],binN[j],binL[j],binU[j]);
	    hX2d[i][j]->Sumw2();
	}
    }
//--------------------------------------------------------------------------------------------------
    for (int i = 0; i < nentrieshardvar; i++) {
	thardvar->GetEntry(i);
	for (int j = 0; j < 5; j++) {
	    hX1d[j]->Fill(hardvar[j],weighthardvar[0]);
	}
	for (int j = 0; j < 4; j++) {
	    for (int k = j+1; k < 5; k++) {
		hX2d[j][k]->Fill(hardvar[j],hardvar[k],weighthardvar[0]);
	    }
	}
    }
//--------------------------------------------------------------------------------------------------
    for (int i = 0; i < 5; i++) {
	c.SetLogx(0);
	c.SetLogy(0);
	hX1d[i]->SetMinimum(0.0);
	hX1d[i]->GetXaxis()->SetTitle(xTitle[i]);
	hX1d[i]->GetYaxis()->SetTitle("N");
	hX1d[i]->DrawCopy("");
	hX1d[i]->DrawCopy("hist same");
	c.Update();
	c.SaveAs(nameRoot1d[i]);
	c.Print(namePdf1d[i]);
	delete hX1d[i];
    }
//--------------------------------------------------------------------------------------------------
    k2d = 0;
    for (int i = 0; i < 4; i++) {
	for (int j = i+1; j < 5; j++) {
	    c.SetLogx(0);
	    c.SetLogy(0);
	    c.SetLogz(0);
	    hX2d[i][j]->SetMinimum(0.0);
	    hX2d[i][j]->GetXaxis()->SetTitle(xTitle[i]);
	    hX2d[i][j]->GetYaxis()->SetTitle(xTitle[j]);
	    hX2d[i][j]->GetZaxis()->SetTitle("N");
	    hX2d[i][j]->DrawCopy("lego2");
	    c.Update();
	    c.SaveAs(nameRoot2d[k2d]);
	    c.Print(namePdf2d[k2d]);
	    delete hX2d[i][j];
	    k2d++;
	}
    }
//--------------------------------------------------------------------------------------------------
    return 0;
}

void set_style()
{
    gStyle->SetCanvasColor(kWhite);
    gStyle->SetHistFillColor(kWhite);
    gStyle->SetHistLineColor(kBlack);
    gStyle->SetHistFillStyle(0);
    gStyle->SetFillStyle(4050);
    gStyle->SetMarkerColor(kBlack);
    gStyle->SetMarkerStyle(1);
    gStyle->SetHistLineStyle(1);
    gStyle->SetHistLineWidth(1);
    gStyle->SetPaperSize(20, 28);
//    gStyle->SetPalette(1);
    gStyle->SetOptStat(0);
    gStyle->SetLabelFont(42,"X");
    gStyle->SetLabelSize(0.06,"X");
    gStyle->SetLabelOffset(0.006,"X");
    gStyle->SetTitleFont(42,"X");
    gStyle->SetTitleSize(0.06,"X");
    gStyle->SetTitleOffset(1.1,"X");
    gStyle->SetTitleColor(kBlack,"X");
    gStyle->SetLabelFont(42,"Y");
    gStyle->SetLabelSize(0.06,"Y");
    gStyle->SetLabelOffset(0.006,"Y");
    gStyle->SetTitleFont(42,"Y");
    gStyle->SetTitleSize(0.06,"Y");
    gStyle->SetTitleOffset(1.1,"Y");
    gStyle->SetTitleColor(kBlack,"Y");
    gStyle->SetTextFont(42);
}
