#ifndef INFO_H
#define INFO_H
#include "General.h"

namespace SANC {

class Settings;

class Info {
public:
  Info(Settings &_cfg);
  std::string version();
  void init();
  /*
      Process ID:
      101: e+e- -> e-e+
      102: e+e- -> ZH
      103: e+e- -> mu-mu+
      104: e+e- -> tau-tau+
      201: p p --> e^-   e^+        X
      202: p p --> mu^-  mu^+       X
      203: p p --> tau^- tau^+      X
      211: p p --> e^-   nu_e_bar   X
      212: p p --> mu^-  nu_mu_bar  X
      213: p p --> tau^- nu_tau_bar X
      221: p p --> e^+   nu_e       X
      222: p p --> mu^+  nu_mu      X
      223: p p --> tau^+ nu_tau     X
  */
  const int Pid;
  //--------------------------------------------------------------------------------------------------
  const double LamMinus; // Longitudinal polarization of electron beam
  const double LamPlus;  // Longitudinal polarization of positron beam
  //--------------------------------------------------------------------------------------------------
  const int Scheme; // Scheme: 0 - alpha(0), 1 - Gmu, 2 - alpha(M_Z)
  double Ecm;       // Total energy of colliding particles in CM frame
  double EA;        // Energy of beam A, moving in the +z direction
  double EB;        // Energy of beam B, moving in the -z direction
  const double Ome;
  const double DeltaLL;
  const double ScaleLL;
  const double Alphai;
  const double AlphaMZi;
  const double Alphas;
  const double GF;
  const double Conhc;
  //--------------------------------------------------------------------------------------------------
  const std::string PDFname;
  const int PDFmember;
  //--------------------------------------------------------------------------------------------------
  const int Alr;
  //--------------------------------------------------------------------------------------------------
  const int Iborn;
  const int IgmZ;
  const int Iqed;
  const int Iqedlli;
  const int Iqedllf;
  const int Iew;
  const int Iqcd;
  const int Ifs;
  const int Iho;
  const int Ilin;
  const int Ifgg;
  const int Its;
  const int Irun;
  const int Imsb;
  const int Iph;
  const int Iyfs;
  //--------------------------------------------------------------------------------------------------
  const int Ibeams;
  const int Iafb;
  const int Iach;
  const int Icuts;
  const int Iscale;
  //--------------------------------------------------------------------------------------------------
  const bool ForceOffH;
  const bool ForceOffSV;
  //--------------------------------------------------------------------------------------------------
  const double Men;
  const double Mel;
  const double Mup;
  const double Mdn;
  const double Mmn;
  const double Mmo;
  const double Mch;
  const double Mst;
  const double Mtn;
  const double Mta;
  const double Mtp;
  const double Mbt;
  const double MW;
  const double MZ;
  const double MH;
  const double Wz;
  const double Ww;
  const double Wh;
  const double Wtp;
  const double Vud;
  const double Vus;
  const double Vcd;
  const double Vcs;
  const double Vcb;
  const double Vub;
  //--------------------------------------------------------------------------------------------------
  const double CutMinCth;
  const double CutMaxCth;
  const double CutMinTheta;
  const double CutMaxTheta;
  // double CutMinM34;
  // double CutMaxM34;
  // double CutMinPt;
  // double CutMaxPt;
  double CutMaxPhotonE;
  const bool eta3cut;
  const double eta3min;
  const double eta3max;
  const bool eta4cut;
  const double eta4min;
  const double eta4max;
  const bool pt3cut;
  const double pt3min;
  const double pt3max;
  const bool pt4cut;
  const double pt4min;
  const double pt4max;
  const bool m34cut;
  const double m34min;
  const double m34max;
  const bool mt34cut;
  const double mt34min;
  const double mt34max;
  const bool y34cut;
  const double y34min;
  const double y34max;
  const double xmin;
  const double xmax;
  //--------------------------------------------------------------------------
  const long RanSeed; // Seed for RNG initialization (0 <= RanSeed <= 9E8)
  const long NevBorn; // MC statistics for Born
  const long NevVirt; // MC statistics for Virt
  const long NevHard; // MC statistics for Hard
  const long NevLL11; // MC statistics for LL11
  const long NevLL22; // MC statistics for LL22
  const long NevLL12; // MC statistics for LL12
  const long NevTot;  // MC statistics for Total
  const long NevBrdq; // MC statistics for Brdq
  const long NevIbaa; // MC statistics for Ibaa
  const long NevIbaq; // MC statistics for Ibaq
  const long NevIbs1; // MC statistics for Ibs1
  const long NevIbs2; // MC statistics for Ibs2
  //--------------------------------------------------------------------------------------------------
  //  FOAM parameters for Born
  const int kDimBorn;
  const int nCellsBorn;
  const int nSamplBorn;
  const int nBinBorn;
  const int EvPerBinBorn;
  const double MaxWtRejBorn;
  //--------------------------------------------------------------------------------------------------
  //  FOAM parameters for Virt
  const int kDimVirt;
  const int nCellsVirt;
  const int nSamplVirt;
  const int nBinVirt;
  const int EvPerBinVirt;
  const double MaxWtRejVirt;
  //--------------------------------------------------------------------------------------------------
  //  FOAM parameters for Hard
  const int kDimHard;
  const int nCellsHard;      // Number of Cells
  const int nSamplHard;      // Number of MC events per cell in build-up
  const int nBinHard;        // Number of bins in build-up
  const int EvPerBinHard;    // Maximum events (equiv.) per bin in buid-up
  const double MaxWtRejHard; // Maximum wt for rejection, for OptRej=1
  //--------------------------------------------------------------------------------------------------
  //  FOAM parameters for LL11
  const int nCellsLL11;
  const int nSamplLL11;
  const int nBinLL11;
  const int EvPerBinLL11;
  const double MaxWtRejLL11;
  //--------------------------------------------------------------------------------------------------
  //  FOAM parameters for LL22
  const int nCellsLL22;
  const int nSamplLL22;
  const int nBinLL22;
  const int EvPerBinLL22;
  const double MaxWtRejLL22;
  //--------------------------------------------------------------------------------------------------
  //  FOAM parameters for LL12
  const int nCellsLL12;
  const int nSamplLL12;
  const int nBinLL12;
  const int EvPerBinLL12;
  const double MaxWtRejLL12;
  //--------------------------------------------------------------------------------------------------
  //  FOAM parameters for Brdq
  const int kDimBrdq;
  const int nCellsBrdq;
  const int nSamplBrdq;
  const int nBinBrdq;
  const int EvPerBinBrdq;
  const double MaxWtRejBrdq;
  //--------------------------------------------------------------------------------------------------
  //  FOAM parameters for Ibaa
  const int kDimIbaa;
  const int nCellsIbaa;
  const int nSamplIbaa;
  const int nBinIbaa;
  const int EvPerBinIbaa;
  const double MaxWtRejIbaa;
  //--------------------------------------------------------------------------------------------------
  //  FOAM parameters for Ibaq
  const int kDimIbaq;
  const int nCellsIbaq;
  const int nSamplIbaq;
  const int nBinIbaq;
  const int EvPerBinIbaq;
  const double MaxWtRejIbaq;
  //--------------------------------------------------------------------------------------------------
  //  FOAM parameters for Ibs1
  const int kDimIbs1;
  const int nCellsIbs1;
  const int nSamplIbs1;
  const int nBinIbs1;
  const int EvPerBinIbs1;
  const double MaxWtRejIbs1;
  //--------------------------------------------------------------------------------------------------
  //  FOAM parameters for Ibs2
  const int kDimIbs2;
  const int nCellsIbs2;
  const int nSamplIbs2;
  const int nBinIbs2;
  const int EvPerBinIbs2;
  const double MaxWtRejIbs2;
  //--------------------------------------------------------------------------------------------------
  //  General FOAM parameters
  const int OptRej;   // =0, weighted events;  =1, wt=1 events
  const int OptDrive; // (D=2) Option, type of Drive =0,1,2 for TrueVol,Sigma,WtMax
  const int Chat;     // Chat level
  //--------------------------------------------------------------------------------------------------
  //  Parameters for branching
  double SigmaBorn;
  double SigmaVirt;
  double SigmaHard;
  double SigmaLLI11;
  double SigmaLLI22;
  double SigmaLLI12;
  double SigmaLLF11;
  double SigmaLLF22;
  double SigmaLLF12;
  double SigmaBrdq;
  double SigmaIbaa;
  double SigmaIbaq;
  double SigmaIbs1;
  double SigmaIbs2;
  double SigmaTot;
  double Sigma;
  double SigmaErr;
  //--------------------------------------------------------------------------------------------------
  const bool IEXPLBORN;
  const bool IEXPLVIRT;
  const bool IEXPLHARD;
  const bool IEXPLLLI11;
  const bool IEXPLLLI22;
  const bool IEXPLLLI12;
  const bool IEXPLLLF11;
  const bool IEXPLLLF22;
  const bool IEXPLLLF12;
  const bool IEXPLBRDQ;
  const bool IEXPLIBAA;
  const bool IEXPLIBAQ;
  const bool IEXPLIBS1;
  const bool IEXPLIBS2;
  //--------------------------------------------------------------------------------------------------
  const bool PrintLHE;
  const bool PrintROOT;
  const bool PrintHard;
  const bool PrintDEBUG;
  //--------------------------------------------------------------------------------------------------
  const int verMajor, verMinor, verPatch;
  std::string outputDir;

private:
  Settings &cfg;
};

} // namespace SANC
#endif // INFO_H
