#ifndef INTEGRAND_H
#define INTEGRAND_H

#include "TFoamIntegrand.h"

namespace SANC {

class Info;
class LHEF;
class Process;
class Vec4;
class PDF;

class Integrand : public TFoamIntegrand {
public:
  Integrand(SANC::Info &_info, SANC::Process &_proc, int t = 0);
  ~Integrand(void) {}
  double Density(int ndim, double *Xarg);
  double Born(int ndim, double *Xarg);
  double Virt(int ndim, double *Xarg);
  double Hard(int ndim, double *Xarg);
  double Loop(int ndim, double *Xarg);
  double LLI11(int ndim, double *Xarg);
  double LLI22(int ndim, double *Xarg);
  double LLI12(int ndim, double *Xarg);
  double LLF11(int ndim, double *Xarg);
  double LLF22(int ndim, double *Xarg);
  double LLF12(int ndim, double *Xarg);

private:
  SANC::Info &info;
  SANC::Process &proc;
  int m_Type; // Type of function
  double Mf1, Mf2, Mf3, Mf4, Mf1_2, Mf2_2, Mf3_2, Mf4_2;
  double sm, dm;
  Vec4 *P_com[6], *P_lab[6];
  ////////////////////////////////////////////////////////////////////////////
};

class Integrand_pp : public TFoamIntegrand {
public:
  Integrand_pp(SANC::Info &_info, SANC::Process &_proc, PDF *_pdf, int t = 0);
  ~Integrand_pp(void) {}
  double Density(int ndim, double *Xarg);
  double BornH(int ndim, double *Xarg);
  double VirtH(int ndim, double *Xarg);
  double HardH(int ndim, double *Xarg);
  double BrdqH(int ndim, double *Xarg);
  double IbaaH(int ndim, double *Xarg);
  double IbaqH(int ndim, double *Xarg);
  double Ibs1H(int ndim, double *Xarg);
  double Ibs2H(int ndim, double *Xarg);

private:
  SANC::Info &info;
  SANC::Process &proc;
  PDF *pdf;
  int m_Type; // Type of function
  double Mf1, Mf2, Mf3, Mf4, Mf1_2, Mf2_2, Mf3_2, Mf4_2;
  double sm, dm;
  Vec4 *P_com[6], *P_lab[6];
  ////////////////////////////////////////////////////////////////////////////
};

} // namespace SANC
#endif
