************************************************************************
* sanc_nc_v1.30 package.
************************************************************************
* File (nc_ha_1_14__14_20_20.f) is created on Fri Aug 16 13:11:20 CEST 2013.
************************************************************************
* This is the FORTRAN module (nc_ha_1_14__14_20_20) to calculate differential
* hard photon Bremsstrahlung for the a + dn -> dn + ta^+ + ta^- process.
*
* It is produced by s2n package of SANC (v1.10) Project.
* Copyright (C), SANC Project Team, 2002-2013.
*
* http://sanc.jinr.ru/
* http://pcphsanc.cern.ch/
* E-mail: <sanc@jinr.ru>
************************************************************************
      subroutine nc_ha_1_14__14_20_20 (s,spr,ph3,costh3,costh5,hard)
        implicit none!
        include 's2n_declare.h'

        real*8 kappaz,sq,sqspr,ps
        real*8 a1z,a2z,v1z,v2z,vaz
        real*8 p1p2,p1p3,p1p4,p1p5,p2p3,p2p4,p2p5,p3p4,p3p5,p4p5
        real*8 ph3,cosph3,sinph3,costh3,costh5,sinth3,sinth5
        real*8 sqrtlssprdn,isqrtlssprdn
        complex*16 chizs,chizsc,chizspr,chizsprc,chizps,chizpsc
        real*8 betasprtata,ibetasprtata
        real*8 iz1dn,iz2dn,iz3ta,iz4ta
        real*8 v0ps,v0spr,v0sprps,a0ps,a0spr,a0sprps,vaps,vaspr,vasprps,a
     &   1sprps

        cmz2 = mz2

        sq = dsqrt(s)
        sqspr = dsqrt(spr)

        cosph3 = dcos(ph3)
        sinph3 = dsin(ph3)
        sinth3 = dsqrt(1d0-costh3**2)
        sinth5 = dsqrt(1d0-costh5**2)

        kappaz   = gf*rzm2/(dsqrt(2d0)*8d0*pi)/alpha
        if (irun.eq.0) then
          chizs = 4d0*kappaz*s/(s-cmz2)
          chizspr = 4d0*kappaz*spr/(spr-cmz2)
        else
          chizs = 4d0*kappaz*s/(s-dcmplx(mz**2,-s*wz/mz))
          chizspr = 4d0*kappaz*spr/(spr-dcmplx(mz**2,-spr*wz/mz))
        endif

        sqrtlssprdn = sqrt(s**2-2d0*s*(spr+rdnm2)+(spr-rdnm2)**2)
        isqrtlssprdn = 1d0/sqrtlssprdn
        ps=(s+mdn**2)*(s-spr+mdn**2)/2/s-2*mdn**2+(s-mdn**2)*sqrtlssprdn*costh5/2/s

        chizps   = 4d0*kappaz*ps/(ps+mz**2)
        chizsc   = dconjg(chizs)
        chizsprc = dconjg(chizspr)
        chizpsc  = dconjg(chizps)

        a1z = adn*ata
        a2z = 4d0*vdn*adn*vta*ata
        v1z = vdn*vta
        v2z = (vdn**2+adn**2)*(vta**2+ata**2)
        vaz = (vdn**2+adn**2)*(vta**2-ata**2)

        betasprtata = sqrt(1d0-4d0*rtam2/spr)
        ibetasprtata = 1d0/betasprtata

        v0ps =
     &   +qdn**2*qta**2
     &   +qdn*qta*(chizps+chizpsc)*v1z
     &   +chizps*chizpsc*v2z

        v0spr =
     &   +qdn**2*qta**2
     &   +qdn*qta*(chizspr+chizsprc)*v1z
     &   +chizspr*chizsprc*v2z

        v0sprps =
     &   +qdn**2*qta**2
     &   +qdn*qta*(chizspr+chizsprc)*v1z
     &   +chizps*chizpsc*v2z

        a0ps =
     &   +qdn*qta*(chizps+chizpsc)*a1z
     &   +chizps*chizpsc*a2z

        a0spr =
     &   +qdn*qta*(chizspr+chizsprc)*a1z
     &   +chizspr*chizsprc*a2z

        a0sprps =
     &   +qdn*qta*(chizspr+chizsprc)*a1z
     &   +chizps*chizpsc*a2z

        vaps =
     &   +qdn**2*qta**2
     &   +qdn*qta*(chizps+chizpsc)*v1z
     &   +chizps*chizpsc*vaz

        vaspr =
     &   +qdn**2*qta**2
     &   +qdn*qta*(chizspr+chizsprc)*v1z
     &   +chizspr*chizsprc*vaz

        vasprps =
     &   +2d0*qdn**2*qta**2
     &   +qdn*qta*(chizspr+chizsprc+chizps+chizpsc)*v1z
     &   +(chizspr*chizpsc+chizsprc*chizps)*vaz

        a1sprps =
     &   -(chizspr+chizsprc-chizps-chizpsc)*a1z

        p1p2=
     &   +sqrtlssprdn*costh5*(-1d0/4+1d0/4*mdn**2/s)
     &   +1d0/4*spr-1d0/4*s+1d0/4*mdn**2/s*spr-1d0/2*mdn**2-1d0/4*mdn**4/s

        p1p3=
     &   +sqrtlssprdn**2*(-1d0/8/s)
     &   +sqrtlssprdn*betasprtata*costh3*(1d0/4)
     &   +1d0/8/s*spr**2-1d0/8*s-1d0/4*mdn**2/s*spr+1d0/8*mdn**4/s

        p1p4=
     &   +sqrtlssprdn**2*(-1d0/8/s)
     &   +sqrtlssprdn*betasprtata*costh3*(-1d0/4)
     &   +1d0/8/s*spr**2-1d0/8*s-1d0/4*mdn**2/s*spr+1d0/8*mdn**4/s

        p1p5=
     &   +sqrtlssprdn*costh5*(1d0/4-1d0/4*mdn**2/s)
     &   +1d0/4*spr-1d0/4*s-1d0/4*mdn**2/s*spr+1d0/4*mdn**4/s

        p2p3=
     &   +sqrtlssprdn*betasprtata*costh3*(1d0/8+1d0/8*mdn**2/s)
     &   +sqrtlssprdn*costh5*(1d0/8-1d0/8*mdn**2/s)
     &   +betasprtata*sinph3*sinth3*sinth5*(-1d0/4*sq*sqspr+1d0/4*sq*sqspr
     &   *mdn**2/s)
     &   +betasprtata*costh3*costh5*(-1d0/8*spr-1d0/8*s+1d0/8*mdn**2/s*spr
     &   +1d0/4*mdn**2-1d0/8*mdn**4/s)
     &   -1d0/8*spr-1d0/8*s-1d0/8*mdn**2/s*spr+1d0/8*mdn**4/s

        p2p4=
     &   +sqrtlssprdn*betasprtata*costh3*(-1d0/8-1d0/8*mdn**2/s)
     &   +sqrtlssprdn*costh5*(1d0/8-1d0/8*mdn**2/s)
     &   +betasprtata*sinph3*sinth3*sinth5*(1d0/4*sq*sqspr-1d0/4*sq*sqspr*
     &   mdn**2/s)
     &   +betasprtata*costh3*costh5*(1d0/8*spr+1d0/8*s-1d0/8*mdn**2/s*spr-
     &   1d0/4*mdn**2+1d0/8*mdn**4/s)
     &   -1d0/8*spr-1d0/8*s-1d0/8*mdn**2/s*spr+1d0/8*mdn**4/s

        p2p5=
     &   -1d0/2*s+1d0/2*mdn**2

        p3p4=
     &   -1d0/2*spr+mta**2

        p3p5=
     &   +sqrtlssprdn*betasprtata*costh3*(1d0/8-1d0/8*mdn**2/s)
     &   +sqrtlssprdn*costh5*(-1d0/8+1d0/8*mdn**2/s)
     &   +betasprtata*sinph3*sinth3*sinth5*(1d0/4*sq*sqspr-1d0/4*sq*sqspr*
     &   mdn**2/s)
     &   +betasprtata*costh3*costh5*(1d0/8*spr+1d0/8*s-1d0/8*mdn**2/s*spr-
     &   1d0/4*mdn**2+1d0/8*mdn**4/s)
     &   -1d0/8*spr-1d0/8*s+1d0/8*mdn**2/s*spr+1d0/4*mdn**2-1d0/8*mdn**4/s

        p4p5=
     &   +sqrtlssprdn*betasprtata*costh3*(-1d0/8+1d0/8*mdn**2/s)
     &   +sqrtlssprdn*costh5*(-1d0/8+1d0/8*mdn**2/s)
     &   +betasprtata*sinph3*sinth3*sinth5*(-1d0/4*sq*sqspr+1d0/4*sq*sqspr
     &   *mdn**2/s)
     &   +betasprtata*costh3*costh5*(-1d0/8*spr-1d0/8*s+1d0/8*mdn**2/s*spr
     &   +1d0/4*mdn**2-1d0/8*mdn**4/s)
     &   -1d0/8*spr-1d0/8*s+1d0/8*mdn**2/s*spr+1d0/4*mdn**2-1d0/8*mdn**4/s

        iz1dn=
     &   +1d0/(mdn**2/s+1d0/4*sqrtlssprdn**2*sinth5**2/s**2)/(s-mdn**2)*(1
     &   -1d0/2/s*spr+1d0/2*sqrtlssprdn*costh5/s)
     &   +1d0/(mdn**2/s+1d0/4*sqrtlssprdn**2*sinth5**2/s**2)*(-1d0/2/s)

        iz2dn=
     &   +1d0/(s-mdn**2)*(1)

        iz3ta=
     &   +1d0/(1d0/4*spr+1d0/4*s-1d0/4*mdn**2/s*spr-1d0/2*mdn**2+1d0/4*mdn
     &   **4/s-1d0/4*sqrtlssprdn*betasprtata*costh3+1d0/4*sqrtlssprdn*beta
     &   sprtata*costh3*mdn**2/s+1d0/4*sqrtlssprdn*costh5-1d0/4*sqrtlssprd
     &   n*costh5*mdn**2/s-1d0/2*betasprtata*sinph3*sinth3*sinth5*sq*sqspr
     &   +1d0/2*betasprtata*sinph3*sinth3*sinth5*sq*sqspr*mdn**2/s-1d0/4*b
     &   etasprtata*costh3*costh5*spr-1d0/4*betasprtata*costh3*costh5*s+1d
     &   0/4*betasprtata*costh3*costh5*mdn**2/s*spr+1d0/2*betasprtata*cost
     &   h3*costh5*mdn**2-1d0/4*betasprtata*costh3*costh5*mdn**4/s)*(1)

        iz4ta=
     &   +1d0/(1d0/4*spr+1d0/4*s-1d0/4*mdn**2/s*spr-1d0/2*mdn**2+1d0/4*mdn
     &   **4/s+1d0/4*sqrtlssprdn*betasprtata*costh3-1d0/4*sqrtlssprdn*beta
     &   sprtata*costh3*mdn**2/s+1d0/4*sqrtlssprdn*costh5-1d0/4*sqrtlssprd
     &   n*costh5*mdn**2/s+1d0/2*betasprtata*sinph3*sinth3*sinth5*sq*sqspr
     &   -1d0/2*betasprtata*sinph3*sinth3*sinth5*sq*sqspr*mdn**2/s+1d0/4*b
     &   etasprtata*costh3*costh5*spr+1d0/4*betasprtata*costh3*costh5*s-1d
     &   0/4*betasprtata*costh3*costh5*mdn**2/s*spr-1d0/2*betasprtata*cost
     &   h3*costh5*mdn**2+1d0/4*betasprtata*costh3*costh5*mdn**4/s)*(1)

        hard=
     &   +v0ps*iz3ta**2*betasprtata/ps**2/(s-mdn**2)/pi*alpha**3/s*(s-spr)
     &   *(-p1p3*p2p4*qta**2*mta**2-p1p4*p2p3*qta**2*mta**2+p1p4*p2p5*qta*
     &   *2*mta**2+p1p5*p2p4*qta**2*mta**2-p3p4*qta**2*mdn**2*mta**2+p4p5*
     &   qta**2*mdn**2*mta**2)
     &   +v0ps*iz3ta*iz4ta*betasprtata/ps**2/(s-mdn**2)/pi*alpha**3/s*(s-s
     &   pr)*(-2*p1p3*p2p4*p3p4*qta**2+p1p3*p2p5*p3p4*qta**2-2*p1p4*p2p3*p
     &   3p4*qta**2+p1p4*p2p5*p3p4*qta**2+p1p5*p2p3*p3p4*qta**2+p1p5*p2p4*
     &   p3p4*qta**2-2*p3p4**2*qta**2*mdn**2)
     &   +v0ps*iz3ta*betasprtata/ps**2/(s-mdn**2)/pi*alpha**3/s*(s-spr)*(-
     &   1d0/2*qta**2*mdn**2*mta**2+p1p3*p2p3*qta**2-1d0/2*p1p3*p2p4*qta**
     &   2-1d0/2*p1p4*p2p3*qta**2+1d0/2*p1p4*p2p5*qta**2+1d0/2*p1p5*p2p4*q
     &   ta**2-p3p4*qta**2*mdn**2+1d0/2*p4p5*qta**2*mdn**2)
     &   +v0ps*iz4ta**2*betasprtata/ps**2/(s-mdn**2)/pi*alpha**3/s*(s-spr)
     &   *(-p1p3*p2p4*qta**2*mta**2+p1p3*p2p5*qta**2*mta**2-p1p4*p2p3*qta*
     &   *2*mta**2+p1p5*p2p3*qta**2*mta**2-p3p4*qta**2*mdn**2*mta**2+p3p5*
     &   qta**2*mdn**2*mta**2)
     &   +v0ps*iz4ta*betasprtata/ps**2/(s-mdn**2)/pi*alpha**3/s*(s-spr)*(-
     &   1d0/2*qta**2*mdn**2*mta**2-1d0/2*p1p3*p2p4*qta**2+1d0/2*p1p3*p2p5
     &   *qta**2-1d0/2*p1p4*p2p3*qta**2+p1p4*p2p4*qta**2+1d0/2*p1p5*p2p3*q
     &   ta**2-p3p4*qta**2*mdn**2+1d0/2*p3p5*qta**2*mdn**2)
     &   +v0spr*iz1dn**2*betasprtata/(s-mdn**2)/pi*alpha**3*qdn**2/s/spr**
     &   2*(s-spr)*(-p1p3*p2p4*mdn**2-p1p4*p2p3*mdn**2+p2p3*p4p5*mdn**2+p2
     &   p4*p3p5*mdn**2-p3p4*mdn**4)
     &   +v0spr*iz1dn*iz2dn*betasprtata/(s-mdn**2)/pi*alpha**3*qdn**2/s/sp
     &   r**2*(s-spr)*(-2*p1p2*p1p3*p2p4-p1p2*p1p3*p4p5-2*p1p2*p1p4*p2p3-p
     &   1p2*p1p4*p3p5+p1p2*p2p3*p4p5+p1p2*p2p4*p3p5-2*p1p2*p3p4*mdn**2-2*
     &   p3p5*p4p5*mdn**2)
     &   +v0spr*iz1dn*betasprtata/(s-mdn**2)/pi*alpha**3*qdn**2/s/spr**2*(
     &   s-spr)*(-p1p3*p1p4-1d0/2*p1p3*p2p4-1d0/2*p1p4*p2p3+1d0/2*p2p3*p4p
     &   5+1d0/2*p2p4*p3p5)
     &   +v0spr*iz2dn**2*betasprtata/(s-mdn**2)/pi*alpha**3*qdn**2/s/spr**
     &   2*(s-spr)*(-p1p3*p2p4*mdn**2-p1p3*p4p5*mdn**2-p1p4*p2p3*mdn**2-p1
     &   p4*p3p5*mdn**2-p3p4*mdn**4)
     &   +v0spr*iz2dn*betasprtata/(s-mdn**2)/pi*alpha**3*qdn**2/s/spr**2*(
     &   s-spr)*(1d0/2*p1p3*p2p4+1d0/2*p1p3*p4p5+1d0/2*p1p4*p2p3+1d0/2*p1p
     &   4*p3p5+p2p3*p2p4)
     &   +v0sprps*iz1dn*iz3ta*betasprtata/ps/(s-mdn**2)/pi*alpha**3*qdn/s/
     &   spr*(s-spr)*(-p1p3*p1p4*p2p3*qta+1d0/2*p1p3*p1p4*p2p5*qta+1d0/2*p
     &   1p3*p2p3*p4p5*qta-p1p3*p3p4*qta*mdn**2+1d0/2*p1p3*p4p5*qta*mdn**2
     &   -p1p3**2*p2p4*qta)
     &   +v0sprps*iz1dn*iz4ta*betasprtata/ps/(s-mdn**2)/pi*alpha**3*qdn/s/
     &   spr*(s-spr)*(p1p3*p1p4*p2p4*qta-1d0/2*p1p3*p1p4*p2p5*qta-1d0/2*p1
     &   p4*p2p4*p3p5*qta+p1p4*p3p4*qta*mdn**2-1d0/2*p1p4*p3p5*qta*mdn**2+
     &   p1p4**2*p2p3*qta)
     &   +v0sprps*iz1dn*betasprtata/ps/(s-mdn**2)/pi*alpha**3*qdn/s/spr*(s
     &   -spr)*(-1d0/4*p1p2*p1p3*qta+1d0/4*p1p2*p1p4*qta-1d0/4*p1p3*p2p4*q
     &   ta-1d0/4*p1p3*qta*mdn**2+1d0/4*p1p4*p2p3*qta+1d0/4*p1p4*qta*mdn**
     &   2+1d0/4*p2p3*qta*mdn**2-1d0/4*p2p4*qta*mdn**2-1d0/4*p3p5*qta*mdn*
     &   *2+1d0/4*p4p5*qta*mdn**2)
     &   +v0sprps*iz2dn*iz3ta*betasprtata/ps/(s-mdn**2)/pi*alpha**3*qdn/s/
     &   spr*(s-spr)*(p1p3*p2p3*p2p4*qta+1d0/2*p1p3*p2p3*p4p5*qta+p1p4*p2p
     &   3**2*qta-1d0/2*p1p5*p2p3*p2p4*qta+p2p3*p3p4*qta*mdn**2-1d0/2*p2p3
     &   *p4p5*qta*mdn**2)
     &   +v0sprps*iz2dn*iz4ta*betasprtata/ps/(s-mdn**2)/pi*alpha**3*qdn/s/
     &   spr*(s-spr)*(-p1p3*p2p4**2*qta-p1p4*p2p3*p2p4*qta-1d0/2*p1p4*p2p4
     &   *p3p5*qta+1d0/2*p1p5*p2p3*p2p4*qta-p2p4*p3p4*qta*mdn**2+1d0/2*p2p
     &   4*p3p5*qta*mdn**2)
     &   +v0sprps*iz2dn*betasprtata/ps/(s-mdn**2)/pi*alpha**3*qdn/s/spr*(s
     &   -spr)*(1d0/4*p1p2*p2p3*qta-1d0/4*p1p2*p2p4*qta+1d0/4*p1p3*p2p4*qt
     &   a-1d0/4*p1p3*qta*mdn**2-1d0/4*p1p4*p2p3*qta+1d0/4*p1p4*qta*mdn**2
     &   +1d0/4*p2p3*qta*mdn**2-1d0/4*p2p4*qta*mdn**2-1d0/4*p3p5*qta*mdn**
     &   2+1d0/4*p4p5*qta*mdn**2)
     &   +v0sprps*iz3ta*betasprtata/ps/(s-mdn**2)/pi*alpha**3*qdn/s/spr*(s
     &   -spr)*(-1d0/4*p1p3*p2p4*qta+1d0/4*p1p3*p3p4*qta+1d0/4*p1p4*p2p3*q
     &   ta-1d0/4*p1p4*qta*mta**2+1d0/4*p2p3*p3p4*qta-1d0/4*p2p4*qta*mta**
     &   2)
     &   +v0sprps*iz4ta*betasprtata/ps/(s-mdn**2)/pi*alpha**3*qdn/s/spr*(s
     &   -spr)*(-1d0/4*p1p3*p2p4*qta+1d0/4*p1p3*qta*mta**2+1d0/4*p1p4*p2p3
     &   *qta-1d0/4*p1p4*p3p4*qta+1d0/4*p2p3*qta*mta**2-1d0/4*p2p4*p3p4*qt
     &   a)
     &   +v0sprps*betasprtata/ps/(s-mdn**2)/pi*alpha**3*qdn/s/spr*(s-spr)*
     &   (1d0/4*p1p3*qta-1d0/4*p1p4*qta+1d0/4*p2p3*qta-1d0/4*p2p4*qta)
     &   +a0ps*iz3ta**2*betasprtata/ps**2/(s-mdn**2)/pi*alpha**3/s*(s-spr)
     &   *(-p1p3*p2p4*qta**2*mta**2+p1p4*p2p3*qta**2*mta**2-p1p4*p2p5*qta*
     &   *2*mta**2+p1p5*p2p4*qta**2*mta**2)
     &   +a0ps*iz3ta*iz4ta*betasprtata/ps**2/(s-mdn**2)/pi*alpha**3/s*(s-s
     &   pr)*(-2*p1p3*p2p4*p3p4*qta**2+p1p3*p2p5*p3p4*qta**2+2*p1p4*p2p3*p
     &   3p4*qta**2-p1p4*p2p5*p3p4*qta**2-p1p5*p2p3*p3p4*qta**2+p1p5*p2p4*
     &   p3p4*qta**2)
     &   +a0ps*iz3ta*betasprtata/ps**2/(s-mdn**2)/pi*alpha**3/s*(s-spr)*(-
     &   1d0/2*p1p3*p2p4*qta**2+1d0/2*p1p4*p2p3*qta**2-1d0/2*p1p4*p2p5*qta
     &   **2+1d0/2*p1p5*p2p4*qta**2)
     &   +a0ps*iz4ta**2*betasprtata/ps**2/(s-mdn**2)/pi*alpha**3/s*(s-spr)
     &   *(-p1p3*p2p4*qta**2*mta**2+p1p3*p2p5*qta**2*mta**2+p1p4*p2p3*qta*
     &   *2*mta**2-p1p5*p2p3*qta**2*mta**2)
     &   +a0ps*iz4ta*betasprtata/ps**2/(s-mdn**2)/pi*alpha**3/s*(s-spr)*(-
     &   1d0/2*p1p3*p2p4*qta**2+1d0/2*p1p3*p2p5*qta**2+1d0/2*p1p4*p2p3*qta
     &   **2-1d0/2*p1p5*p2p3*qta**2)
     &   +a0spr*iz1dn**2*betasprtata/(s-mdn**2)/pi*alpha**3*qdn**2/s/spr**
     &   2*(s-spr)*(-p1p3*p2p4*mdn**2+p1p4*p2p3*mdn**2-p2p3*p4p5*mdn**2+p2
     &   p4*p3p5*mdn**2)
     &   +a0spr*iz1dn*iz2dn*betasprtata/(s-mdn**2)/pi*alpha**3*qdn**2/s/sp
     &   r**2*(s-spr)*(-2*p1p2*p1p3*p2p4-p1p2*p1p3*p4p5+2*p1p2*p1p4*p2p3+p
     &   1p2*p1p4*p3p5-p1p2*p2p3*p4p5+p1p2*p2p4*p3p5)
     &   +a0spr*iz1dn*betasprtata/(s-mdn**2)/pi*alpha**3*qdn**2/s/spr**2*(
     &   s-spr)*(-1d0/2*p1p3*p2p4+1d0/2*p1p4*p2p3-1d0/2*p2p3*p4p5+1d0/2*p2
     &   p4*p3p5)
     &   +a0spr*iz2dn**2*betasprtata/(s-mdn**2)/pi*alpha**3*qdn**2/s/spr**
     &   2*(s-spr)*(-p1p3*p2p4*mdn**2-p1p3*p4p5*mdn**2+p1p4*p2p3*mdn**2+p1
     &   p4*p3p5*mdn**2)
     &   +a0spr*iz2dn*betasprtata/(s-mdn**2)/pi*alpha**3*qdn**2/s/spr**2*(
     &   s-spr)*(1d0/2*p1p3*p2p4+1d0/2*p1p3*p4p5-1d0/2*p1p4*p2p3-1d0/2*p1p
     &   4*p3p5)
     &   +a0sprps*iz1dn*iz3ta*betasprtata/ps/(s-mdn**2)/pi*alpha**3*qdn/s/
     &   spr*(s-spr)*(p1p3*p1p4*p2p3*qta-1d0/2*p1p3*p1p4*p2p5*qta-1d0/2*p1
     &   p3*p2p3*p4p5*qta-p1p3**2*p2p4*qta+1d0/2*p2p5*p4p5*qta/mz**2*mdn**
     &   2*mta**2)
     &   +a0sprps*iz1dn*iz4ta*betasprtata/ps/(s-mdn**2)/pi*alpha**3*qdn/s/
     &   spr*(s-spr)*(p1p3*p1p4*p2p4*qta-1d0/2*p1p3*p1p4*p2p5*qta-1d0/2*p1
     &   p4*p2p4*p3p5*qta-p1p4**2*p2p3*qta+1d0/2*p2p5*p3p5*qta/mz**2*mdn**
     &   2*mta**2)
     &   +a0sprps*iz1dn*betasprtata/ps/(s-mdn**2)/pi*alpha**3*qdn/s/spr*(s
     &   -spr)*(-1d0/4*p1p2*p1p3*qta-1d0/4*p1p2*p1p4*qta-1d0/4*p1p3*p2p4*q
     &   ta-1d0/4*p1p4*p2p3*qta-1d0/4*p2p3*qta*mdn**2-1d0/4*p2p4*qta*mdn**
     &   2-1d0/2*p2p5*qta/mz**2*mdn**2*mta**2)
     &   +a0sprps*iz2dn*iz3ta*betasprtata/ps/(s-mdn**2)/pi*alpha**3*qdn/s/
     &   spr*(s-spr)*(p1p3*p2p3*p2p4*qta+1d0/2*p1p3*p2p3*p4p5*qta-p1p4*p2p
     &   3**2*qta-1d0/2*p1p5*p2p3*p2p4*qta+1d0/2*p1p5*p4p5*qta/mz**2*mdn**
     &   2*mta**2)
     &   +a0sprps*iz2dn*iz4ta*betasprtata/ps/(s-mdn**2)/pi*alpha**3*qdn/s/
     &   spr*(s-spr)*(-p1p3*p2p4**2*qta+p1p4*p2p3*p2p4*qta+1d0/2*p1p4*p2p4
     &   *p3p5*qta-1d0/2*p1p5*p2p3*p2p4*qta+1d0/2*p1p5*p3p5*qta/mz**2*mdn*
     &   *2*mta**2)
     &   +a0sprps*iz2dn*betasprtata/ps/(s-mdn**2)/pi*alpha**3*qdn/s/spr*(s
     &   -spr)*(-1d0/4*p1p2*p2p3*qta-1d0/4*p1p2*p2p4*qta+1d0/4*p1p3*p2p4*q
     &   ta-1d0/4*p1p3*qta*mdn**2+1d0/4*p1p4*p2p3*qta-1d0/4*p1p4*qta*mdn**
     &   2-1d0/2*p1p5*qta/mz**2*mdn**2*mta**2)
     &   +a0sprps*iz3ta*betasprtata/ps/(s-mdn**2)/pi*alpha**3*qdn/s/spr*(s
     &   -spr)*(-1d0/4*p1p3*p2p4*qta+1d0/4*p1p3*p3p4*qta-1d0/4*p1p4*p2p3*q
     &   ta+1d0/4*p1p4*qta*mta**2-1d0/4*p2p3*p3p4*qta-1d0/4*p2p4*qta*mta**
     &   2+1d0/2*p4p5*qta/mz**2*mdn**2*mta**2)
     &   +a0sprps*iz4ta*betasprtata/ps/(s-mdn**2)/pi*alpha**3*qdn/s/spr*(s
     &   -spr)*(-1d0/4*p1p3*p2p4*qta+1d0/4*p1p3*qta*mta**2-1d0/4*p1p4*p2p3
     &   *qta+1d0/4*p1p4*p3p4*qta-1d0/4*p2p3*qta*mta**2-1d0/4*p2p4*p3p4*qt
     &   a+1d0/2*p3p5*qta/mz**2*mdn**2*mta**2)
     &   +a0sprps*betasprtata/ps/(s-mdn**2)/pi*alpha**3*qdn/s/spr*(s-spr)*
     &   (-1d0/2*qta/mz**2*mdn**2*mta**2+1d0/4*p1p3*qta+1d0/4*p1p4*qta-1d0
     &   /4*p2p3*qta-1d0/4*p2p4*qta)
     &   +vaps*iz3ta**2*betasprtata/ps**2/(s-mdn**2)/pi*alpha**3/s*(s-spr)
     &   *(2*qta**2*mdn**2*mta**4+p1p2*qta**2*mta**4)
     &   +vaps*iz3ta*iz4ta*betasprtata/ps**2/(s-mdn**2)/pi*alpha**3/s*(s-s
     &   pr)*(2*p1p2*p3p4*qta**2*mta**2-2*p1p5*p2p5*qta**2*mta**2+4*p3p4*q
     &   ta**2*mdn**2*mta**2)
     &   +vaps*iz4ta**2*betasprtata/ps**2/(s-mdn**2)/pi*alpha**3/s*(s-spr)
     &   *(2*qta**2*mdn**2*mta**4+p1p2*qta**2*mta**4)
     &   +vaspr*iz1dn**2*betasprtata/(s-mdn**2)/pi*alpha**3*qdn**2/s/spr**
     &   2*(s-spr)*(2*mdn**4*mta**2+p1p2*mdn**2*mta**2-p2p5*mdn**2*mta**2)
     &
     &   +vaspr*iz1dn*iz2dn*betasprtata/(s-mdn**2)/pi*alpha**3*qdn**2/s/sp
     &   r**2*(s-spr)*(4*p1p2*mdn**2*mta**2+2*p1p2**2*mta**2)
     &   +vaspr*iz1dn*betasprtata/(s-mdn**2)/pi*alpha**3*qdn**2/s/spr**2*(
     &   s-spr)*(-1d0/2*mdn**2*mta**2+p1p2*mta**2-1d0/2*p2p5*mta**2)
     &   +vaspr*iz2dn**2*betasprtata/(s-mdn**2)/pi*alpha**3*qdn**2/s/spr**
     &   2*(s-spr)*(2*mdn**4*mta**2+p1p2*mdn**2*mta**2+p1p5*mdn**2*mta**2)
     &
     &   +vaspr*iz2dn*betasprtata/(s-mdn**2)/pi*alpha**3*qdn**2/s/spr**2*(
     &   s-spr)*(1d0/2*mdn**2*mta**2-p1p2*mta**2-1d0/2*p1p5*mta**2)
     &   +vasprps*iz1dn*iz3ta*betasprtata/ps/(s-mdn**2)/pi*alpha**3*qdn/s/
     &   spr*(s-spr)*(p1p2*p1p3*qta*mta**2-1d0/2*p1p3*p2p5*qta*mta**2+2*p1
     &   p3*qta*mdn**2*mta**2)
     &   +vasprps*iz1dn*iz4ta*betasprtata/ps/(s-mdn**2)/pi*alpha**3*qdn/s/
     &   spr*(s-spr)*(-p1p2*p1p4*qta*mta**2+1d0/2*p1p4*p2p5*qta*mta**2-2*p
     &   1p4*qta*mdn**2*mta**2)
     &   +vasprps*iz2dn*iz3ta*betasprtata/ps/(s-mdn**2)/pi*alpha**3*qdn/s/
     &   spr*(s-spr)*(-p1p2*p2p3*qta*mta**2-1d0/2*p1p5*p2p3*qta*mta**2-2*p
     &   2p3*qta*mdn**2*mta**2)
     &   +vasprps*iz2dn*iz4ta*betasprtata/ps/(s-mdn**2)/pi*alpha**3*qdn/s/
     &   spr*(s-spr)*(p1p2*p2p4*qta*mta**2+1d0/2*p1p5*p2p4*qta*mta**2+2*p2
     &   p4*qta*mdn**2*mta**2)
     &   +vasprps*iz3ta*betasprtata/ps/(s-mdn**2)/pi*alpha**3*qdn/s/spr*(s
     &   -spr)*(-1d0/4*p1p3*qta*mta**2-1d0/4*p1p5*qta*mta**2-1d0/4*p2p3*qt
     &   a*mta**2-1d0/4*p2p5*qta*mta**2)
     &   +vasprps*iz4ta*betasprtata/ps/(s-mdn**2)/pi*alpha**3*qdn/s/spr*(s
     &   -spr)*(1d0/4*p1p4*qta*mta**2+1d0/4*p1p5*qta*mta**2+1d0/4*p2p4*qta
     &   *mta**2+1d0/4*p2p5*qta*mta**2)
     &   +a1sprps*iz1dn*iz3ta*betasprtata/ps/(s-mdn**2)/pi*alpha**3*qdn**2
     &   /s/spr*(s-spr)*(1d0/2*p2p5*p4p5*qta**2/mz**2*mdn**2*mta**2-1d0/2*
     &   p2p5*qta**2*mdn**2*mta**2-1d0/2*p4p5*qta**2*mdn**2*mta**2)
     &   +a1sprps*iz1dn*iz3ta*betasprtata*chizsprc/ps/(s-mdn**2)*a1z/pi*al
     &   pha**3*qdn/s/spr*(s-spr)*(-8*p1p2*p1p3*p3p4*qta/mz**4*mdn**2*mta*
     &   *2+4*p1p2*p1p3*p4p5*qta/mz**4*mdn**2*mta**2+8*p1p2*p1p3*qta/mz**4
     &   *mdn**2*mta**4-4*p1p3*p1p4*qta/mz**2*mdn**2*mta**2+4*p1p3*p2p3*qt
     &   a/mz**2*mdn**2*mta**2+4*p1p3*p2p4*qta/mz**2*mdn**2*mta**2+4*p1p3*
     &   p2p5*p3p4*qta/mz**4*mdn**2*mta**2-2*p1p3*p2p5*p4p5*qta/mz**4*mdn*
     &   *2*mta**2-4*p1p3*p2p5*qta/mz**4*mdn**2*mta**4-2*p1p3*p2p5*qta/mz*
     &   *2*mdn**2*mta**2-8*p1p3*p3p4*qta/mz**4*mdn**4*mta**2+2*p1p3*p3p4*
     &   qta*mdn**2+4*p1p3*p4p5*qta/mz**4*mdn**4*mta**2+2*p1p3*p4p5*qta/mz
     &   **2*mdn**2*mta**2-p1p3*p4p5*qta*mdn**2+8*p1p3*qta/mz**4*mdn**4*mt
     &   a**4+4*p1p3*qta*mdn**2*mta**2-4*p1p3**2*qta/mz**2*mdn**2*mta**2-2
     &   *p2p5*p4p5*qta/mz**2*mdn**2*mta**2)
     &   +a1sprps*iz1dn*iz4ta*betasprtata/ps/(s-mdn**2)/pi*alpha**3*qdn**2
     &   /s/spr*(s-spr)*(1d0/2*p2p5*p3p5*qta**2/mz**2*mdn**2*mta**2-1d0/2*
     &   p2p5*qta**2*mdn**2*mta**2-1d0/2*p3p5*qta**2*mdn**2*mta**2)
     &   +a1sprps*iz1dn*iz4ta*betasprtata*chizsprc/ps/(s-mdn**2)*a1z/pi*al
     &   pha**3*qdn/s/spr*(s-spr)*(8*p1p2*p1p4*p3p4*qta/mz**4*mdn**2*mta**
     &   2-4*p1p2*p1p4*p3p5*qta/mz**4*mdn**2*mta**2-8*p1p2*p1p4*qta/mz**4*
     &   mdn**2*mta**4+4*p1p3*p1p4*qta/mz**2*mdn**2*mta**2-4*p1p4*p2p3*qta
     &   /mz**2*mdn**2*mta**2-4*p1p4*p2p4*qta/mz**2*mdn**2*mta**2-4*p1p4*p
     &   2p5*p3p4*qta/mz**4*mdn**2*mta**2+2*p1p4*p2p5*p3p5*qta/mz**4*mdn**
     &   2*mta**2+4*p1p4*p2p5*qta/mz**4*mdn**2*mta**4+2*p1p4*p2p5*qta/mz**
     &   2*mdn**2*mta**2+8*p1p4*p3p4*qta/mz**4*mdn**4*mta**2-2*p1p4*p3p4*q
     &   ta*mdn**2-4*p1p4*p3p5*qta/mz**4*mdn**4*mta**2-2*p1p4*p3p5*qta/mz*
     &   *2*mdn**2*mta**2+p1p4*p3p5*qta*mdn**2-8*p1p4*qta/mz**4*mdn**4*mta
     &   **4-4*p1p4*qta*mdn**2*mta**2+4*p1p4**2*qta/mz**2*mdn**2*mta**2+2*
     &   p2p5*p3p5*qta/mz**2*mdn**2*mta**2)
     &   +a1sprps*iz1dn*betasprtata/ps/(s-mdn**2)/pi*alpha**3*qdn**2/s/spr
     &   *(s-spr)*(-1d0/2*p2p5*qta**2/mz**2*mdn**2*mta**2+1d0/2*p3p4*qta**
     &   2*mdn**2-1d0/4*p3p5*qta**2*mdn**2-1d0/4*p4p5*qta**2*mdn**2)
     &   +a1sprps*iz1dn*betasprtata*chizsprc/ps/(s-mdn**2)*a1z/pi*alpha**3
     &   *qdn/s/spr*(s-spr)*(-2*p1p2*p1p3*qta/mz**4*mdn**2*mta**2+2*p1p2*p
     &   1p4*qta/mz**4*mdn**2*mta**2+p1p3*p2p5*qta/mz**4*mdn**2*mta**2-2*p
     &   1p3*qta/mz**4*mdn**4*mta**2-p1p3*qta/mz**2*mdn**2*mta**2+1d0/2*p1
     &   p3*qta*mdn**2-p1p4*p2p5*qta/mz**4*mdn**2*mta**2+2*p1p4*qta/mz**4*
     &   mdn**4*mta**2+p1p4*qta/mz**2*mdn**2*mta**2-1d0/2*p1p4*qta*mdn**2+
     &   1d0/2*p3p5*qta*mdn**2-1d0/2*p4p5*qta*mdn**2)
     &   +a1sprps*iz2dn*iz3ta*betasprtata/ps/(s-mdn**2)/pi*alpha**3*qdn**2
     &   /s/spr*(s-spr)*(1d0/2*p1p5*p4p5*qta**2/mz**2*mdn**2*mta**2-1d0/2*
     &   p1p5*qta**2*mdn**2*mta**2+1d0/2*p4p5*qta**2*mdn**2*mta**2)
     &   +a1sprps*iz2dn*iz3ta*betasprtata*chizsprc/ps/(s-mdn**2)*a1z/pi*al
     &   pha**3*qdn/s/spr*(s-spr)*(8*p1p2*p2p3*p3p4*qta/mz**4*mdn**2*mta**
     &   2-4*p1p2*p2p3*p4p5*qta/mz**4*mdn**2*mta**2-8*p1p2*p2p3*qta/mz**4*
     &   mdn**2*mta**4+4*p1p3*p2p3*qta/mz**2*mdn**2*mta**2+4*p1p4*p2p3*qta
     &   /mz**2*mdn**2*mta**2+4*p1p5*p2p3*p3p4*qta/mz**4*mdn**2*mta**2-2*p
     &   1p5*p2p3*p4p5*qta/mz**4*mdn**2*mta**2-4*p1p5*p2p3*qta/mz**4*mdn**
     &   2*mta**4-2*p1p5*p2p3*qta/mz**2*mdn**2*mta**2+2*p1p5*p4p5*qta/mz**
     &   2*mdn**2*mta**2-4*p2p3*p2p4*qta/mz**2*mdn**2*mta**2+8*p2p3*p3p4*q
     &   ta/mz**4*mdn**4*mta**2-2*p2p3*p3p4*qta*mdn**2-4*p2p3*p4p5*qta/mz*
     &   *4*mdn**4*mta**2-2*p2p3*p4p5*qta/mz**2*mdn**2*mta**2+p2p3*p4p5*qt
     &   a*mdn**2-8*p2p3*qta/mz**4*mdn**4*mta**4-4*p2p3*qta*mdn**2*mta**2-
     &   4*p2p3**2*qta/mz**2*mdn**2*mta**2)
     &   +a1sprps*iz2dn*iz4ta*betasprtata/ps/(s-mdn**2)/pi*alpha**3*qdn**2
     &   /s/spr*(s-spr)*(1d0/2*p1p5*p3p5*qta**2/mz**2*mdn**2*mta**2-1d0/2*
     &   p1p5*qta**2*mdn**2*mta**2+1d0/2*p3p5*qta**2*mdn**2*mta**2)
     &   +a1sprps*iz2dn*iz4ta*betasprtata*chizsprc/ps/(s-mdn**2)*a1z/pi*al
     &   pha**3*qdn/s/spr*(s-spr)*(-8*p1p2*p2p4*p3p4*qta/mz**4*mdn**2*mta*
     &   *2+4*p1p2*p2p4*p3p5*qta/mz**4*mdn**2*mta**2+8*p1p2*p2p4*qta/mz**4
     &   *mdn**2*mta**4-4*p1p3*p2p4*qta/mz**2*mdn**2*mta**2-4*p1p4*p2p4*qt
     &   a/mz**2*mdn**2*mta**2-4*p1p5*p2p4*p3p4*qta/mz**4*mdn**2*mta**2+2*
     &   p1p5*p2p4*p3p5*qta/mz**4*mdn**2*mta**2+4*p1p5*p2p4*qta/mz**4*mdn*
     &   *2*mta**4+2*p1p5*p2p4*qta/mz**2*mdn**2*mta**2-2*p1p5*p3p5*qta/mz*
     &   *2*mdn**2*mta**2+4*p2p3*p2p4*qta/mz**2*mdn**2*mta**2-8*p2p4*p3p4*
     &   qta/mz**4*mdn**4*mta**2+2*p2p4*p3p4*qta*mdn**2+4*p2p4*p3p5*qta/mz
     &   **4*mdn**4*mta**2+2*p2p4*p3p5*qta/mz**2*mdn**2*mta**2-p2p4*p3p5*q
     &   ta*mdn**2+8*p2p4*qta/mz**4*mdn**4*mta**4+4*p2p4*qta*mdn**2*mta**2
     &   +4*p2p4**2*qta/mz**2*mdn**2*mta**2)
     &   +a1sprps*iz2dn*betasprtata/ps/(s-mdn**2)/pi*alpha**3*qdn**2/s/spr
     &   *(s-spr)*(-1d0/2*p1p5*qta**2/mz**2*mdn**2*mta**2-1d0/2*p3p4*qta**
     &   2*mdn**2+1d0/4*p3p5*qta**2*mdn**2+1d0/4*p4p5*qta**2*mdn**2)
     &   +a1sprps*iz2dn*betasprtata*chizsprc/ps/(s-mdn**2)*a1z/pi*alpha**3
     &   *qdn/s/spr*(s-spr)*(2*p1p2*p2p3*qta/mz**4*mdn**2*mta**2-2*p1p2*p2
     &   p4*qta/mz**4*mdn**2*mta**2+p1p5*p2p3*qta/mz**4*mdn**2*mta**2-p1p5
     &   *p2p4*qta/mz**4*mdn**2*mta**2+2*p2p3*qta/mz**4*mdn**4*mta**2+p2p3
     &   *qta/mz**2*mdn**2*mta**2-1d0/2*p2p3*qta*mdn**2-2*p2p4*qta/mz**4*m
     &   dn**4*mta**2-p2p4*qta/mz**2*mdn**2*mta**2+1d0/2*p2p4*qta*mdn**2+1
     &   d0/2*p3p5*qta*mdn**2-1d0/2*p4p5*qta*mdn**2)
     &   +a1sprps*iz3ta**2*betasprtata*chizpsc/ps**2/(s-mdn**2)*a1z/pi*alp
     &   ha**3/s*(s-spr)*(8*qta**2/mz**4*mdn**4*mta**6+4*qta**2*mdn**2*mta
     &   **4-8*p1p2*p3p4*qta**2/mz**4*mdn**2*mta**4+8*p1p2*p4p5*qta**2/mz*
     &   *4*mdn**2*mta**4+8*p1p2*qta**2/mz**4*mdn**2*mta**6-4*p1p3*qta**2/
     &   mz**2*mdn**2*mta**4-4*p1p4*qta**2/mz**2*mdn**2*mta**4+4*p1p5*qta*
     &   *2/mz**2*mdn**2*mta**4+4*p2p3*qta**2/mz**2*mdn**2*mta**4+4*p2p4*q
     &   ta**2/mz**2*mdn**2*mta**4-4*p2p5*qta**2/mz**2*mdn**2*mta**4-8*p3p
     &   4*qta**2/mz**4*mdn**4*mta**4+2*p3p4*qta**2*mdn**2*mta**2+8*p4p5*q
     &   ta**2/mz**4*mdn**4*mta**4-2*p4p5*qta**2*mdn**2*mta**2)
     &   +a1sprps*iz3ta*iz4ta*betasprtata*chizpsc/ps**2/(s-mdn**2)*a1z/pi*
     &   alpha**3/s*(s-spr)*(16*p1p2*p3p4*qta**2/mz**4*mdn**2*mta**4-16*p1
     &   p2*p3p4**2*qta**2/mz**4*mdn**2*mta**2-8*p1p3*p3p4*qta**2/mz**2*md
     &   n**2*mta**2-8*p1p4*p3p4*qta**2/mz**2*mdn**2*mta**2+8*p1p5*p3p4*qt
     &   a**2/mz**2*mdn**2*mta**2+8*p2p3*p3p4*qta**2/mz**2*mdn**2*mta**2+8
     &   *p2p4*p3p4*qta**2/mz**2*mdn**2*mta**2-8*p2p5*p3p4*qta**2/mz**2*md
     &   n**2*mta**2+16*p3p4*qta**2/mz**4*mdn**4*mta**4+8*p3p4*qta**2*mdn*
     &   *2*mta**2-16*p3p4**2*qta**2/mz**4*mdn**4*mta**2+4*p3p4**2*qta**2*
     &   mdn**2)
     &   +a1sprps*iz3ta*betasprtata/ps/(s-mdn**2)/pi*alpha**3*qdn**2/s/spr
     &   *(s-spr)*(1d0/2*p1p2*qta**2*mta**2+1d0/4*p1p5*qta**2*mta**2-1d0/4
     &   *p2p5*qta**2*mta**2+1d0/2*p4p5*qta**2/mz**2*mdn**2*mta**2)
     &   +a1sprps*iz3ta*betasprtata*chizpsc/ps**2/(s-mdn**2)*a1z/pi*alpha*
     &   *3/s*(s-spr)*(-4*qta**2/mz**4*mdn**4*mta**4+qta**2*mdn**2*mta**2-
     &   8*p1p2*p3p4*qta**2/mz**4*mdn**2*mta**2+4*p1p2*p4p5*qta**2/mz**4*m
     &   dn**2*mta**2-4*p1p2*qta**2/mz**4*mdn**2*mta**4+4*p1p5*qta**2/mz**
     &   2*mdn**2*mta**2-4*p2p5*qta**2/mz**2*mdn**2*mta**2-8*p3p4*qta**2/m
     &   z**4*mdn**4*mta**2+2*p3p4*qta**2*mdn**2+4*p4p5*qta**2/mz**4*mdn**
     &   4*mta**2-p4p5*qta**2*mdn**2)
     &   +a1sprps*iz3ta*betasprtata*chizsprc/ps/(s-mdn**2)*a1z/pi*alpha**3
     &   *qdn/s/spr*(s-spr)*(2*p1p3*p3p4*qta/mz**4*mdn**2*mta**2-p1p3*p4p5
     &   *qta/mz**4*mdn**2*mta**2-2*p1p3*qta/mz**4*mdn**2*mta**4-p1p3*qta/
     &   mz**2*mdn**2*mta**2+2*p2p3*p3p4*qta/mz**4*mdn**2*mta**2-p2p3*p4p5
     &   *qta/mz**4*mdn**2*mta**2-2*p2p3*qta/mz**4*mdn**2*mta**4-p2p3*qta/
     &   mz**2*mdn**2*mta**2)
     &   +a1sprps*iz4ta**2*betasprtata*chizpsc/ps**2/(s-mdn**2)*a1z/pi*alp
     &   ha**3/s*(s-spr)*(8*qta**2/mz**4*mdn**4*mta**6+4*qta**2*mdn**2*mta
     &   **4-8*p1p2*p3p4*qta**2/mz**4*mdn**2*mta**4+8*p1p2*p3p5*qta**2/mz*
     &   *4*mdn**2*mta**4+8*p1p2*qta**2/mz**4*mdn**2*mta**6-4*p1p3*qta**2/
     &   mz**2*mdn**2*mta**4-4*p1p4*qta**2/mz**2*mdn**2*mta**4+4*p1p5*qta*
     &   *2/mz**2*mdn**2*mta**4+4*p2p3*qta**2/mz**2*mdn**2*mta**4+4*p2p4*q
     &   ta**2/mz**2*mdn**2*mta**4-4*p2p5*qta**2/mz**2*mdn**2*mta**4-8*p3p
     &   4*qta**2/mz**4*mdn**4*mta**4+2*p3p4*qta**2*mdn**2*mta**2+8*p3p5*q
     &   ta**2/mz**4*mdn**4*mta**4-2*p3p5*qta**2*mdn**2*mta**2)
     &   +a1sprps*iz4ta*betasprtata/ps/(s-mdn**2)/pi*alpha**3*qdn**2/s/spr
     &   *(s-spr)*(1d0/2*p1p2*qta**2*mta**2+1d0/4*p1p5*qta**2*mta**2-1d0/4
     &   *p2p5*qta**2*mta**2+1d0/2*p3p5*qta**2/mz**2*mdn**2*mta**2)
     &   +a1sprps*iz4ta*betasprtata*chizpsc/ps**2/(s-mdn**2)*a1z/pi*alpha*
     &   *3/s*(s-spr)*(-4*qta**2/mz**4*mdn**4*mta**4+qta**2*mdn**2*mta**2-
     &   8*p1p2*p3p4*qta**2/mz**4*mdn**2*mta**2+4*p1p2*p3p5*qta**2/mz**4*m
     &   dn**2*mta**2-4*p1p2*qta**2/mz**4*mdn**2*mta**4+4*p1p5*qta**2/mz**
     &   2*mdn**2*mta**2-4*p2p5*qta**2/mz**2*mdn**2*mta**2-8*p3p4*qta**2/m
     &   z**4*mdn**4*mta**2+2*p3p4*qta**2*mdn**2+4*p3p5*qta**2/mz**4*mdn**
     &   4*mta**2-p3p5*qta**2*mdn**2)
     &   +a1sprps*iz4ta*betasprtata*chizsprc/ps/(s-mdn**2)*a1z/pi*alpha**3
     &   *qdn/s/spr*(s-spr)*(-2*p1p4*p3p4*qta/mz**4*mdn**2*mta**2+p1p4*p3p
     &   5*qta/mz**4*mdn**2*mta**2+2*p1p4*qta/mz**4*mdn**2*mta**4+p1p4*qta
     &   /mz**2*mdn**2*mta**2-2*p2p4*p3p4*qta/mz**4*mdn**2*mta**2+p2p4*p3p
     &   5*qta/mz**4*mdn**2*mta**2+2*p2p4*qta/mz**4*mdn**2*mta**4+p2p4*qta
     &   /mz**2*mdn**2*mta**2)
     &   +a1sprps*betasprtata/ps/(s-mdn**2)/pi*alpha**3*qdn**2/s/spr*(s-sp
     &   r)*(-1d0/2*qta**2/mz**2*mdn**2*mta**2)
     &   +a1sprps*betasprtata*chizpsc/ps**2/(s-mdn**2)*a1z/pi*alpha**3/s*(
     &   s-spr)*(-4*qta**2/mz**4*mdn**4*mta**2-4*p1p2*qta**2/mz**4*mdn**2*
     &   mta**2)
     &   +a1sprps*betasprtata*chizsprc/ps/(s-mdn**2)*a1z/pi*alpha**3*qdn/s
     &   /spr*(s-spr)*(1d0/2*p1p3*qta/mz**4*mdn**2*mta**2-1d0/2*p1p4*qta/m
     &   z**4*mdn**2*mta**2+1d0/2*p2p3*qta/mz**4*mdn**2*mta**2-1d0/2*p2p4*
     &   qta/mz**4*mdn**2*mta**2)
     &   +iz1dn**2*betasprtata*chizspr*chizsprc/(s-mdn**2)/pi*alpha**3*qdn
     &   **2/s/spr**2*(s-spr)*(-4*adn**2*vta**2*mdn**4*mta**2+2*p3p4*adn**
     &   2*vta**2*mdn**4)
     &   +iz1dn**2*betasprtata*chizspr*chizsprc/(s-mdn**2)*a1z**2/pi*alpha
     &   **3*qdn**2/s/spr**2*(s-spr)*(8/mz**4*mdn**6*mta**4+4*mdn**4*mta**
     &   2-8*p1p2*p3p4/mz**4*mdn**4*mta**2+8*p1p2/mz**4*mdn**4*mta**4-4*p1
     &   p3/mz**2*mdn**4*mta**2-4*p1p4/mz**2*mdn**4*mta**2+4*p2p3/mz**2*md
     &   n**4*mta**2+4*p2p4/mz**2*mdn**4*mta**2+8*p2p5*p3p4/mz**4*mdn**4*m
     &   ta**2-8*p2p5/mz**4*mdn**4*mta**4-8*p3p4/mz**4*mdn**6*mta**2+2*p3p
     &   4*mdn**4+4*p3p5/mz**2*mdn**4*mta**2+4*p4p5/mz**2*mdn**4*mta**2)
     &   +iz1dn*iz2dn*betasprtata*chizspr*chizsprc/(s-mdn**2)/pi*alpha**3*
     &   qdn**2/s/spr**2*(s-spr)*(4*p1p2*p3p4*adn**2*vta**2*mdn**2-8*p1p2*
     &   adn**2*vta**2*mdn**2*mta**2+4*p3p5*p4p5*adn**2*vta**2*mdn**2)
     &   +iz1dn*iz2dn*betasprtata*chizspr*chizsprc/(s-mdn**2)*a1z**2/pi*al
     &   pha**3*qdn**2/s/spr**2*(s-spr)*(-8*p1p2*p1p3/mz**2*mdn**2*mta**2-
     &   8*p1p2*p1p4/mz**2*mdn**2*mta**2+8*p1p2*p2p3/mz**2*mdn**2*mta**2+8
     &   *p1p2*p2p4/mz**2*mdn**2*mta**2-16*p1p2*p3p4/mz**4*mdn**4*mta**2+4
     &   *p1p2*p3p4*mdn**2+8*p1p2*p3p5/mz**2*mdn**2*mta**2+8*p1p2*p4p5/mz*
     &   *2*mdn**2*mta**2+16*p1p2/mz**4*mdn**4*mta**4+8*p1p2*mdn**2*mta**2
     &   -16*p1p2**2*p3p4/mz**4*mdn**2*mta**2+16*p1p2**2/mz**4*mdn**2*mta*
     &   *4+4*p3p5*p4p5*mdn**2)
     &   +iz1dn*iz3ta*betasprtata*chizps*chizsprc/ps/(s-mdn**2)/pi*alpha**
     &   3*qdn/s/spr*(s-spr)*(2*p1p3*p3p4*adn**2*qta*vta**2*mdn**2-p1p3*p4
     &   p5*adn**2*qta*vta**2*mdn**2-4*p1p3*adn**2*qta*vta**2*mdn**2*mta**
     &   2)
     &   +iz1dn*iz3ta*betasprtata*chizspr/ps/(s-mdn**2)*a1z/pi*alpha**3*qd
     &   n**2/s/spr*(s-spr)*(p2p5*p4p5*qta**2/mz**2*mdn**2*mta**2)
     &   +iz1dn*iz3ta*betasprtata*chizspr*chizpsc/ps/(s-mdn**2)/pi*alpha**
     &   3*qdn/s/spr*(s-spr)*(2*p1p3*p3p4*adn**2*qta*vta**2*mdn**2-p1p3*p4
     &   p5*adn**2*qta*vta**2*mdn**2-4*p1p3*adn**2*qta*vta**2*mdn**2*mta**
     &   2)
     &   +iz1dn*iz3ta*betasprtata*chizspr*chizpsc/ps/(s-mdn**2)*a1z**2/pi*
     &   alpha**3*qdn/s/spr*(s-spr)*(-8*p1p2*p1p3*p3p4*qta/mz**4*mdn**2*mt
     &   a**2+4*p1p2*p1p3*p4p5*qta/mz**4*mdn**2*mta**2+8*p1p2*p1p3*qta/mz*
     &   *4*mdn**2*mta**4-4*p1p3*p1p4*qta/mz**2*mdn**2*mta**2+4*p1p3*p2p3*
     &   qta/mz**2*mdn**2*mta**2+4*p1p3*p2p4*qta/mz**2*mdn**2*mta**2+4*p1p
     &   3*p2p5*p3p4*qta/mz**4*mdn**2*mta**2-2*p1p3*p2p5*p4p5*qta/mz**4*md
     &   n**2*mta**2-4*p1p3*p2p5*qta/mz**4*mdn**2*mta**4-2*p1p3*p2p5*qta/m
     &   z**2*mdn**2*mta**2-8*p1p3*p3p4*qta/mz**4*mdn**4*mta**2+2*p1p3*p3p
     &   4*qta*mdn**2+4*p1p3*p4p5*qta/mz**4*mdn**4*mta**2+2*p1p3*p4p5*qta/
     &   mz**2*mdn**2*mta**2-p1p3*p4p5*qta*mdn**2+8*p1p3*qta/mz**4*mdn**4*
     &   mta**4+4*p1p3*qta*mdn**2*mta**2-4*p1p3**2*qta/mz**2*mdn**2*mta**2
     &   -2*p2p5*p4p5*qta/mz**2*mdn**2*mta**2)
     &   +iz1dn*iz3ta*betasprtata*chizspr*chizsprc/ps/(s-mdn**2)*a1z**2/pi
     &   *alpha**3*qdn/s/spr*(s-spr)*(-8*p1p2*p1p3*p3p4*qta/mz**4*mdn**2*m
     &   ta**2+4*p1p2*p1p3*p4p5*qta/mz**4*mdn**2*mta**2+8*p1p2*p1p3*qta/mz
     &   **4*mdn**2*mta**4-4*p1p3*p1p4*qta/mz**2*mdn**2*mta**2+4*p1p3*p2p3
     &   *qta/mz**2*mdn**2*mta**2+4*p1p3*p2p4*qta/mz**2*mdn**2*mta**2+4*p1
     &   p3*p2p5*p3p4*qta/mz**4*mdn**2*mta**2-2*p1p3*p2p5*p4p5*qta/mz**4*m
     &   dn**2*mta**2-4*p1p3*p2p5*qta/mz**4*mdn**2*mta**4-2*p1p3*p2p5*qta/
     &   mz**2*mdn**2*mta**2-8*p1p3*p3p4*qta/mz**4*mdn**4*mta**2+2*p1p3*p3
     &   p4*qta*mdn**2+4*p1p3*p4p5*qta/mz**4*mdn**4*mta**2+2*p1p3*p4p5*qta
     &   /mz**2*mdn**2*mta**2-p1p3*p4p5*qta*mdn**2+8*p1p3*qta/mz**4*mdn**4
     &   *mta**4+4*p1p3*qta*mdn**2*mta**2-4*p1p3**2*qta/mz**2*mdn**2*mta**
     &   2-2*p2p5*p4p5*qta/mz**2*mdn**2*mta**2)
     &   +iz1dn*iz3ta*betasprtata*chizpsc*chizsprc/ps/(s-mdn**2)*a1z**2/pi
     &   *alpha**3*qdn/s/spr*(s-spr)*(8*p1p2*p1p3*p3p4*qta/mz**4*mdn**2*mt
     &   a**2-4*p1p2*p1p3*p4p5*qta/mz**4*mdn**2*mta**2-8*p1p2*p1p3*qta/mz*
     &   *4*mdn**2*mta**4+4*p1p3*p1p4*qta/mz**2*mdn**2*mta**2-4*p1p3*p2p3*
     &   qta/mz**2*mdn**2*mta**2-4*p1p3*p2p4*qta/mz**2*mdn**2*mta**2-4*p1p
     &   3*p2p5*p3p4*qta/mz**4*mdn**2*mta**2+2*p1p3*p2p5*p4p5*qta/mz**4*md
     &   n**2*mta**2+4*p1p3*p2p5*qta/mz**4*mdn**2*mta**4+2*p1p3*p2p5*qta/m
     &   z**2*mdn**2*mta**2+8*p1p3*p3p4*qta/mz**4*mdn**4*mta**2-2*p1p3*p3p
     &   4*qta*mdn**2-4*p1p3*p4p5*qta/mz**4*mdn**4*mta**2-2*p1p3*p4p5*qta/
     &   mz**2*mdn**2*mta**2+p1p3*p4p5*qta*mdn**2-8*p1p3*qta/mz**4*mdn**4*
     &   mta**4-4*p1p3*qta*mdn**2*mta**2+4*p1p3**2*qta/mz**2*mdn**2*mta**2
     &   +2*p2p5*p4p5*qta/mz**2*mdn**2*mta**2)
     &   +iz1dn*iz3ta*betasprtata*chizsprc/ps/(s-mdn**2)*a1z/pi*alpha**3*q
     &   dn**2/s/spr*(s-spr)*(p2p5*p4p5*qta**2/mz**2*mdn**2*mta**2)
     &   +iz1dn*iz3ta*betasprtata*chizsprc**2/ps/(s-mdn**2)*a1z**2/pi*alph
     &   a**3*qdn/s/spr*(s-spr)*(-8*p1p2*p1p3*p3p4*qta/mz**4*mdn**2*mta**2
     &   +4*p1p2*p1p3*p4p5*qta/mz**4*mdn**2*mta**2+8*p1p2*p1p3*qta/mz**4*m
     &   dn**2*mta**4-4*p1p3*p1p4*qta/mz**2*mdn**2*mta**2+4*p1p3*p2p3*qta/
     &   mz**2*mdn**2*mta**2+4*p1p3*p2p4*qta/mz**2*mdn**2*mta**2+4*p1p3*p2
     &   p5*p3p4*qta/mz**4*mdn**2*mta**2-2*p1p3*p2p5*p4p5*qta/mz**4*mdn**2
     &   *mta**2-4*p1p3*p2p5*qta/mz**4*mdn**2*mta**4-2*p1p3*p2p5*qta/mz**2
     &   *mdn**2*mta**2-8*p1p3*p3p4*qta/mz**4*mdn**4*mta**2+2*p1p3*p3p4*qt
     &   a*mdn**2+4*p1p3*p4p5*qta/mz**4*mdn**4*mta**2+2*p1p3*p4p5*qta/mz**
     &   2*mdn**2*mta**2-p1p3*p4p5*qta*mdn**2+8*p1p3*qta/mz**4*mdn**4*mta*
     &   *4+4*p1p3*qta*mdn**2*mta**2-4*p1p3**2*qta/mz**2*mdn**2*mta**2-2*p
     &   2p5*p4p5*qta/mz**2*mdn**2*mta**2)
     &   +iz1dn*iz4ta*betasprtata*chizps*chizsprc/ps/(s-mdn**2)/pi*alpha**
     &   3*qdn/s/spr*(s-spr)*(-2*p1p4*p3p4*adn**2*qta*vta**2*mdn**2+p1p4*p
     &   3p5*adn**2*qta*vta**2*mdn**2+4*p1p4*adn**2*qta*vta**2*mdn**2*mta*
     &   *2)
     &   +iz1dn*iz4ta*betasprtata*chizspr/ps/(s-mdn**2)*a1z/pi*alpha**3*qd
     &   n**2/s/spr*(s-spr)*(p2p5*p3p5*qta**2/mz**2*mdn**2*mta**2)
     &   +iz1dn*iz4ta*betasprtata*chizspr*chizpsc/ps/(s-mdn**2)/pi*alpha**
     &   3*qdn/s/spr*(s-spr)*(-2*p1p4*p3p4*adn**2*qta*vta**2*mdn**2+p1p4*p
     &   3p5*adn**2*qta*vta**2*mdn**2+4*p1p4*adn**2*qta*vta**2*mdn**2*mta*
     &   *2)
     &   +iz1dn*iz4ta*betasprtata*chizspr*chizpsc/ps/(s-mdn**2)*a1z**2/pi*
     &   alpha**3*qdn/s/spr*(s-spr)*(8*p1p2*p1p4*p3p4*qta/mz**4*mdn**2*mta
     &   **2-4*p1p2*p1p4*p3p5*qta/mz**4*mdn**2*mta**2-8*p1p2*p1p4*qta/mz**
     &   4*mdn**2*mta**4+4*p1p3*p1p4*qta/mz**2*mdn**2*mta**2-4*p1p4*p2p3*q
     &   ta/mz**2*mdn**2*mta**2-4*p1p4*p2p4*qta/mz**2*mdn**2*mta**2-4*p1p4
     &   *p2p5*p3p4*qta/mz**4*mdn**2*mta**2+2*p1p4*p2p5*p3p5*qta/mz**4*mdn
     &   **2*mta**2+4*p1p4*p2p5*qta/mz**4*mdn**2*mta**4+2*p1p4*p2p5*qta/mz
     &   **2*mdn**2*mta**2+8*p1p4*p3p4*qta/mz**4*mdn**4*mta**2-2*p1p4*p3p4
     &   *qta*mdn**2-4*p1p4*p3p5*qta/mz**4*mdn**4*mta**2-2*p1p4*p3p5*qta/m
     &   z**2*mdn**2*mta**2+p1p4*p3p5*qta*mdn**2-8*p1p4*qta/mz**4*mdn**4*m
     &   ta**4-4*p1p4*qta*mdn**2*mta**2+4*p1p4**2*qta/mz**2*mdn**2*mta**2+
     &   2*p2p5*p3p5*qta/mz**2*mdn**2*mta**2)
     &   +iz1dn*iz4ta*betasprtata*chizspr*chizsprc/ps/(s-mdn**2)*a1z**2/pi
     &   *alpha**3*qdn/s/spr*(s-spr)*(8*p1p2*p1p4*p3p4*qta/mz**4*mdn**2*mt
     &   a**2-4*p1p2*p1p4*p3p5*qta/mz**4*mdn**2*mta**2-8*p1p2*p1p4*qta/mz*
     &   *4*mdn**2*mta**4+4*p1p3*p1p4*qta/mz**2*mdn**2*mta**2-4*p1p4*p2p3*
     &   qta/mz**2*mdn**2*mta**2-4*p1p4*p2p4*qta/mz**2*mdn**2*mta**2-4*p1p
     &   4*p2p5*p3p4*qta/mz**4*mdn**2*mta**2+2*p1p4*p2p5*p3p5*qta/mz**4*md
     &   n**2*mta**2+4*p1p4*p2p5*qta/mz**4*mdn**2*mta**4+2*p1p4*p2p5*qta/m
     &   z**2*mdn**2*mta**2+8*p1p4*p3p4*qta/mz**4*mdn**4*mta**2-2*p1p4*p3p
     &   4*qta*mdn**2-4*p1p4*p3p5*qta/mz**4*mdn**4*mta**2-2*p1p4*p3p5*qta/
     &   mz**2*mdn**2*mta**2+p1p4*p3p5*qta*mdn**2-8*p1p4*qta/mz**4*mdn**4*
     &   mta**4-4*p1p4*qta*mdn**2*mta**2+4*p1p4**2*qta/mz**2*mdn**2*mta**2
     &   +2*p2p5*p3p5*qta/mz**2*mdn**2*mta**2)
     &   +iz1dn*iz4ta*betasprtata*chizpsc*chizsprc/ps/(s-mdn**2)*a1z**2/pi
     &   *alpha**3*qdn/s/spr*(s-spr)*(-8*p1p2*p1p4*p3p4*qta/mz**4*mdn**2*m
     &   ta**2+4*p1p2*p1p4*p3p5*qta/mz**4*mdn**2*mta**2+8*p1p2*p1p4*qta/mz
     &   **4*mdn**2*mta**4-4*p1p3*p1p4*qta/mz**2*mdn**2*mta**2+4*p1p4*p2p3
     &   *qta/mz**2*mdn**2*mta**2+4*p1p4*p2p4*qta/mz**2*mdn**2*mta**2+4*p1
     &   p4*p2p5*p3p4*qta/mz**4*mdn**2*mta**2-2*p1p4*p2p5*p3p5*qta/mz**4*m
     &   dn**2*mta**2-4*p1p4*p2p5*qta/mz**4*mdn**2*mta**4-2*p1p4*p2p5*qta/
     &   mz**2*mdn**2*mta**2-8*p1p4*p3p4*qta/mz**4*mdn**4*mta**2+2*p1p4*p3
     &   p4*qta*mdn**2+4*p1p4*p3p5*qta/mz**4*mdn**4*mta**2+2*p1p4*p3p5*qta
     &   /mz**2*mdn**2*mta**2-p1p4*p3p5*qta*mdn**2+8*p1p4*qta/mz**4*mdn**4
     &   *mta**4+4*p1p4*qta*mdn**2*mta**2-4*p1p4**2*qta/mz**2*mdn**2*mta**
     &   2-2*p2p5*p3p5*qta/mz**2*mdn**2*mta**2)
     &   +iz1dn*iz4ta*betasprtata*chizsprc/ps/(s-mdn**2)*a1z/pi*alpha**3*q
     &   dn**2/s/spr*(s-spr)*(p2p5*p3p5*qta**2/mz**2*mdn**2*mta**2)
     &   +iz1dn*iz4ta*betasprtata*chizsprc**2/ps/(s-mdn**2)*a1z**2/pi*alph
     &   a**3*qdn/s/spr*(s-spr)*(8*p1p2*p1p4*p3p4*qta/mz**4*mdn**2*mta**2-
     &   4*p1p2*p1p4*p3p5*qta/mz**4*mdn**2*mta**2-8*p1p2*p1p4*qta/mz**4*md
     &   n**2*mta**4+4*p1p3*p1p4*qta/mz**2*mdn**2*mta**2-4*p1p4*p2p3*qta/m
     &   z**2*mdn**2*mta**2-4*p1p4*p2p4*qta/mz**2*mdn**2*mta**2-4*p1p4*p2p
     &   5*p3p4*qta/mz**4*mdn**2*mta**2+2*p1p4*p2p5*p3p5*qta/mz**4*mdn**2*
     &   mta**2+4*p1p4*p2p5*qta/mz**4*mdn**2*mta**4+2*p1p4*p2p5*qta/mz**2*
     &   mdn**2*mta**2+8*p1p4*p3p4*qta/mz**4*mdn**4*mta**2-2*p1p4*p3p4*qta
     &   *mdn**2-4*p1p4*p3p5*qta/mz**4*mdn**4*mta**2-2*p1p4*p3p5*qta/mz**2
     &   *mdn**2*mta**2+p1p4*p3p5*qta*mdn**2-8*p1p4*qta/mz**4*mdn**4*mta**
     &   4-4*p1p4*qta*mdn**2*mta**2+4*p1p4**2*qta/mz**2*mdn**2*mta**2+2*p2
     &   p5*p3p5*qta/mz**2*mdn**2*mta**2)
     &   +iz1dn*betasprtata*chizps*chizsprc/ps/(s-mdn**2)/pi*alpha**3*qdn/
     &   s/spr*(s-spr)*(1d0/2*p1p3*adn**2*qta*vta**2*mdn**2-1d0/2*p1p4*adn
     &   **2*qta*vta**2*mdn**2+1d0/2*p3p5*adn**2*qta*vta**2*mdn**2-1d0/2*p
     &   4p5*adn**2*qta*vta**2*mdn**2)
     &   +iz1dn*betasprtata*chizspr/ps/(s-mdn**2)*a1z/pi*alpha**3*qdn**2/s
     &   /spr*(s-spr)*(-p2p5*qta**2/mz**2*mdn**2*mta**2)
     &   +iz1dn*betasprtata*chizspr*chizpsc/ps/(s-mdn**2)/pi*alpha**3*qdn/
     &   s/spr*(s-spr)*(1d0/2*p1p3*adn**2*qta*vta**2*mdn**2-1d0/2*p1p4*adn
     &   **2*qta*vta**2*mdn**2+1d0/2*p3p5*adn**2*qta*vta**2*mdn**2-1d0/2*p
     &   4p5*adn**2*qta*vta**2*mdn**2)
     &   +iz1dn*betasprtata*chizspr*chizpsc/ps/(s-mdn**2)*a1z**2/pi*alpha*
     &   *3*qdn/s/spr*(s-spr)*(-2*p1p2*p1p3*qta/mz**4*mdn**2*mta**2+2*p1p2
     &   *p1p4*qta/mz**4*mdn**2*mta**2+p1p3*p2p5*qta/mz**4*mdn**2*mta**2-2
     &   *p1p3*qta/mz**4*mdn**4*mta**2-p1p3*qta/mz**2*mdn**2*mta**2+1d0/2*
     &   p1p3*qta*mdn**2-p1p4*p2p5*qta/mz**4*mdn**2*mta**2+2*p1p4*qta/mz**
     &   4*mdn**4*mta**2+p1p4*qta/mz**2*mdn**2*mta**2-1d0/2*p1p4*qta*mdn**
     &   2+1d0/2*p3p5*qta*mdn**2-1d0/2*p4p5*qta*mdn**2)
     &   +iz1dn*betasprtata*chizspr*chizsprc/ps/(s-mdn**2)*a1z**2/pi*alpha
     &   **3*qdn/s/spr*(s-spr)*(-2*p1p2*p1p3*qta/mz**4*mdn**2*mta**2+2*p1p
     &   2*p1p4*qta/mz**4*mdn**2*mta**2+p1p3*p2p5*qta/mz**4*mdn**2*mta**2-
     &   2*p1p3*qta/mz**4*mdn**4*mta**2-p1p3*qta/mz**2*mdn**2*mta**2+1d0/2
     &   *p1p3*qta*mdn**2-p1p4*p2p5*qta/mz**4*mdn**2*mta**2+2*p1p4*qta/mz*
     &   *4*mdn**4*mta**2+p1p4*qta/mz**2*mdn**2*mta**2-1d0/2*p1p4*qta*mdn*
     &   *2+1d0/2*p3p5*qta*mdn**2-1d0/2*p4p5*qta*mdn**2)
     &   +iz1dn*betasprtata*chizspr*chizsprc/(s-mdn**2)*a1z**2/pi*alpha**3
     &   *qdn**2/s/spr**2*(s-spr)*(-4/mz**4*mdn**4*mta**4-8*p1p2*p3p4/mz**
     &   4*mdn**2*mta**2+8*p1p2/mz**4*mdn**2*mta**4+4*p2p5*p3p4/mz**4*mdn*
     &   *2*mta**2-4*p2p5/mz**4*mdn**2*mta**4+4*p3p4/mz**4*mdn**4*mta**2+4
     &   *p3p5/mz**2*mdn**2*mta**2+4*p4p5/mz**2*mdn**2*mta**2)
     &   +iz1dn*betasprtata*chizpsc*chizsprc/ps/(s-mdn**2)*a1z**2/pi*alpha
     &   **3*qdn/s/spr*(s-spr)*(2*p1p2*p1p3*qta/mz**4*mdn**2*mta**2-2*p1p2
     &   *p1p4*qta/mz**4*mdn**2*mta**2-p1p3*p2p5*qta/mz**4*mdn**2*mta**2+2
     &   *p1p3*qta/mz**4*mdn**4*mta**2+p1p3*qta/mz**2*mdn**2*mta**2-1d0/2*
     &   p1p3*qta*mdn**2+p1p4*p2p5*qta/mz**4*mdn**2*mta**2-2*p1p4*qta/mz**
     &   4*mdn**4*mta**2-p1p4*qta/mz**2*mdn**2*mta**2+1d0/2*p1p4*qta*mdn**
     &   2-1d0/2*p3p5*qta*mdn**2+1d0/2*p4p5*qta*mdn**2)
     &   +iz1dn*betasprtata*chizsprc/ps/(s-mdn**2)*a1z/pi*alpha**3*qdn**2/
     &   s/spr*(s-spr)*(-p2p5*qta**2/mz**2*mdn**2*mta**2)
     &   +iz1dn*betasprtata*chizsprc**2/ps/(s-mdn**2)*a1z**2/pi*alpha**3*q
     &   dn/s/spr*(s-spr)*(-2*p1p2*p1p3*qta/mz**4*mdn**2*mta**2+2*p1p2*p1p
     &   4*qta/mz**4*mdn**2*mta**2+p1p3*p2p5*qta/mz**4*mdn**2*mta**2-2*p1p
     &   3*qta/mz**4*mdn**4*mta**2-p1p3*qta/mz**2*mdn**2*mta**2+1d0/2*p1p3
     &   *qta*mdn**2-p1p4*p2p5*qta/mz**4*mdn**2*mta**2+2*p1p4*qta/mz**4*md
     &   n**4*mta**2+p1p4*qta/mz**2*mdn**2*mta**2-1d0/2*p1p4*qta*mdn**2+1d
     &   0/2*p3p5*qta*mdn**2-1d0/2*p4p5*qta*mdn**2)
     &   +iz2dn**2*betasprtata*chizspr*chizsprc/(s-mdn**2)/pi*alpha**3*qdn
     &   **2/s/spr**2*(s-spr)*(-4*adn**2*vta**2*mdn**4*mta**2+2*p3p4*adn**
     &   2*vta**2*mdn**4)
     &   +iz2dn**2*betasprtata*chizspr*chizsprc/(s-mdn**2)*a1z**2/pi*alpha
     &   **3*qdn**2/s/spr**2*(s-spr)*(8/mz**4*mdn**6*mta**4+4*mdn**4*mta**
     &   2-8*p1p2*p3p4/mz**4*mdn**4*mta**2+8*p1p2/mz**4*mdn**4*mta**4-4*p1
     &   p3/mz**2*mdn**4*mta**2-4*p1p4/mz**2*mdn**4*mta**2-8*p1p5*p3p4/mz*
     &   *4*mdn**4*mta**2+8*p1p5/mz**4*mdn**4*mta**4+4*p2p3/mz**2*mdn**4*m
     &   ta**2+4*p2p4/mz**2*mdn**4*mta**2-8*p3p4/mz**4*mdn**6*mta**2+2*p3p
     &   4*mdn**4+4*p3p5/mz**2*mdn**4*mta**2+4*p4p5/mz**2*mdn**4*mta**2)
     &   +iz2dn*iz3ta*betasprtata*chizps*chizsprc/ps/(s-mdn**2)/pi*alpha**
     &   3*qdn/s/spr*(s-spr)*(-2*p2p3*p3p4*adn**2*qta*vta**2*mdn**2+p2p3*p
     &   4p5*adn**2*qta*vta**2*mdn**2+4*p2p3*adn**2*qta*vta**2*mdn**2*mta*
     &   *2)
     &   +iz2dn*iz3ta*betasprtata*chizspr/ps/(s-mdn**2)*a1z/pi*alpha**3*qd
     &   n**2/s/spr*(s-spr)*(p1p5*p4p5*qta**2/mz**2*mdn**2*mta**2)
     &   +iz2dn*iz3ta*betasprtata*chizspr*chizpsc/ps/(s-mdn**2)/pi*alpha**
     &   3*qdn/s/spr*(s-spr)*(-2*p2p3*p3p4*adn**2*qta*vta**2*mdn**2+p2p3*p
     &   4p5*adn**2*qta*vta**2*mdn**2+4*p2p3*adn**2*qta*vta**2*mdn**2*mta*
     &   *2)
     &   +iz2dn*iz3ta*betasprtata*chizspr*chizpsc/ps/(s-mdn**2)*a1z**2/pi*
     &   alpha**3*qdn/s/spr*(s-spr)*(8*p1p2*p2p3*p3p4*qta/mz**4*mdn**2*mta
     &   **2-4*p1p2*p2p3*p4p5*qta/mz**4*mdn**2*mta**2-8*p1p2*p2p3*qta/mz**
     &   4*mdn**2*mta**4+4*p1p3*p2p3*qta/mz**2*mdn**2*mta**2+4*p1p4*p2p3*q
     &   ta/mz**2*mdn**2*mta**2+4*p1p5*p2p3*p3p4*qta/mz**4*mdn**2*mta**2-2
     &   *p1p5*p2p3*p4p5*qta/mz**4*mdn**2*mta**2-4*p1p5*p2p3*qta/mz**4*mdn
     &   **2*mta**4-2*p1p5*p2p3*qta/mz**2*mdn**2*mta**2+2*p1p5*p4p5*qta/mz
     &   **2*mdn**2*mta**2-4*p2p3*p2p4*qta/mz**2*mdn**2*mta**2+8*p2p3*p3p4
     &   *qta/mz**4*mdn**4*mta**2-2*p2p3*p3p4*qta*mdn**2-4*p2p3*p4p5*qta/m
     &   z**4*mdn**4*mta**2-2*p2p3*p4p5*qta/mz**2*mdn**2*mta**2+p2p3*p4p5*
     &   qta*mdn**2-8*p2p3*qta/mz**4*mdn**4*mta**4-4*p2p3*qta*mdn**2*mta**
     &   2-4*p2p3**2*qta/mz**2*mdn**2*mta**2)
     &   +iz2dn*iz3ta*betasprtata*chizspr*chizsprc/ps/(s-mdn**2)*a1z**2/pi
     &   *alpha**3*qdn/s/spr*(s-spr)*(8*p1p2*p2p3*p3p4*qta/mz**4*mdn**2*mt
     &   a**2-4*p1p2*p2p3*p4p5*qta/mz**4*mdn**2*mta**2-8*p1p2*p2p3*qta/mz*
     &   *4*mdn**2*mta**4+4*p1p3*p2p3*qta/mz**2*mdn**2*mta**2+4*p1p4*p2p3*
     &   qta/mz**2*mdn**2*mta**2+4*p1p5*p2p3*p3p4*qta/mz**4*mdn**2*mta**2-
     &   2*p1p5*p2p3*p4p5*qta/mz**4*mdn**2*mta**2-4*p1p5*p2p3*qta/mz**4*md
     &   n**2*mta**4-2*p1p5*p2p3*qta/mz**2*mdn**2*mta**2+2*p1p5*p4p5*qta/m
     &   z**2*mdn**2*mta**2-4*p2p3*p2p4*qta/mz**2*mdn**2*mta**2+8*p2p3*p3p
     &   4*qta/mz**4*mdn**4*mta**2-2*p2p3*p3p4*qta*mdn**2-4*p2p3*p4p5*qta/
     &   mz**4*mdn**4*mta**2-2*p2p3*p4p5*qta/mz**2*mdn**2*mta**2+p2p3*p4p5
     &   *qta*mdn**2-8*p2p3*qta/mz**4*mdn**4*mta**4-4*p2p3*qta*mdn**2*mta*
     &   *2-4*p2p3**2*qta/mz**2*mdn**2*mta**2)
     &   +iz2dn*iz3ta*betasprtata*chizpsc*chizsprc/ps/(s-mdn**2)*a1z**2/pi
     &   *alpha**3*qdn/s/spr*(s-spr)*(-8*p1p2*p2p3*p3p4*qta/mz**4*mdn**2*m
     &   ta**2+4*p1p2*p2p3*p4p5*qta/mz**4*mdn**2*mta**2+8*p1p2*p2p3*qta/mz
     &   **4*mdn**2*mta**4-4*p1p3*p2p3*qta/mz**2*mdn**2*mta**2-4*p1p4*p2p3
     &   *qta/mz**2*mdn**2*mta**2-4*p1p5*p2p3*p3p4*qta/mz**4*mdn**2*mta**2
     &   +2*p1p5*p2p3*p4p5*qta/mz**4*mdn**2*mta**2+4*p1p5*p2p3*qta/mz**4*m
     &   dn**2*mta**4+2*p1p5*p2p3*qta/mz**2*mdn**2*mta**2-2*p1p5*p4p5*qta/
     &   mz**2*mdn**2*mta**2+4*p2p3*p2p4*qta/mz**2*mdn**2*mta**2-8*p2p3*p3
     &   p4*qta/mz**4*mdn**4*mta**2+2*p2p3*p3p4*qta*mdn**2+4*p2p3*p4p5*qta
     &   /mz**4*mdn**4*mta**2+2*p2p3*p4p5*qta/mz**2*mdn**2*mta**2-p2p3*p4p
     &   5*qta*mdn**2+8*p2p3*qta/mz**4*mdn**4*mta**4+4*p2p3*qta*mdn**2*mta
     &   **2+4*p2p3**2*qta/mz**2*mdn**2*mta**2)
     &   +iz2dn*iz3ta*betasprtata*chizsprc/ps/(s-mdn**2)*a1z/pi*alpha**3*q
     &   dn**2/s/spr*(s-spr)*(p1p5*p4p5*qta**2/mz**2*mdn**2*mta**2)
     &   +iz2dn*iz3ta*betasprtata*chizsprc**2/ps/(s-mdn**2)*a1z**2/pi*alph
     &   a**3*qdn/s/spr*(s-spr)*(8*p1p2*p2p3*p3p4*qta/mz**4*mdn**2*mta**2-
     &   4*p1p2*p2p3*p4p5*qta/mz**4*mdn**2*mta**2-8*p1p2*p2p3*qta/mz**4*md
     &   n**2*mta**4+4*p1p3*p2p3*qta/mz**2*mdn**2*mta**2+4*p1p4*p2p3*qta/m
     &   z**2*mdn**2*mta**2+4*p1p5*p2p3*p3p4*qta/mz**4*mdn**2*mta**2-2*p1p
     &   5*p2p3*p4p5*qta/mz**4*mdn**2*mta**2-4*p1p5*p2p3*qta/mz**4*mdn**2*
     &   mta**4-2*p1p5*p2p3*qta/mz**2*mdn**2*mta**2+2*p1p5*p4p5*qta/mz**2*
     &   mdn**2*mta**2-4*p2p3*p2p4*qta/mz**2*mdn**2*mta**2+8*p2p3*p3p4*qta
     &   /mz**4*mdn**4*mta**2-2*p2p3*p3p4*qta*mdn**2-4*p2p3*p4p5*qta/mz**4
     &   *mdn**4*mta**2-2*p2p3*p4p5*qta/mz**2*mdn**2*mta**2+p2p3*p4p5*qta*
     &   mdn**2-8*p2p3*qta/mz**4*mdn**4*mta**4-4*p2p3*qta*mdn**2*mta**2-4*
     &   p2p3**2*qta/mz**2*mdn**2*mta**2)
     &   +iz2dn*iz4ta*betasprtata*chizps*chizsprc/ps/(s-mdn**2)/pi*alpha**
     &   3*qdn/s/spr*(s-spr)*(2*p2p4*p3p4*adn**2*qta*vta**2*mdn**2-p2p4*p3
     &   p5*adn**2*qta*vta**2*mdn**2-4*p2p4*adn**2*qta*vta**2*mdn**2*mta**
     &   2)
     &   +iz2dn*iz4ta*betasprtata*chizspr/ps/(s-mdn**2)*a1z/pi*alpha**3*qd
     &   n**2/s/spr*(s-spr)*(p1p5*p3p5*qta**2/mz**2*mdn**2*mta**2)
     &   +iz2dn*iz4ta*betasprtata*chizspr*chizpsc/ps/(s-mdn**2)/pi*alpha**
     &   3*qdn/s/spr*(s-spr)*(2*p2p4*p3p4*adn**2*qta*vta**2*mdn**2-p2p4*p3
     &   p5*adn**2*qta*vta**2*mdn**2-4*p2p4*adn**2*qta*vta**2*mdn**2*mta**
     &   2)
     &   +iz2dn*iz4ta*betasprtata*chizspr*chizpsc/ps/(s-mdn**2)*a1z**2/pi*
     &   alpha**3*qdn/s/spr*(s-spr)*(-8*p1p2*p2p4*p3p4*qta/mz**4*mdn**2*mt
     &   a**2+4*p1p2*p2p4*p3p5*qta/mz**4*mdn**2*mta**2+8*p1p2*p2p4*qta/mz*
     &   *4*mdn**2*mta**4-4*p1p3*p2p4*qta/mz**2*mdn**2*mta**2-4*p1p4*p2p4*
     &   qta/mz**2*mdn**2*mta**2-4*p1p5*p2p4*p3p4*qta/mz**4*mdn**2*mta**2+
     &   2*p1p5*p2p4*p3p5*qta/mz**4*mdn**2*mta**2+4*p1p5*p2p4*qta/mz**4*md
     &   n**2*mta**4+2*p1p5*p2p4*qta/mz**2*mdn**2*mta**2-2*p1p5*p3p5*qta/m
     &   z**2*mdn**2*mta**2+4*p2p3*p2p4*qta/mz**2*mdn**2*mta**2-8*p2p4*p3p
     &   4*qta/mz**4*mdn**4*mta**2+2*p2p4*p3p4*qta*mdn**2+4*p2p4*p3p5*qta/
     &   mz**4*mdn**4*mta**2+2*p2p4*p3p5*qta/mz**2*mdn**2*mta**2-p2p4*p3p5
     &   *qta*mdn**2+8*p2p4*qta/mz**4*mdn**4*mta**4+4*p2p4*qta*mdn**2*mta*
     &   *2+4*p2p4**2*qta/mz**2*mdn**2*mta**2)
     &   +iz2dn*iz4ta*betasprtata*chizspr*chizsprc/ps/(s-mdn**2)*a1z**2/pi
     &   *alpha**3*qdn/s/spr*(s-spr)*(-8*p1p2*p2p4*p3p4*qta/mz**4*mdn**2*m
     &   ta**2+4*p1p2*p2p4*p3p5*qta/mz**4*mdn**2*mta**2+8*p1p2*p2p4*qta/mz
     &   **4*mdn**2*mta**4-4*p1p3*p2p4*qta/mz**2*mdn**2*mta**2-4*p1p4*p2p4
     &   *qta/mz**2*mdn**2*mta**2-4*p1p5*p2p4*p3p4*qta/mz**4*mdn**2*mta**2
     &   +2*p1p5*p2p4*p3p5*qta/mz**4*mdn**2*mta**2+4*p1p5*p2p4*qta/mz**4*m
     &   dn**2*mta**4+2*p1p5*p2p4*qta/mz**2*mdn**2*mta**2-2*p1p5*p3p5*qta/
     &   mz**2*mdn**2*mta**2+4*p2p3*p2p4*qta/mz**2*mdn**2*mta**2-8*p2p4*p3
     &   p4*qta/mz**4*mdn**4*mta**2+2*p2p4*p3p4*qta*mdn**2+4*p2p4*p3p5*qta
     &   /mz**4*mdn**4*mta**2+2*p2p4*p3p5*qta/mz**2*mdn**2*mta**2-p2p4*p3p
     &   5*qta*mdn**2+8*p2p4*qta/mz**4*mdn**4*mta**4+4*p2p4*qta*mdn**2*mta
     &   **2+4*p2p4**2*qta/mz**2*mdn**2*mta**2)
     &   +iz2dn*iz4ta*betasprtata*chizpsc*chizsprc/ps/(s-mdn**2)*a1z**2/pi
     &   *alpha**3*qdn/s/spr*(s-spr)*(8*p1p2*p2p4*p3p4*qta/mz**4*mdn**2*mt
     &   a**2-4*p1p2*p2p4*p3p5*qta/mz**4*mdn**2*mta**2-8*p1p2*p2p4*qta/mz*
     &   *4*mdn**2*mta**4+4*p1p3*p2p4*qta/mz**2*mdn**2*mta**2+4*p1p4*p2p4*
     &   qta/mz**2*mdn**2*mta**2+4*p1p5*p2p4*p3p4*qta/mz**4*mdn**2*mta**2-
     &   2*p1p5*p2p4*p3p5*qta/mz**4*mdn**2*mta**2-4*p1p5*p2p4*qta/mz**4*md
     &   n**2*mta**4-2*p1p5*p2p4*qta/mz**2*mdn**2*mta**2+2*p1p5*p3p5*qta/m
     &   z**2*mdn**2*mta**2-4*p2p3*p2p4*qta/mz**2*mdn**2*mta**2+8*p2p4*p3p
     &   4*qta/mz**4*mdn**4*mta**2-2*p2p4*p3p4*qta*mdn**2-4*p2p4*p3p5*qta/
     &   mz**4*mdn**4*mta**2-2*p2p4*p3p5*qta/mz**2*mdn**2*mta**2+p2p4*p3p5
     &   *qta*mdn**2-8*p2p4*qta/mz**4*mdn**4*mta**4-4*p2p4*qta*mdn**2*mta*
     &   *2-4*p2p4**2*qta/mz**2*mdn**2*mta**2)
     &   +iz2dn*iz4ta*betasprtata*chizsprc/ps/(s-mdn**2)*a1z/pi*alpha**3*q
     &   dn**2/s/spr*(s-spr)*(p1p5*p3p5*qta**2/mz**2*mdn**2*mta**2)
     &   +iz2dn*iz4ta*betasprtata*chizsprc**2/ps/(s-mdn**2)*a1z**2/pi*alph
     &   a**3*qdn/s/spr*(s-spr)*(-8*p1p2*p2p4*p3p4*qta/mz**4*mdn**2*mta**2
     &   +4*p1p2*p2p4*p3p5*qta/mz**4*mdn**2*mta**2+8*p1p2*p2p4*qta/mz**4*m
     &   dn**2*mta**4-4*p1p3*p2p4*qta/mz**2*mdn**2*mta**2-4*p1p4*p2p4*qta/
     &   mz**2*mdn**2*mta**2-4*p1p5*p2p4*p3p4*qta/mz**4*mdn**2*mta**2+2*p1
     &   p5*p2p4*p3p5*qta/mz**4*mdn**2*mta**2+4*p1p5*p2p4*qta/mz**4*mdn**2
     &   *mta**4+2*p1p5*p2p4*qta/mz**2*mdn**2*mta**2-2*p1p5*p3p5*qta/mz**2
     &   *mdn**2*mta**2+4*p2p3*p2p4*qta/mz**2*mdn**2*mta**2-8*p2p4*p3p4*qt
     &   a/mz**4*mdn**4*mta**2+2*p2p4*p3p4*qta*mdn**2+4*p2p4*p3p5*qta/mz**
     &   4*mdn**4*mta**2+2*p2p4*p3p5*qta/mz**2*mdn**2*mta**2-p2p4*p3p5*qta
     &   *mdn**2+8*p2p4*qta/mz**4*mdn**4*mta**4+4*p2p4*qta*mdn**2*mta**2+4
     &   *p2p4**2*qta/mz**2*mdn**2*mta**2)
     &   +iz2dn*betasprtata*chizps*chizsprc/ps/(s-mdn**2)/pi*alpha**3*qdn/
     &   s/spr*(s-spr)*(-1d0/2*p2p3*adn**2*qta*vta**2*mdn**2+1d0/2*p2p4*ad
     &   n**2*qta*vta**2*mdn**2+1d0/2*p3p5*adn**2*qta*vta**2*mdn**2-1d0/2*
     &   p4p5*adn**2*qta*vta**2*mdn**2)
     &   +iz2dn*betasprtata*chizspr/ps/(s-mdn**2)*a1z/pi*alpha**3*qdn**2/s
     &   /spr*(s-spr)*(-p1p5*qta**2/mz**2*mdn**2*mta**2)
     &   +iz2dn*betasprtata*chizspr*chizpsc/ps/(s-mdn**2)/pi*alpha**3*qdn/
     &   s/spr*(s-spr)*(-1d0/2*p2p3*adn**2*qta*vta**2*mdn**2+1d0/2*p2p4*ad
     &   n**2*qta*vta**2*mdn**2+1d0/2*p3p5*adn**2*qta*vta**2*mdn**2-1d0/2*
     &   p4p5*adn**2*qta*vta**2*mdn**2)
     &   +iz2dn*betasprtata*chizspr*chizpsc/ps/(s-mdn**2)*a1z**2/pi*alpha*
     &   *3*qdn/s/spr*(s-spr)*(2*p1p2*p2p3*qta/mz**4*mdn**2*mta**2-2*p1p2*
     &   p2p4*qta/mz**4*mdn**2*mta**2+p1p5*p2p3*qta/mz**4*mdn**2*mta**2-p1
     &   p5*p2p4*qta/mz**4*mdn**2*mta**2+2*p2p3*qta/mz**4*mdn**4*mta**2+p2
     &   p3*qta/mz**2*mdn**2*mta**2-1d0/2*p2p3*qta*mdn**2-2*p2p4*qta/mz**4
     &   *mdn**4*mta**2-p2p4*qta/mz**2*mdn**2*mta**2+1d0/2*p2p4*qta*mdn**2
     &   +1d0/2*p3p5*qta*mdn**2-1d0/2*p4p5*qta*mdn**2)
     &   +iz2dn*betasprtata*chizspr*chizsprc/ps/(s-mdn**2)*a1z**2/pi*alpha
     &   **3*qdn/s/spr*(s-spr)*(2*p1p2*p2p3*qta/mz**4*mdn**2*mta**2-2*p1p2
     &   *p2p4*qta/mz**4*mdn**2*mta**2+p1p5*p2p3*qta/mz**4*mdn**2*mta**2-p
     &   1p5*p2p4*qta/mz**4*mdn**2*mta**2+2*p2p3*qta/mz**4*mdn**4*mta**2+p
     &   2p3*qta/mz**2*mdn**2*mta**2-1d0/2*p2p3*qta*mdn**2-2*p2p4*qta/mz**
     &   4*mdn**4*mta**2-p2p4*qta/mz**2*mdn**2*mta**2+1d0/2*p2p4*qta*mdn**
     &   2+1d0/2*p3p5*qta*mdn**2-1d0/2*p4p5*qta*mdn**2)
     &   +iz2dn*betasprtata*chizspr*chizsprc/(s-mdn**2)*a1z**2/pi*alpha**3
     &   *qdn**2/s/spr**2*(s-spr)*(4/mz**4*mdn**4*mta**4+8*p1p2*p3p4/mz**4
     &   *mdn**2*mta**2-8*p1p2/mz**4*mdn**2*mta**4+4*p1p5*p3p4/mz**4*mdn**
     &   2*mta**2-4*p1p5/mz**4*mdn**2*mta**4-4*p3p4/mz**4*mdn**4*mta**2-4*
     &   p3p5/mz**2*mdn**2*mta**2-4*p4p5/mz**2*mdn**2*mta**2)
     &   +iz2dn*betasprtata*chizpsc*chizsprc/ps/(s-mdn**2)*a1z**2/pi*alpha
     &   **3*qdn/s/spr*(s-spr)*(-2*p1p2*p2p3*qta/mz**4*mdn**2*mta**2+2*p1p
     &   2*p2p4*qta/mz**4*mdn**2*mta**2-p1p5*p2p3*qta/mz**4*mdn**2*mta**2+
     &   p1p5*p2p4*qta/mz**4*mdn**2*mta**2-2*p2p3*qta/mz**4*mdn**4*mta**2-
     &   p2p3*qta/mz**2*mdn**2*mta**2+1d0/2*p2p3*qta*mdn**2+2*p2p4*qta/mz*
     &   *4*mdn**4*mta**2+p2p4*qta/mz**2*mdn**2*mta**2-1d0/2*p2p4*qta*mdn*
     &   *2-1d0/2*p3p5*qta*mdn**2+1d0/2*p4p5*qta*mdn**2)
     &   +iz2dn*betasprtata*chizsprc/ps/(s-mdn**2)*a1z/pi*alpha**3*qdn**2/
     &   s/spr*(s-spr)*(-p1p5*qta**2/mz**2*mdn**2*mta**2)
     &   +iz2dn*betasprtata*chizsprc**2/ps/(s-mdn**2)*a1z**2/pi*alpha**3*q
     &   dn/s/spr*(s-spr)*(2*p1p2*p2p3*qta/mz**4*mdn**2*mta**2-2*p1p2*p2p4
     &   *qta/mz**4*mdn**2*mta**2+p1p5*p2p3*qta/mz**4*mdn**2*mta**2-p1p5*p
     &   2p4*qta/mz**4*mdn**2*mta**2+2*p2p3*qta/mz**4*mdn**4*mta**2+p2p3*q
     &   ta/mz**2*mdn**2*mta**2-1d0/2*p2p3*qta*mdn**2-2*p2p4*qta/mz**4*mdn
     &   **4*mta**2-p2p4*qta/mz**2*mdn**2*mta**2+1d0/2*p2p4*qta*mdn**2+1d0
     &   /2*p3p5*qta*mdn**2-1d0/2*p4p5*qta*mdn**2)
     &   +iz3ta**2*betasprtata*chizps*chizpsc/ps**2/(s-mdn**2)/pi*alpha**3
     &   /s*(s-spr)*(-4*adn**2*qta**2*vta**2*mdn**2*mta**4+2*p3p4*adn**2*q
     &   ta**2*vta**2*mdn**2*mta**2-2*p4p5*adn**2*qta**2*vta**2*mdn**2*mta
     &   **2)
     &   +iz3ta**2*betasprtata*chizspr*chizpsc/ps**2/(s-mdn**2)*a1z**2/pi*
     &   alpha**3/s*(s-spr)*(8*qta**2/mz**4*mdn**4*mta**6+4*qta**2*mdn**2*
     &   mta**4-8*p1p2*p3p4*qta**2/mz**4*mdn**2*mta**4+8*p1p2*p4p5*qta**2/
     &   mz**4*mdn**2*mta**4+8*p1p2*qta**2/mz**4*mdn**2*mta**6-4*p1p3*qta*
     &   *2/mz**2*mdn**2*mta**4-4*p1p4*qta**2/mz**2*mdn**2*mta**4+4*p1p5*q
     &   ta**2/mz**2*mdn**2*mta**4+4*p2p3*qta**2/mz**2*mdn**2*mta**4+4*p2p
     &   4*qta**2/mz**2*mdn**2*mta**4-4*p2p5*qta**2/mz**2*mdn**2*mta**4-8*
     &   p3p4*qta**2/mz**4*mdn**4*mta**4+2*p3p4*qta**2*mdn**2*mta**2+8*p4p
     &   5*qta**2/mz**4*mdn**4*mta**4-2*p4p5*qta**2*mdn**2*mta**2)
     &   +iz3ta**2*betasprtata*chizpsc**2/ps**2/(s-mdn**2)*a1z**2/pi*alpha
     &   **3/s*(s-spr)*(-8*qta**2/mz**4*mdn**4*mta**6-4*qta**2*mdn**2*mta*
     &   *4+8*p1p2*p3p4*qta**2/mz**4*mdn**2*mta**4-8*p1p2*p4p5*qta**2/mz**
     &   4*mdn**2*mta**4-8*p1p2*qta**2/mz**4*mdn**2*mta**6+4*p1p3*qta**2/m
     &   z**2*mdn**2*mta**4+4*p1p4*qta**2/mz**2*mdn**2*mta**4-4*p1p5*qta**
     &   2/mz**2*mdn**2*mta**4-4*p2p3*qta**2/mz**2*mdn**2*mta**4-4*p2p4*qt
     &   a**2/mz**2*mdn**2*mta**4+4*p2p5*qta**2/mz**2*mdn**2*mta**4+8*p3p4
     &   *qta**2/mz**4*mdn**4*mta**4-2*p3p4*qta**2*mdn**2*mta**2-8*p4p5*qt
     &   a**2/mz**4*mdn**4*mta**4+2*p4p5*qta**2*mdn**2*mta**2)
     &   +iz3ta**2*betasprtata*chizpsc*chizsprc/ps**2/(s-mdn**2)*a1z**2/pi
     &   *alpha**3/s*(s-spr)*(8*qta**2/mz**4*mdn**4*mta**6+4*qta**2*mdn**2
     &   *mta**4-8*p1p2*p3p4*qta**2/mz**4*mdn**2*mta**4+8*p1p2*p4p5*qta**2
     &   /mz**4*mdn**2*mta**4+8*p1p2*qta**2/mz**4*mdn**2*mta**6-4*p1p3*qta
     &   **2/mz**2*mdn**2*mta**4-4*p1p4*qta**2/mz**2*mdn**2*mta**4+4*p1p5*
     &   qta**2/mz**2*mdn**2*mta**4+4*p2p3*qta**2/mz**2*mdn**2*mta**4+4*p2
     &   p4*qta**2/mz**2*mdn**2*mta**4-4*p2p5*qta**2/mz**2*mdn**2*mta**4-8
     &   *p3p4*qta**2/mz**4*mdn**4*mta**4+2*p3p4*qta**2*mdn**2*mta**2+8*p4
     &   p5*qta**2/mz**4*mdn**4*mta**4-2*p4p5*qta**2*mdn**2*mta**2)
     &   +iz3ta*iz4ta*betasprtata*chizps*chizpsc/ps**2/(s-mdn**2)/pi*alpha
     &   **3/s*(s-spr)*(-8*p3p4*adn**2*qta**2*vta**2*mdn**2*mta**2+4*p3p4*
     &   *2*adn**2*qta**2*vta**2*mdn**2)
     &   +iz3ta*iz4ta*betasprtata*chizspr*chizpsc/ps**2/(s-mdn**2)*a1z**2/
     &   pi*alpha**3/s*(s-spr)*(16*p1p2*p3p4*qta**2/mz**4*mdn**2*mta**4-16
     &   *p1p2*p3p4**2*qta**2/mz**4*mdn**2*mta**2-8*p1p3*p3p4*qta**2/mz**2
     &   *mdn**2*mta**2-8*p1p4*p3p4*qta**2/mz**2*mdn**2*mta**2+8*p1p5*p3p4
     &   *qta**2/mz**2*mdn**2*mta**2+8*p2p3*p3p4*qta**2/mz**2*mdn**2*mta**
     &   2+8*p2p4*p3p4*qta**2/mz**2*mdn**2*mta**2-8*p2p5*p3p4*qta**2/mz**2
     &   *mdn**2*mta**2+16*p3p4*qta**2/mz**4*mdn**4*mta**4+8*p3p4*qta**2*m
     &   dn**2*mta**2-16*p3p4**2*qta**2/mz**4*mdn**4*mta**2+4*p3p4**2*qta*
     &   *2*mdn**2)
     &   +iz3ta*iz4ta*betasprtata*chizpsc**2/ps**2/(s-mdn**2)*a1z**2/pi*al
     &   pha**3/s*(s-spr)*(-16*p1p2*p3p4*qta**2/mz**4*mdn**2*mta**4+16*p1p
     &   2*p3p4**2*qta**2/mz**4*mdn**2*mta**2+8*p1p3*p3p4*qta**2/mz**2*mdn
     &   **2*mta**2+8*p1p4*p3p4*qta**2/mz**2*mdn**2*mta**2-8*p1p5*p3p4*qta
     &   **2/mz**2*mdn**2*mta**2-8*p2p3*p3p4*qta**2/mz**2*mdn**2*mta**2-8*
     &   p2p4*p3p4*qta**2/mz**2*mdn**2*mta**2+8*p2p5*p3p4*qta**2/mz**2*mdn
     &   **2*mta**2-16*p3p4*qta**2/mz**4*mdn**4*mta**4-8*p3p4*qta**2*mdn**
     &   2*mta**2+16*p3p4**2*qta**2/mz**4*mdn**4*mta**2-4*p3p4**2*qta**2*m
     &   dn**2)
     &   +iz3ta*iz4ta*betasprtata*chizpsc*chizsprc/ps**2/(s-mdn**2)*a1z**2
     &   /pi*alpha**3/s*(s-spr)*(16*p1p2*p3p4*qta**2/mz**4*mdn**2*mta**4-1
     &   6*p1p2*p3p4**2*qta**2/mz**4*mdn**2*mta**2-8*p1p3*p3p4*qta**2/mz**
     &   2*mdn**2*mta**2-8*p1p4*p3p4*qta**2/mz**2*mdn**2*mta**2+8*p1p5*p3p
     &   4*qta**2/mz**2*mdn**2*mta**2+8*p2p3*p3p4*qta**2/mz**2*mdn**2*mta*
     &   *2+8*p2p4*p3p4*qta**2/mz**2*mdn**2*mta**2-8*p2p5*p3p4*qta**2/mz**
     &   2*mdn**2*mta**2+16*p3p4*qta**2/mz**4*mdn**4*mta**4+8*p3p4*qta**2*
     &   mdn**2*mta**2-16*p3p4**2*qta**2/mz**4*mdn**4*mta**2+4*p3p4**2*qta
     &   **2*mdn**2)
     &   +iz3ta*betasprtata*chizps*chizpsc/ps**2/(s-mdn**2)/pi*alpha**3/s*
     &   (s-spr)*(adn**2*qta**2*vta**2*mdn**2*mta**2+2*p3p4*adn**2*qta**2*
     &   vta**2*mdn**2-p4p5*adn**2*qta**2*vta**2*mdn**2)
     &   +iz3ta*betasprtata*chizspr/ps/(s-mdn**2)*a1z/pi*alpha**3*qdn**2/s
     &   /spr*(s-spr)*(p4p5*qta**2/mz**2*mdn**2*mta**2)
     &   +iz3ta*betasprtata*chizspr*chizpsc/ps**2/(s-mdn**2)*a1z**2/pi*alp
     &   ha**3/s*(s-spr)*(-4*qta**2/mz**4*mdn**4*mta**4+qta**2*mdn**2*mta*
     &   *2-8*p1p2*p3p4*qta**2/mz**4*mdn**2*mta**2+4*p1p2*p4p5*qta**2/mz**
     &   4*mdn**2*mta**2-4*p1p2*qta**2/mz**4*mdn**2*mta**4+4*p1p5*qta**2/m
     &   z**2*mdn**2*mta**2-4*p2p5*qta**2/mz**2*mdn**2*mta**2-8*p3p4*qta**
     &   2/mz**4*mdn**4*mta**2+2*p3p4*qta**2*mdn**2+4*p4p5*qta**2/mz**4*md
     &   n**4*mta**2-p4p5*qta**2*mdn**2)
     &   +iz3ta*betasprtata*chizspr*chizpsc/ps/(s-mdn**2)*a1z**2/pi*alpha*
     &   *3*qdn/s/spr*(s-spr)*(2*p1p3*p3p4*qta/mz**4*mdn**2*mta**2-p1p3*p4
     &   p5*qta/mz**4*mdn**2*mta**2-2*p1p3*qta/mz**4*mdn**2*mta**4-p1p3*qt
     &   a/mz**2*mdn**2*mta**2+2*p2p3*p3p4*qta/mz**4*mdn**2*mta**2-p2p3*p4
     &   p5*qta/mz**4*mdn**2*mta**2-2*p2p3*qta/mz**4*mdn**2*mta**4-p2p3*qt
     &   a/mz**2*mdn**2*mta**2)
     &   +iz3ta*betasprtata*chizspr*chizsprc/ps/(s-mdn**2)*a1z**2/pi*alpha
     &   **3*qdn/s/spr*(s-spr)*(2*p1p3*p3p4*qta/mz**4*mdn**2*mta**2-p1p3*p
     &   4p5*qta/mz**4*mdn**2*mta**2-2*p1p3*qta/mz**4*mdn**2*mta**4-p1p3*q
     &   ta/mz**2*mdn**2*mta**2+2*p2p3*p3p4*qta/mz**4*mdn**2*mta**2-p2p3*p
     &   4p5*qta/mz**4*mdn**2*mta**2-2*p2p3*qta/mz**4*mdn**2*mta**4-p2p3*q
     &   ta/mz**2*mdn**2*mta**2)
     &   +iz3ta*betasprtata*chizpsc**2/ps**2/(s-mdn**2)*a1z**2/pi*alpha**3
     &   /s*(s-spr)*(4*qta**2/mz**4*mdn**4*mta**4-qta**2*mdn**2*mta**2+8*p
     &   1p2*p3p4*qta**2/mz**4*mdn**2*mta**2-4*p1p2*p4p5*qta**2/mz**4*mdn*
     &   *2*mta**2+4*p1p2*qta**2/mz**4*mdn**2*mta**4-4*p1p5*qta**2/mz**2*m
     &   dn**2*mta**2+4*p2p5*qta**2/mz**2*mdn**2*mta**2+8*p3p4*qta**2/mz**
     &   4*mdn**4*mta**2-2*p3p4*qta**2*mdn**2-4*p4p5*qta**2/mz**4*mdn**4*m
     &   ta**2+p4p5*qta**2*mdn**2)
     &   +iz3ta*betasprtata*chizpsc*chizsprc/ps**2/(s-mdn**2)*a1z**2/pi*al
     &   pha**3/s*(s-spr)*(-4*qta**2/mz**4*mdn**4*mta**4+qta**2*mdn**2*mta
     &   **2-8*p1p2*p3p4*qta**2/mz**4*mdn**2*mta**2+4*p1p2*p4p5*qta**2/mz*
     &   *4*mdn**2*mta**2-4*p1p2*qta**2/mz**4*mdn**2*mta**4+4*p1p5*qta**2/
     &   mz**2*mdn**2*mta**2-4*p2p5*qta**2/mz**2*mdn**2*mta**2-8*p3p4*qta*
     &   *2/mz**4*mdn**4*mta**2+2*p3p4*qta**2*mdn**2+4*p4p5*qta**2/mz**4*m
     &   dn**4*mta**2-p4p5*qta**2*mdn**2)
     &   +iz3ta*betasprtata*chizpsc*chizsprc/ps/(s-mdn**2)*a1z**2/pi*alpha
     &   **3*qdn/s/spr*(s-spr)*(-2*p1p3*p3p4*qta/mz**4*mdn**2*mta**2+p1p3*
     &   p4p5*qta/mz**4*mdn**2*mta**2+2*p1p3*qta/mz**4*mdn**2*mta**4+p1p3*
     &   qta/mz**2*mdn**2*mta**2-2*p2p3*p3p4*qta/mz**4*mdn**2*mta**2+p2p3*
     &   p4p5*qta/mz**4*mdn**2*mta**2+2*p2p3*qta/mz**4*mdn**2*mta**4+p2p3*
     &   qta/mz**2*mdn**2*mta**2)
     &   +iz3ta*betasprtata*chizsprc/ps/(s-mdn**2)*a1z/pi*alpha**3*qdn**2/
     &   s/spr*(s-spr)*(p4p5*qta**2/mz**2*mdn**2*mta**2)
     &   +iz3ta*betasprtata*chizsprc**2/ps/(s-mdn**2)*a1z**2/pi*alpha**3*q
     &   dn/s/spr*(s-spr)*(2*p1p3*p3p4*qta/mz**4*mdn**2*mta**2-p1p3*p4p5*q
     &   ta/mz**4*mdn**2*mta**2-2*p1p3*qta/mz**4*mdn**2*mta**4-p1p3*qta/mz
     &   **2*mdn**2*mta**2+2*p2p3*p3p4*qta/mz**4*mdn**2*mta**2-p2p3*p4p5*q
     &   ta/mz**4*mdn**2*mta**2-2*p2p3*qta/mz**4*mdn**2*mta**4-p2p3*qta/mz
     &   **2*mdn**2*mta**2)
     &   +iz4ta**2*betasprtata*chizps*chizpsc/ps**2/(s-mdn**2)/pi*alpha**3
     &   /s*(s-spr)*(-4*adn**2*qta**2*vta**2*mdn**2*mta**4+2*p3p4*adn**2*q
     &   ta**2*vta**2*mdn**2*mta**2-2*p3p5*adn**2*qta**2*vta**2*mdn**2*mta
     &   **2)
     &   +iz4ta**2*betasprtata*chizspr*chizpsc/ps**2/(s-mdn**2)*a1z**2/pi*
     &   alpha**3/s*(s-spr)*(8*qta**2/mz**4*mdn**4*mta**6+4*qta**2*mdn**2*
     &   mta**4-8*p1p2*p3p4*qta**2/mz**4*mdn**2*mta**4+8*p1p2*p3p5*qta**2/
     &   mz**4*mdn**2*mta**4+8*p1p2*qta**2/mz**4*mdn**2*mta**6-4*p1p3*qta*
     &   *2/mz**2*mdn**2*mta**4-4*p1p4*qta**2/mz**2*mdn**2*mta**4+4*p1p5*q
     &   ta**2/mz**2*mdn**2*mta**4+4*p2p3*qta**2/mz**2*mdn**2*mta**4+4*p2p
     &   4*qta**2/mz**2*mdn**2*mta**4-4*p2p5*qta**2/mz**2*mdn**2*mta**4-8*
     &   p3p4*qta**2/mz**4*mdn**4*mta**4+2*p3p4*qta**2*mdn**2*mta**2+8*p3p
     &   5*qta**2/mz**4*mdn**4*mta**4-2*p3p5*qta**2*mdn**2*mta**2)
     &   +iz4ta**2*betasprtata*chizpsc**2/ps**2/(s-mdn**2)*a1z**2/pi*alpha
     &   **3/s*(s-spr)*(-8*qta**2/mz**4*mdn**4*mta**6-4*qta**2*mdn**2*mta*
     &   *4+8*p1p2*p3p4*qta**2/mz**4*mdn**2*mta**4-8*p1p2*p3p5*qta**2/mz**
     &   4*mdn**2*mta**4-8*p1p2*qta**2/mz**4*mdn**2*mta**6+4*p1p3*qta**2/m
     &   z**2*mdn**2*mta**4+4*p1p4*qta**2/mz**2*mdn**2*mta**4-4*p1p5*qta**
     &   2/mz**2*mdn**2*mta**4-4*p2p3*qta**2/mz**2*mdn**2*mta**4-4*p2p4*qt
     &   a**2/mz**2*mdn**2*mta**4+4*p2p5*qta**2/mz**2*mdn**2*mta**4+8*p3p4
     &   *qta**2/mz**4*mdn**4*mta**4-2*p3p4*qta**2*mdn**2*mta**2-8*p3p5*qt
     &   a**2/mz**4*mdn**4*mta**4+2*p3p5*qta**2*mdn**2*mta**2)
     &   +iz4ta**2*betasprtata*chizpsc*chizsprc/ps**2/(s-mdn**2)*a1z**2/pi
     &   *alpha**3/s*(s-spr)*(8*qta**2/mz**4*mdn**4*mta**6+4*qta**2*mdn**2
     &   *mta**4-8*p1p2*p3p4*qta**2/mz**4*mdn**2*mta**4+8*p1p2*p3p5*qta**2
     &   /mz**4*mdn**2*mta**4+8*p1p2*qta**2/mz**4*mdn**2*mta**6-4*p1p3*qta
     &   **2/mz**2*mdn**2*mta**4-4*p1p4*qta**2/mz**2*mdn**2*mta**4+4*p1p5*
     &   qta**2/mz**2*mdn**2*mta**4+4*p2p3*qta**2/mz**2*mdn**2*mta**4+4*p2
     &   p4*qta**2/mz**2*mdn**2*mta**4-4*p2p5*qta**2/mz**2*mdn**2*mta**4-8
     &   *p3p4*qta**2/mz**4*mdn**4*mta**4+2*p3p4*qta**2*mdn**2*mta**2+8*p3
     &   p5*qta**2/mz**4*mdn**4*mta**4-2*p3p5*qta**2*mdn**2*mta**2)
     &   +iz4ta*betasprtata*chizps*chizpsc/ps**2/(s-mdn**2)/pi*alpha**3/s*
     &   (s-spr)*(adn**2*qta**2*vta**2*mdn**2*mta**2+2*p3p4*adn**2*qta**2*
     &   vta**2*mdn**2-p3p5*adn**2*qta**2*vta**2*mdn**2)
     &   +iz4ta*betasprtata*chizspr/ps/(s-mdn**2)*a1z/pi*alpha**3*qdn**2/s
     &   /spr*(s-spr)*(p3p5*qta**2/mz**2*mdn**2*mta**2)
     &   +iz4ta*betasprtata*chizspr*chizpsc/ps**2/(s-mdn**2)*a1z**2/pi*alp
     &   ha**3/s*(s-spr)*(-4*qta**2/mz**4*mdn**4*mta**4+qta**2*mdn**2*mta*
     &   *2-8*p1p2*p3p4*qta**2/mz**4*mdn**2*mta**2+4*p1p2*p3p5*qta**2/mz**
     &   4*mdn**2*mta**2-4*p1p2*qta**2/mz**4*mdn**2*mta**4+4*p1p5*qta**2/m
     &   z**2*mdn**2*mta**2-4*p2p5*qta**2/mz**2*mdn**2*mta**2-8*p3p4*qta**
     &   2/mz**4*mdn**4*mta**2+2*p3p4*qta**2*mdn**2+4*p3p5*qta**2/mz**4*md
     &   n**4*mta**2-p3p5*qta**2*mdn**2)
     &   +iz4ta*betasprtata*chizspr*chizpsc/ps/(s-mdn**2)*a1z**2/pi*alpha*
     &   *3*qdn/s/spr*(s-spr)*(-2*p1p4*p3p4*qta/mz**4*mdn**2*mta**2+p1p4*p
     &   3p5*qta/mz**4*mdn**2*mta**2+2*p1p4*qta/mz**4*mdn**2*mta**4+p1p4*q
     &   ta/mz**2*mdn**2*mta**2-2*p2p4*p3p4*qta/mz**4*mdn**2*mta**2+p2p4*p
     &   3p5*qta/mz**4*mdn**2*mta**2+2*p2p4*qta/mz**4*mdn**2*mta**4+p2p4*q
     &   ta/mz**2*mdn**2*mta**2)
     &   +iz4ta*betasprtata*chizspr*chizsprc/ps/(s-mdn**2)*a1z**2/pi*alpha
     &   **3*qdn/s/spr*(s-spr)*(-2*p1p4*p3p4*qta/mz**4*mdn**2*mta**2+p1p4*
     &   p3p5*qta/mz**4*mdn**2*mta**2+2*p1p4*qta/mz**4*mdn**2*mta**4+p1p4*
     &   qta/mz**2*mdn**2*mta**2-2*p2p4*p3p4*qta/mz**4*mdn**2*mta**2+p2p4*
     &   p3p5*qta/mz**4*mdn**2*mta**2+2*p2p4*qta/mz**4*mdn**2*mta**4+p2p4*
     &   qta/mz**2*mdn**2*mta**2)
     &   +iz4ta*betasprtata*chizpsc**2/ps**2/(s-mdn**2)*a1z**2/pi*alpha**3
     &   /s*(s-spr)*(4*qta**2/mz**4*mdn**4*mta**4-qta**2*mdn**2*mta**2+8*p
     &   1p2*p3p4*qta**2/mz**4*mdn**2*mta**2-4*p1p2*p3p5*qta**2/mz**4*mdn*
     &   *2*mta**2+4*p1p2*qta**2/mz**4*mdn**2*mta**4-4*p1p5*qta**2/mz**2*m
     &   dn**2*mta**2+4*p2p5*qta**2/mz**2*mdn**2*mta**2+8*p3p4*qta**2/mz**
     &   4*mdn**4*mta**2-2*p3p4*qta**2*mdn**2-4*p3p5*qta**2/mz**4*mdn**4*m
     &   ta**2+p3p5*qta**2*mdn**2)
     &   +iz4ta*betasprtata*chizpsc*chizsprc/ps**2/(s-mdn**2)*a1z**2/pi*al
     &   pha**3/s*(s-spr)*(-4*qta**2/mz**4*mdn**4*mta**4+qta**2*mdn**2*mta
     &   **2-8*p1p2*p3p4*qta**2/mz**4*mdn**2*mta**2+4*p1p2*p3p5*qta**2/mz*
     &   *4*mdn**2*mta**2-4*p1p2*qta**2/mz**4*mdn**2*mta**4+4*p1p5*qta**2/
     &   mz**2*mdn**2*mta**2-4*p2p5*qta**2/mz**2*mdn**2*mta**2-8*p3p4*qta*
     &   *2/mz**4*mdn**4*mta**2+2*p3p4*qta**2*mdn**2+4*p3p5*qta**2/mz**4*m
     &   dn**4*mta**2-p3p5*qta**2*mdn**2)
     &   +iz4ta*betasprtata*chizpsc*chizsprc/ps/(s-mdn**2)*a1z**2/pi*alpha
     &   **3*qdn/s/spr*(s-spr)*(2*p1p4*p3p4*qta/mz**4*mdn**2*mta**2-p1p4*p
     &   3p5*qta/mz**4*mdn**2*mta**2-2*p1p4*qta/mz**4*mdn**2*mta**4-p1p4*q
     &   ta/mz**2*mdn**2*mta**2+2*p2p4*p3p4*qta/mz**4*mdn**2*mta**2-p2p4*p
     &   3p5*qta/mz**4*mdn**2*mta**2-2*p2p4*qta/mz**4*mdn**2*mta**4-p2p4*q
     &   ta/mz**2*mdn**2*mta**2)
     &   +iz4ta*betasprtata*chizsprc/ps/(s-mdn**2)*a1z/pi*alpha**3*qdn**2/
     &   s/spr*(s-spr)*(p3p5*qta**2/mz**2*mdn**2*mta**2)
     &   +iz4ta*betasprtata*chizsprc**2/ps/(s-mdn**2)*a1z**2/pi*alpha**3*q
     &   dn/s/spr*(s-spr)*(-2*p1p4*p3p4*qta/mz**4*mdn**2*mta**2+p1p4*p3p5*
     &   qta/mz**4*mdn**2*mta**2+2*p1p4*qta/mz**4*mdn**2*mta**4+p1p4*qta/m
     &   z**2*mdn**2*mta**2-2*p2p4*p3p4*qta/mz**4*mdn**2*mta**2+p2p4*p3p5*
     &   qta/mz**4*mdn**2*mta**2+2*p2p4*qta/mz**4*mdn**2*mta**4+p2p4*qta/m
     &   z**2*mdn**2*mta**2)
     &   +betasprtata*chizspr/ps/(s-mdn**2)*a1z/pi*alpha**3*qdn**2/s/spr*(
     &   s-spr)*(-qta**2/mz**2*mdn**2*mta**2)
     &   +betasprtata*chizspr*chizpsc/ps**2/(s-mdn**2)*a1z**2/pi*alpha**3/
     &   s*(s-spr)*(-4*qta**2/mz**4*mdn**4*mta**2-4*p1p2*qta**2/mz**4*mdn*
     &   *2*mta**2)
     &   +betasprtata*chizspr*chizpsc/ps/(s-mdn**2)*a1z**2/pi*alpha**3*qdn
     &   /s/spr*(s-spr)*(1d0/2*p1p3*qta/mz**4*mdn**2*mta**2-1d0/2*p1p4*qta
     &   /mz**4*mdn**2*mta**2+1d0/2*p2p3*qta/mz**4*mdn**2*mta**2-1d0/2*p2p
     &   4*qta/mz**4*mdn**2*mta**2)
     &   +betasprtata*chizspr*chizsprc/ps/(s-mdn**2)*a1z**2/pi*alpha**3*qd
     &   n/s/spr*(s-spr)*(1d0/2*p1p3*qta/mz**4*mdn**2*mta**2-1d0/2*p1p4*qt
     &   a/mz**4*mdn**2*mta**2+1d0/2*p2p3*qta/mz**4*mdn**2*mta**2-1d0/2*p2
     &   p4*qta/mz**4*mdn**2*mta**2)
     &   +betasprtata*chizspr*chizsprc/(s-mdn**2)*a1z**2/pi*alpha**3*qdn**
     &   2/s/spr**2*(s-spr)*(-4/mz**4*mdn**2*mta**4+4*p3p4/mz**4*mdn**2*mt
     &   a**2)
     &   +betasprtata*chizpsc**2/ps**2/(s-mdn**2)*a1z**2/pi*alpha**3/s*(s-
     &   spr)*(4*qta**2/mz**4*mdn**4*mta**2+4*p1p2*qta**2/mz**4*mdn**2*mta
     &   **2)
     &   +betasprtata*chizpsc*chizsprc/ps**2/(s-mdn**2)*a1z**2/pi*alpha**3
     &   /s*(s-spr)*(-4*qta**2/mz**4*mdn**4*mta**2-4*p1p2*qta**2/mz**4*mdn
     &   **2*mta**2)
     &   +betasprtata*chizpsc*chizsprc/ps/(s-mdn**2)*a1z**2/pi*alpha**3*qd
     &   n/s/spr*(s-spr)*(-1d0/2*p1p3*qta/mz**4*mdn**2*mta**2+1d0/2*p1p4*q
     &   ta/mz**4*mdn**2*mta**2-1d0/2*p2p3*qta/mz**4*mdn**2*mta**2+1d0/2*p
     &   2p4*qta/mz**4*mdn**2*mta**2)
     &   +betasprtata*chizsprc/ps/(s-mdn**2)*a1z/pi*alpha**3*qdn**2/s/spr*
     &   (s-spr)*(-qta**2/mz**2*mdn**2*mta**2)
     &   +betasprtata*chizsprc**2/ps/(s-mdn**2)*a1z**2/pi*alpha**3*qdn/s/s
     &   pr*(s-spr)*(1d0/2*p1p3*qta/mz**4*mdn**2*mta**2-1d0/2*p1p4*qta/mz*
     &   *4*mdn**2*mta**2+1d0/2*p2p3*qta/mz**4*mdn**2*mta**2-1d0/2*p2p4*qt
     &   a/mz**4*mdn**2*mta**2)

        hard = hard*conhc*cfprime

        return
      end
