#include "Integrand.h"
#include "General.h"
#include "Info.h"
#include "LHEF.h"
#include "ModulesInterface.h"
#include "Process.h"
#include "Vec4.h"
#include <cmath>
using namespace std;
using namespace SANC;
using namespace SANCmodules;
using namespace SANCmodulesVar;

Integrand::Integrand(SANC::Info &_info, SANC::Process &_proc, int type) : info(_info), proc(_proc) {
  m_Type = type;
  Mf1 = proc.Mf1;
  Mf2 = proc.Mf2;
  Mf3 = proc.Mf3;
  Mf4 = proc.Mf4;
  Mf1_2 = proc.Mf1_2;
  Mf2_2 = proc.Mf2_2;
  Mf3_2 = proc.Mf3_2;
  Mf4_2 = proc.Mf4_2;
  sm = proc.sm;
  dm = proc.dm;
  P_com[0] = &proc.event.P_com(0);
  P_com[1] = &proc.event.P_com(1);
  P_com[2] = &proc.event.P_com(2);
  P_com[3] = &proc.event.P_com(3);
  P_com[4] = &proc.event.P_com(4);
  P_com[5] = &proc.event.P_com(5);
  P_lab[0] = &proc.event.P_lab(0);
  P_lab[1] = &proc.event.P_lab(1);
  P_lab[2] = &proc.event.P_lab(2);
  P_lab[3] = &proc.event.P_lab(3);
  P_lab[4] = &proc.event.P_lab(4);
  P_lab[5] = &proc.event.P_lab(5);
  *P_com[0] = Vec4();
  *P_lab[0] = Vec4();
}

double Integrand::Density(int nDim, double *Xarg) {
  double rho;
  rho = 1e-100;
  if (m_Type == 0)
    rho = Born(nDim, Xarg);
  else if (m_Type == 1)
    rho = Virt(nDim, Xarg);
  else if (m_Type == 2)
    rho = Hard(nDim, Xarg);
  else if (m_Type == 3)
    rho = Loop(nDim, Xarg);
  else if (m_Type == 4)
    rho = LLI11(nDim, Xarg);
  else if (m_Type == 5)
    rho = LLI22(nDim, Xarg);
  else if (m_Type == 6)
    rho = LLI12(nDim, Xarg);
  else if (m_Type == 7)
    rho = LLF11(nDim, Xarg);
  else if (m_Type == 8)
    rho = LLF22(nDim, Xarg);
  else if (m_Type == 9)
    rho = LLF12(nDim, Xarg);
  else {
    cout << " TFDISTR::Density: !!!!!! WRONG m_Type= " << m_Type << endl;
  }
  return rho;
}
////////////////////////////////////////////////////////////////////////////////////////////////////
double Integrand::Born(int nDim, double *Xarg) {
  double BornXS(0.);
  double Xl[2], Xu[2], Z[2];
  double Factor = 1.;
  double Cth3, Phi3;
  double Jac;
  double Sth3, Cph3, Sph3;
  double beta12, Betai, Betaf, n_sm, n_dm;
  double Pf3, Enf1, Enf2, Enf3, Enf4;
  double S, S_2, sqS, Qs, Qt, Qu, Tn, Un;
  // double Cth13,Cth14,Theta13,Theta14,Pt3,Pt4;
  double Born(0.), Soft(0.), Hard(0.);
  proc.event.weightProc = 1.;
  if ((proc.sqS < Mf1 + Mf2) || (proc.sqS < Mf3 + Mf4))
    return 0.0;
  //--------------------------------------------------------------------------------------------------
  Xl[0] = -1.;
  Xu[0] = 1.;
  Xl[1] = 0.;
  Xu[1] = 2. * consts_.pi;
  for (int i = 0; i < 2; i++) {
    Z[i] = Xl[i] + (Xu[i] - Xl[i]) * Xarg[i];
    Factor *= Xu[i] - Xl[i];
  }
  //--------------------------------------------------------------------------------------------------
  Cth3 = Z[0];
  Phi3 = Z[1];
  //--------------------------------------------------------------------------------------------------
  Sth3 = sqrt(1. - Cth3 * Cth3);
  Cph3 = cos(Phi3);
  Sph3 = sin(Phi3);
  S = proc.S;
  sqS = proc.sqS;
  Betai = sqrt((S - pow2(Mf1 + Mf2)) * (S - pow2(Mf1 - Mf2))) / S;
  Betaf = sqrt((S - pow2(Mf3 + Mf4)) * (S - pow2(Mf3 - Mf4))) / S;
  beta12 = (proc.beta1 * proc.E1 - proc.beta2 * proc.E2) / (proc.E1 + proc.E2);
  Pf3 = sqrt((S - pow2(Mf3 + Mf4)) * (S - pow2(Mf3 - Mf4))) / 2. / sqS;
  Enf1 = (S + Mf1_2 - Mf2_2) / 2. / sqS;
  Enf2 = (S + Mf2_2 - Mf1_2) / 2. / sqS;
  Enf3 = (S + Mf3_2 - Mf4_2) / 2. / sqS;
  Enf4 = (S + Mf4_2 - Mf3_2) / 2. / sqS;
  Jac = 1. / 2. / consts_.pi;
  //--------------------------------------------------------------------------------------------------
  *P_lab[1] = Vec4(0., 0., proc.beta1 * proc.E1, proc.E1, Mf1);
  *P_lab[2] = Vec4(0., 0., -proc.beta2 * proc.E2, proc.E2, Mf2);
  *P_lab[3] = Vec4(0., 0., Pf3, Enf3, Mf3).rot(Sth3, Cth3, Sph3, Cph3).bstZ(beta12);
  *P_lab[4] = Vec4(0., 0., -Pf3, Enf4, Mf4).rot(Sth3, Cth3, Sph3, Cph3).bstZ(beta12);
  *P_lab[5] = Vec4();
  *P_com[1] = Vec4(0., 0., Betai * sqS / 2., Enf1, Mf1);
  *P_com[2] = Vec4(0., 0., -Betai * sqS / 2., Enf2, Mf2);
  *P_com[3] = Vec4(0., 0., Pf3, Enf3, Mf3).rot(Sth3, Cth3, Sph3, Cph3);
  *P_com[4] = Vec4(0., 0., -Pf3, Enf4, Mf4).rot(Sth3, Cth3, Sph3, Cph3);
  *P_com[5] = Vec4();
  //--------------------------------------------------------------------------------------------------
  Tn = t(*P_lab[1], *P_lab[4]);
  Un = t(*P_lab[1], *P_lab[3]);
  //--------------------------------------------------------------------------------------------------
  if (!proc.passCuts())
    return 0.0;
  //--------------------------------------------------------------------------------------------------
  Qs = -S;
  Qt = -Tn;
  Qu = -Un;
  //--------------------------------------------------------------------------------------------------
  proc.born(&Qs, &Qt, &Qu, &Born, &Soft, &Hard);
  //--------------------------------------------------------------------------------------------------
  BornXS = Born * Factor * Jac;
  if (BornXS < 0)
    proc.event.weightProc = -1.;
  BornXS = abs(BornXS);
  //--------------------------------------------------------------------------------------------------
  return BornXS;
}
////////////////////////////////////////////////////////////////////////////////////////////////////
double Integrand::Virt(int nDim, double *Xarg) {
  int ktype(1);
  double VirtXS(0.);
  double Xl[2], Xu[2], Z[2];
  double Factor(1.);
  double Cth3, Phi3;
  double X1, X2;
  double Jac;
  double Sth3, Cph3, Sph3;
  double beta12, Betai, Betaf, n_sm, n_dm;
  double Pf3, Enf1, Enf2, Enf3, Enf4;
  double S, S_2, sqS, T, U, Qs, Qt, Qu, Tn, Un;
  // double Cth13,Cth14,Theta13,Theta14,Pt3,Pt4;
  double Born(0.), Soft(0.), Hard(0.), Sigma(0.);
  double FactorLLI(0.), FactorLLF(0.);
  proc.event.weightProc = 1.;
  if ((proc.sqS < Mf1 + Mf2) || (proc.sqS < Mf3 + Mf4))
    return 0.0;
  //--------------------------------------------------------------------------------------------------
  Xl[0] = -1.;
  Xu[0] = 1.;
  Xl[1] = 0.;
  Xu[1] = 2. * consts_.pi;
  for (int i = 0; i < 2; i++) {
    Z[i] = Xl[i] + (Xu[i] - Xl[i]) * Xarg[i];
    Factor *= Xu[i] - Xl[i];
  }
  //--------------------------------------------------------------------------------------------------
  Cth3 = Z[0];
  Phi3 = Z[1];
  //--------------------------------------------------------------------------------------------------
  X1 = 1.;
  X2 = 1.;
  //--------------------------------------------------------------------------------------------------
  Sth3 = sqrt(1. - Cth3 * Cth3);
  Cph3 = cos(Phi3);
  Sph3 = sin(Phi3);
  S = proc.S;
  sqS = proc.sqS;
  Betai = sqrt((S - pow2(Mf1 + Mf2)) * (S - pow2(Mf1 - Mf2))) / S;
  Betaf = sqrt((S - pow2(Mf3 + Mf4)) * (S - pow2(Mf3 - Mf4))) / S;
  beta12 = (proc.beta1 * proc.E1 - proc.beta2 * proc.E2) / (proc.E1 + proc.E2);
  Pf3 = sqrt((S - pow2(Mf3 + Mf4)) * (S - pow2(Mf3 - Mf4))) / 2. / sqS;
  Enf1 = (S + Mf1_2 - Mf2_2) / 2. / sqS;
  Enf2 = (S + Mf2_2 - Mf1_2) / 2. / sqS;
  Enf3 = (S + Mf3_2 - Mf4_2) / 2. / sqS;
  Enf4 = (S + Mf4_2 - Mf3_2) / 2. / sqS;
  Jac = 1. / 2. / consts_.pi;
  //--------------------------------------------------------------------------------------------------
  *P_lab[1] = Vec4(0., 0., proc.beta1 * proc.E1, proc.E1, Mf1);
  *P_lab[2] = Vec4(0., 0., -proc.beta2 * proc.E2, proc.E2, Mf2);
  *P_lab[3] = Vec4(0., 0., Pf3, Enf3, Mf3).rot(Sth3, Cth3, Sph3, Cph3).bstZ(beta12);
  *P_lab[4] = Vec4(0., 0., -Pf3, Enf4, Mf4).rot(Sth3, Cth3, Sph3, Cph3).bstZ(beta12);
  *P_lab[5] = Vec4();
  *P_com[1] = Vec4(0., 0., Betai * sqS / 2., Enf1, Mf1);
  *P_com[2] = Vec4(0., 0., -Betai * sqS / 2., Enf2, Mf2);
  *P_com[3] = Vec4(0., 0., Pf3, Enf3, Mf3).rot(Sth3, Cth3, Sph3, Cph3);
  *P_com[4] = Vec4(0., 0., -Pf3, Enf4, Mf4).rot(Sth3, Cth3, Sph3, Cph3);
  *P_com[5] = Vec4();
  //--------------------------------------------------------------------------------------------------
  Tn = t(*P_lab[1], *P_lab[4]);
  Un = t(*P_lab[1], *P_lab[3]);
  //--------------------------------------------------------------------------------------------------
  if (!proc.passCuts())
    return 0.0;
  //--------------------------------------------------------------------------------------------------
  if (info.Iqedlli != 0) {
    lla_factor_(&ktype, &info.Iqedlli, &Mf1, &S, &X1, &X2, &FactorLLI);
  }
  //--------------------------------------------------------------------------------------------------
  if (info.Iqedllf != 0) {
    lla_factor_(&ktype, &info.Iqedllf, &Mf3, &S, &X1, &X2, &FactorLLF);
  }
  //--------------------------------------------------------------------------------------------------
  Qs = -S;
  Qt = -Tn;
  Qu = -Un;
  flags_.iborn = 0;
  //--------------------------------------------------------------------------------------------------
  proc.born(&Qs, &Qt, &Qu, &Born, &Soft, &Hard);
  if (info.Ifgg != 0 || info.Iqed != 0 || info.Iew != 0) {
    proc.virt(&S, &Tn, &Un, &Sigma);
  }
  if (info.Iqed == 0) {
    Soft = 0.;
    if (info.Iew == 0 && info.Ifgg == 0) {
      Sigma = Born;
    }
  }
  //--------------------------------------------------------------------------------------------------
  VirtXS = (Sigma + Soft) * Factor * Jac + Born * Factor * Jac * FactorLLI +
           Born * Factor * Jac * FactorLLF;
  if (VirtXS < 0)
    proc.event.weightProc = -1.;
  VirtXS = abs(VirtXS);
  //--------------------------------------------------------------------------------------------------
  return VirtXS;
}
////////////////////////////////////////////////////////////////////////////////////////////////////
double Integrand::Hard(int nDim, double *Xarg) {
  double HardXS(0.);
  double Xl[5], Xu[5], Z[5];
  double Factor(1.);
  double Spr, Eta3, Phi3, Eta5, Phi5;
  double Jac;
  double Cth3, Sth3, Cph3, Sph3, Cth5, Sth5, Cph5, Sph5;
  double Beta34, beta12, Betai, Betaf;
  double Pf3, Enf1, Enf2, Enf3, Enf4;
  double S, sqS, sqSpr;
  double Egamma;
  // double Cth13,Cth14,Theta13,Theta14,Pt3,Pt4;
  double Hard(0.);
  proc.event.weightProc = 1.;
  S = proc.S;
  sqS = proc.sqS;
  if ((sqS < Mf1 + Mf2) || (sqS < Mf3 + Mf4))
    return 0.0;
  //--------------------------------------------------------------------------------------------------
  Xl[0] = log(info.Ome);
  Xu[0] = log(1. - (Mf3 + Mf4) * (Mf3 + Mf4) / S);
  Xl[1] = -50.;
  Xu[1] = 50.;
  Xl[2] = 0.;
  Xu[2] = 2. * consts_.pi;
  Xl[3] = -50.;
  Xu[3] = 50.;
  Xl[4] = 0.;
  Xu[4] = 2. * consts_.pi;
  for (int i = 0; i < 5; i++) {
    Z[i] = Xl[i] + (Xu[i] - Xl[i]) * Xarg[i];
    Factor *= Xu[i] - Xl[i];
  }
  //--------------------------------------------------------------------------------------------------
  Spr = S * (1. - exp(Z[0]));
  if (Spr == 0.) {
    return HardXS;
  }
  Eta3 = Z[1];
  Phi3 = Z[2];
  Eta5 = Z[3];
  Phi5 = Z[4];
  //--------------------------------------------------------------------------------------------------
  Cth3 = (exp(2.0 * Eta3) - 1.0) / (exp(2.0 * Eta3) + 1.0);
  Sth3 = 2.0 * exp(Eta3) / (exp(2.0 * Eta3) + 1.0);
  Cph3 = cos(Phi3);
  Sph3 = sin(Phi3);
  Cth5 = (exp(2.0 * Eta5) - 1.0) / (exp(2.0 * Eta5) + 1.0);
  Sth5 = 2.0 * exp(Eta5) / (exp(2.0 * Eta5) + 1.0);
  Cph5 = cos(Phi5);
  Sph5 = sin(Phi5);
  Betai = sqrt((S - pow2(Mf1 + Mf2)) * (S - pow2(Mf1 - Mf2))) / S;
  Betaf = sqrt((S - pow2(Mf3 + Mf4)) * (S - pow2(Mf3 - Mf4))) / S;
  beta12 = (proc.beta1 * proc.E1 - proc.beta2 * proc.E2) / (proc.E1 + proc.E2);
  sqSpr = sqrt(Spr);
  Pf3 = sqrt((Spr - pow2(Mf3 + Mf4)) * (Spr - pow2(Mf3 - Mf4))) / 2.0 / sqSpr;
  Enf1 = (S + Mf1_2 - Mf2_2) / 2. / sqS;
  Enf2 = (S + Mf2_2 - Mf1_2) / 2. / sqS;
  Enf3 = (Spr + Mf3_2 - Mf4_2) / 2. / sqSpr;
  Enf4 = (Spr + Mf4_2 - Mf3_2) / 2. / sqSpr;
  Egamma = (S - Spr) / 2. / sqS;
  Beta34 = (S - Spr) / (S + Spr);
  Jac = Sth3 * Sth3 * Sth5 * Sth5 / 2. / consts_.pi * (S - Spr);
  //--------------------------------------------------------------------------------------------------
  // NOTE: Because SANC use special reference frame,
  // such as phi3=phi3'+pi/2 and th5 is photon`s angle,
  // we need replace Sph3->-Cph3, Cph3->Sph3 and boost in opposite direction
  *P_lab[1] = Vec4(0., 0., proc.beta1 * proc.E1, proc.E1, Mf1);
  *P_lab[2] = Vec4(0., 0., -proc.beta2 * proc.E2, proc.E2, Mf2);
  *P_lab[3] = Vec4(0., 0., Pf3, Enf3, Mf3)
                  .rot(Sth3, Cth3, -Cph3, Sph3)
                  .bstZ(-Beta34)
                  .rot(Sth5, Cth5, Sph5, Cph5)
                  .bstZ(beta12);
  *P_lab[4] = Vec4(0., 0., -Pf3, Enf4, Mf4)
                  .rot(Sth3, Cth3, -Cph3, Sph3)
                  .bstZ(-Beta34)
                  .rot(Sth5, Cth5, Sph5, Cph5)
                  .bstZ(beta12);
  *P_lab[5] = Vec4(0., 0., Egamma, Egamma, 0.).rot(Sth5, Cth5, Sph5, Cph5).bstZ(beta12);
  *P_com[1] = Vec4(0., 0., Betai * sqS / 2., Enf1, Mf1);
  *P_com[2] = Vec4(0., 0., -Betai * sqS / 2., Enf2, Mf2);
  *P_com[3] = Vec4(0., 0., Pf3, Enf3, Mf3)
                  .rot(Sth3, Cth3, -Cph3, Sph3)
                  .bstZ(-Beta34)
                  .rot(Sth5, Cth5, Sph5, Cph5);
  *P_com[4] = Vec4(0., 0., -Pf3, Enf4, Mf4)
                  .rot(Sth3, Cth3, -Cph3, Sph3)
                  .bstZ(-Beta34)
                  .rot(Sth5, Cth5, Sph5, Cph5);
  *P_com[5] = Vec4(0., 0., Egamma, Egamma, 0.).rot(Sth5, Cth5, Sph5, Cph5);
  //--------------------------------------------------------------------------------------------------
  setMomenta(proc.event);
  //--------------------------------------------------------------------------------------------------
  if (!proc.passCuts())
    return 0.0;
  if (Egamma < scales_.omega)
    return HardXS;
  //--------------------------------------------------------------------------------------------------
  proc.hard(&S, &Spr, &Phi3, &Eta3, &Eta5, &Hard);
  if (Hard != Hard)
    return HardXS;
  //--------------------------------------------------------------------------------------------------
  HardXS = Hard * Factor * Jac;
  if (HardXS < 0)
    proc.event.weightProc = -1.;
  HardXS = abs(HardXS);
  //--------------------------------------------------------------------------------------------------
  return HardXS;
}
////////////////////////////////////////////////////////////////////////////////////////////////////
double Integrand::LLI11(int nDim, double *Xarg) {
  int ktype(2);
  double LLI11XS = 0.;
  double Xl[3], Xu[3], Z[3];
  double Factor = 1.;
  double Cth3, Phi3;
  double X1, X2;
  double Jac;
  double Sth3, Cph3, Sph3;
  double Betai, Betaf;
  double Beta, beta12;
  double Pf3, Enf1, Enf2, Enf3, Enf4;
  double S, S_2, sqS, T, U, Qs, Qt, Qu;
  double n_sm, n_dm;
  // double Cth13,Cth14,Pt3,Pt4,M34;
  double Born, Soft, Hard, Sigma;
  double FactorLL, S0;
  proc.event.weightProc = 1.;
  //--------------------------------------------------------------------------------------------------
  Xl[0] = -1.;
  Xu[0] = 1.;
  Xl[1] = 0.;
  Xu[1] = 2. * consts_.pi;
  Xl[2] = 0.;
  Xu[2] = 1. - info.DeltaLL;
  for (int i = 0; i < 3; i++) {
    Z[i] = Xl[i] + (Xu[i] - Xl[i]) * Xarg[i];
    Factor *= Xu[i] - Xl[i];
  }
  //--------------------------------------------------------------------------------------------------
  Cth3 = Z[0];
  Phi3 = Z[1];
  X1 = Z[2];
  X2 = 1.;
  //--------------------------------------------------------------------------------------------------
  Sth3 = sqrt(1. - Cth3 * Cth3);
  Cph3 = cos(Phi3);
  Sph3 = sin(Phi3);
  S0 = proc.S;
  S = S0 * X1;
  if (S < (Mf3 + Mf4) * (Mf3 + Mf4))
    return 0.0;
  sqS = sqrt(S);
  S_2 = pow2(S);
  Betai = sqrt((S - pow2(Mf1 + Mf2)) * (S - pow2(Mf1 - Mf2))) / S;
  Betaf = sqrt((S - pow2(Mf3 + Mf4)) * (S - pow2(Mf3 - Mf4))) / S;
  beta12 = (proc.beta1 * proc.E1 - proc.beta2 * proc.E2) / (proc.E1 + proc.E2);
  Beta = (X1 - 1.) / (X1 + 1.);
  Pf3 = sqrt((S - pow2(Mf3 + Mf4)) * (S - pow2(Mf3 - Mf4))) / 2. / sqS;
  Enf1 = (S + Mf1_2 - Mf2_2) / 2. / sqS;
  Enf2 = (S + Mf2_2 - Mf1_2) / 2. / sqS;
  Enf3 = (S + Mf3_2 - Mf4_2) / 2. / sqS;
  Enf4 = (S + Mf4_2 - Mf3_2) / 2. / sqS;
  n_sm = sm / S;
  n_dm = dm / S_2;
  T = -0.5 * S * (1. + n_dm - n_sm + Betai * Betaf * Cth3);
  U = -0.5 * S * (1. - n_dm - n_sm - Betai * Betaf * Cth3);
  Jac = 1. / 2. / consts_.pi;
  //--------------------------------------------------------------------------------------------------
  *P_com[1] = Vec4(0., 0., Betai * sqS / 2., Enf1, Mf1);
  *P_com[2] = Vec4(0., 0., -Betai * sqS / 2., Enf2, Mf2);
  *P_com[3] = Vec4(0., 0., Pf3, Enf3, Mf3).rot(Sth3, Cth3, Sph3, Cph3);
  *P_com[4] = Vec4(0., 0., -Pf3, Enf4, Mf4).rot(Sth3, Cth3, Sph3, Cph3);
  *P_com[5] = Vec4();
  *P_lab[1] = (*P_com[1]).bstZ(Beta).bstZ(beta12);
  *P_lab[2] = (*P_com[2]).bstZ(Beta).bstZ(beta12);
  *P_lab[3] = (*P_com[3]).bstZ(Beta).bstZ(beta12);
  *P_lab[4] = (*P_com[4]).bstZ(Beta).bstZ(beta12);
  *P_lab[5] = Vec4();
  //--------------------------------------------------------------------------------------------------
  if (!proc.passCuts())
    return 0.0;
  //--------------------------------------------------------------------------------------------------
  lla_factor_(&ktype, &info.Iqedlli, &Mf1, &S0, &X1, &X2, &FactorLL);
  //--------------------------------------------------------------------------------------------------
  Qs = -S;
  Qt = -T;
  Qu = -U;
  // cout<<"cut"<<info.CutMinM34<<endl;
  // cout<<"old S="<<S<<" new="<<s(*P_lab[3],*P_lab[4])<<endl;
  // cout<<"old T="<<T<<" new="<<t(*P_lab[1],*P_lab[4])<<endl;
  flags_.iborn = 0;
  //--------------------------------------------------------------------------------------------------
  proc.born(&Qs, &Qt, &Qu, &Born, &Soft, &Hard);
  //--------------------------------------------------------------------------------------------------
  LLI11XS = Born * Factor * Jac * FactorLL;
  if (LLI11XS < 0)
    proc.event.weightProc = -1.;
  LLI11XS = abs(LLI11XS);
  //--------------------------------------------------------------------------------------------------
  return LLI11XS;
}
////////////////////////////////////////////////////////////////////////////////////////////////////
double Integrand::LLI22(int nDim, double *Xarg) {
  int ktype(3);
  double LLI22XS = 0.;
  double Xl[3], Xu[3], Z[3];
  double Factor = 1.;
  double Cth3, Phi3;
  double X1, X2;
  double Jac;
  double Sth3, Cph3, Sph3;
  double Betai, Betaf;
  double Beta, beta12;
  double Pf3, Enf1, Enf2, Enf3, Enf4;
  double S, S_2, sqS, T, U, Qs, Qt, Qu;
  double n_sm, n_dm;
  double Cth13, Cth14, Pt3, Pt4, M34;
  double Born, Soft, Hard, Sigma;
  double FactorLL, S0;
  proc.event.weightProc = 1.;
  //--------------------------------------------------------------------------------------------------
  Xl[0] = -1.;
  Xu[0] = 1.;
  Xl[1] = 0.;
  Xu[1] = 2. * consts_.pi;
  Xl[2] = 0.;
  Xu[2] = 1. - info.DeltaLL;
  for (int i = 0; i < 3; i++) {
    Z[i] = Xl[i] + (Xu[i] - Xl[i]) * Xarg[i];
    Factor *= Xu[i] - Xl[i];
  }
  //--------------------------------------------------------------------------------------------------
  Cth3 = Z[0];
  Phi3 = Z[1];
  X1 = 1.;
  X2 = Z[2];
  //--------------------------------------------------------------------------------------------------
  Sth3 = sqrt(1. - Cth3 * Cth3);
  Cph3 = cos(Phi3);
  Sph3 = sin(Phi3);
  S0 = proc.S;
  S = S0 * X2;
  if (S < (Mf3 + Mf4) * (Mf3 + Mf4))
    return 0.0;
  sqS = sqrt(S);
  S_2 = pow2(S);
  Betai = sqrt((S - pow2(Mf1 + Mf2)) * (S - pow2(Mf1 - Mf2))) / S;
  Betaf = sqrt((S - pow2(Mf3 + Mf4)) * (S - pow2(Mf3 - Mf4))) / S;
  beta12 = (proc.beta1 * proc.E1 - proc.beta2 * proc.E2) / (proc.E1 + proc.E2);
  Beta = (1. - X2) / (1. + X2);
  Pf3 = sqrt((S - pow2(Mf3 + Mf4)) * (S - pow2(Mf3 - Mf4))) / 2. / sqS;
  Enf1 = (S + Mf1_2 - Mf2_2) / 2. / sqS;
  Enf2 = (S + Mf2_2 - Mf1_2) / 2. / sqS;
  Enf3 = (S + Mf3_2 - Mf4_2) / 2. / sqS;
  Enf4 = (S + Mf4_2 - Mf3_2) / 2. / sqS;
  n_sm = sm / S;
  n_dm = dm / S_2;
  T = -0.5 * S * (1. + n_dm - n_sm + Betai * Betaf * Cth3);
  U = -0.5 * S * (1. - n_dm - n_sm - Betai * Betaf * Cth3);
  Jac = 1. / 2. / consts_.pi;
  //--------------------------------------------------------------------------------------------------
  *P_com[1] = Vec4(0., 0., Betai * sqS / 2., Enf1, Mf1);
  *P_com[2] = Vec4(0., 0., -Betai * sqS / 2., Enf2, Mf2);
  *P_com[3] = Vec4(0., 0., Pf3, Enf3, Mf3).rot(Sth3, Cth3, Sph3, Cph3);
  *P_com[4] = Vec4(0., 0., -Pf3, Enf4, Mf4).rot(Sth3, Cth3, Sph3, Cph3);
  *P_com[5] = Vec4();
  *P_lab[1] = (*P_com[1]).bstZ(Beta).bstZ(beta12);
  *P_lab[2] = (*P_com[2]).bstZ(Beta).bstZ(beta12);
  *P_lab[3] = (*P_com[3]).bstZ(Beta).bstZ(beta12);
  *P_lab[4] = (*P_com[4]).bstZ(Beta).bstZ(beta12);
  *P_lab[5] = Vec4();
  //--------------------------------------------------------------------------------------------------
  if (!proc.passCuts())
    return 0.0;
  //--------------------------------------------------------------------------------------------------
  lla_factor_(&ktype, &info.Iqedlli, &Mf1, &S0, &X1, &X2, &FactorLL);
  //--------------------------------------------------------------------------------------------------
  Qs = -S;
  Qt = -T;
  Qu = -U;
  flags_.iborn = 0;
  //--------------------------------------------------------------------------------------------------
  proc.born(&Qs, &Qt, &Qu, &Born, &Soft, &Hard);
  //--------------------------------------------------------------------------------------------------
  LLI22XS = Born * Factor * Jac * FactorLL;
  if (LLI22XS < 0)
    proc.event.weightProc = -1.;
  LLI22XS = abs(LLI22XS);
  //--------------------------------------------------------------------------------------------------
  return LLI22XS;
}
////////////////////////////////////////////////////////////////////////////////////////////////////
double Integrand::LLI12(int nDim, double *Xarg) {
  int ktype(4);
  double LLI12XS = 0.;
  double Xl[4], Xu[4], Z[4];
  double Factor = 1.;
  double Cth3, Phi3;
  double X1, X2;
  double Jac;
  double Sth3, Cph3, Sph3;
  double Betai, Betaf, Betai0;
  double Beta, beta12;
  double Pf3, Enf1, Enf2, Enf3, Enf4;
  // double Pf03,Enf01,Enf02,Enf03,Enf04;
  double S, S_2, sqS, T, U, Qs, Qt, Qu;
  double n_sm, n_dm;
  double Cth13, Cth14, Pt3, Pt4, M34;
  double Born, Soft, Hard, Sigma;
  double FactorLL, S0;
  proc.event.weightProc = 1.;
  //--------------------------------------------------------------------------------------------------
  Xl[0] = -1.;
  Xu[0] = 1.;
  Xl[1] = 0.;
  Xu[1] = 2. * consts_.pi;
  Xl[2] = 0.;
  Xu[2] = 1. - info.DeltaLL;
  Xl[3] = 0.;
  Xu[3] = 1. - info.DeltaLL;
  for (int i = 0; i < 4; i++) {
    Z[i] = Xl[i] + (Xu[i] - Xl[i]) * Xarg[i];
    Factor *= Xu[i] - Xl[i];
  }
  //--------------------------------------------------------------------------------------------------
  Cth3 = Z[0];
  Phi3 = Z[1];
  X1 = Z[2];
  X2 = Z[3];
  //--------------------------------------------------------------------------------------------------
  Sth3 = sqrt(1. - Cth3 * Cth3);
  Cph3 = cos(Phi3);
  Sph3 = sin(Phi3);
  S0 = proc.S;
  S = S0 * X1 * X2;
  if (S < (Mf3 + Mf4) * (Mf3 + Mf4))
    return 0.0;
  sqS = sqrt(S);
  S_2 = pow2(S);
  Betai = sqrt((S - pow2(Mf1 + Mf2)) * (S - pow2(Mf1 - Mf2))) / S;
  Betaf = sqrt((S - pow2(Mf3 + Mf4)) * (S - pow2(Mf3 - Mf4))) / S;
  beta12 = (proc.beta1 * proc.E1 - proc.beta2 * proc.E2) / (proc.E1 + proc.E2);
  Beta = (X1 - X2) / (X1 + X2);
  Pf3 = sqrt((S - pow2(Mf3 + Mf4)) * (S - pow2(Mf3 - Mf4))) / 2. / sqS;
  Enf1 = (S + Mf1_2 - Mf2_2) / 2. / sqS;
  Enf2 = (S + Mf2_2 - Mf1_2) / 2. / sqS;
  Enf3 = (S + Mf3_2 - Mf4_2) / 2. / sqS;
  Enf4 = (S + Mf4_2 - Mf3_2) / 2. / sqS;
  n_sm = sm / S;
  n_dm = dm / S_2;
  T = -0.5 * S * (1. + n_dm - n_sm + Betai * Betaf * Cth3);
  U = -0.5 * S * (1. - n_dm - n_sm - Betai * Betaf * Cth3);
  Jac = 1. / 2. / consts_.pi;
  *P_com[1] = Vec4(0., 0., Betai * sqS / 2., Enf1, Mf1);
  *P_com[2] = Vec4(0., 0., -Betai * sqS / 2., Enf2, Mf2);
  *P_com[3] = Vec4(0., 0., Pf3, Enf3, Mf3).rot(Sth3, Cth3, Sph3, Cph3);
  *P_com[4] = Vec4(0., 0., -Pf3, Enf4, Mf4).rot(Sth3, Cth3, Sph3, Cph3);
  *P_com[5] = Vec4();
  *P_lab[1] = (*P_com[1]).bstZ(Beta).bstZ(beta12);
  *P_lab[2] = (*P_com[2]).bstZ(Beta).bstZ(beta12);
  *P_lab[3] = (*P_com[3]).bstZ(Beta).bstZ(beta12);
  *P_lab[4] = (*P_com[4]).bstZ(Beta).bstZ(beta12);
  *P_lab[5] = Vec4();
  //--------------------------------------------------------------------------------------------------
  if (!proc.passCuts())
    return 0.0;
  //--------------------------------------------------------------------------------------------------
  lla_factor_(&ktype, &info.Iqedlli, &Mf1, &S0, &X1, &X2, &FactorLL);
  //--------------------------------------------------------------------------------------------------
  Qs = -S;
  Qt = -T;
  Qu = -U;
  flags_.iborn = 0;
  //--------------------------------------------------------------------------------------------------
  proc.born(&Qs, &Qt, &Qu, &Born, &Soft, &Hard);
  //--------------------------------------------------------------------------------------------------
  LLI12XS = Born * Factor * Jac * FactorLL;
  if (LLI12XS < 0)
    proc.event.weightProc = -1.;
  LLI12XS = abs(LLI12XS);
  if (LLI12XS != LLI12XS)
    LLI12XS = 0.;
  //--------------------------------------------------------------------------------------------------
  return LLI12XS;
}
////////////////////////////////////////////////////////////////////////////////////////////////////
double Integrand::LLF11(int nDim, double *Xarg) {
  int ktype(2);
  double LLF11XS = 0.;
  double Xl[3], Xu[3], Z[3];
  double Factor = 1.;
  double Cth3, Phi3;
  double X1, X2;
  double Jac;
  double Sth3, Cph3, Sph3;
  double Betai, Betaf;
  double Beta, beta12;
  double Pf3, Enf1, Enf2, Enf3, Enf4;
  double S, S_2, sqS, T, U, Qs, Qt, Qu, S1;
  double n_sm, n_dm;
  // double Cth13,Cth14,Pt3,Pt4,M34;
  double Born, Soft, Hard, Sigma;
  double FactorLL, S0;
  proc.event.weightProc = 1.;
  //--------------------------------------------------------------------------------------------------
  Xl[0] = -1.;
  Xu[0] = 1.;
  Xl[1] = 0.;
  Xu[1] = 2. * consts_.pi;
  Xl[2] = 0.;
  Xu[2] = 1. - info.DeltaLL;
  for (int i = 0; i < 3; i++) {
    Z[i] = Xl[i] + (Xu[i] - Xl[i]) * Xarg[i];
    Factor *= Xu[i] - Xl[i];
  }
  //--------------------------------------------------------------------------------------------------
  Cth3 = Z[0];
  Phi3 = Z[1];
  X1 = Z[2];
  X2 = 1.;
  //--------------------------------------------------------------------------------------------------
  Sth3 = sqrt(1. - Cth3 * Cth3);
  Cph3 = cos(Phi3);
  Sph3 = sin(Phi3);
  S = proc.S;
  S1 = S * X1;
  if (S1 < (Mf3 + Mf4) * (Mf3 + Mf4))
    return 0.0;
  sqS = sqrt(S);
  S_2 = pow2(S);
  Betai = sqrt((S - pow2(Mf1 + Mf2)) * (S - pow2(Mf1 - Mf2))) / S;
  Betaf = sqrt((S - pow2(Mf3 + Mf4)) * (S - pow2(Mf3 - Mf4))) / S;
  Beta = (X1 - 1.) / (X1 + 1.);
  Pf3 = sqrt((S - pow2(Mf3 + Mf4)) * (S - pow2(Mf3 - Mf4))) / 2. / sqS;
  Enf1 = (S + Mf1_2 - Mf2_2) / 2. / sqS;
  Enf2 = (S + Mf2_2 - Mf1_2) / 2. / sqS;
  Enf3 = (S + Mf3_2 - Mf4_2) / 2. / sqS;
  Enf4 = (S + Mf4_2 - Mf3_2) / 2. / sqS;
  n_sm = sm / S;
  n_dm = dm / S_2;
  T = -0.5 * S * (1. + n_dm - n_sm + Betai * Betaf * Cth3);
  U = -0.5 * S * (1. - n_dm - n_sm - Betai * Betaf * Cth3);
  Jac = 1. / 2. / consts_.pi;
  //--------------------------------------------------------------------------------------------------
  // P_com of hard process
  *P_com[1] = Vec4(0., 0., Betai * sqS / 2., Enf1, Mf1);
  *P_com[2] = Vec4(0., 0., -Betai * sqS / 2., Enf2, Mf2);
  *P_com[3] = Vec4(0., 0., Pf3, Enf3, Mf3).rot(Sth3, Cth3, Sph3, Cph3);
  *P_com[4] = Vec4(0., 0., -Pf3, Enf4, Mf4).rot(Sth3, Cth3, Sph3, Cph3);
  *P_com[5] = Vec4();
  *P_lab[1] = Vec4(0., 0., proc.beta1 * proc.E1, proc.E1, Mf1);
  *P_lab[2] = Vec4(0., 0., -proc.beta2 * proc.E2, proc.E2, Mf2);
  *P_lab[3] = Vec4(0., 0., sqrt(pow2(X1 * Enf3) - Mf3_2), X1 * Enf3, Mf3)
                  .rot(Sth3, Cth3, Sph3, Cph3)
                  .bstZ(beta12);
  *P_lab[4] = Vec4(0., 0., -sqrt(pow2(X2 * Enf4) - Mf4_2), X2 * Enf4, Mf4)
                  .rot(Sth3, Cth3, Sph3, Cph3)
                  .bstZ(beta12);
  *P_lab[5] = Vec4();
  //--------------------------------------------------------------------------------------------------
  if (!proc.passCuts())
    return 0.0;
  //--------------------------------------------------------------------------------------------------
  lla_factor_(&ktype, &info.Iqedllf, &Mf3, &S, &X1, &X2, &FactorLL);
  //--------------------------------------------------------------------------------------------------
  Qs = -S;
  Qt = -T;
  Qu = -U;
  flags_.iborn = 0;
  //--------------------------------------------------------------------------------------------------
  proc.born(&Qs, &Qt, &Qu, &Born, &Soft, &Hard);
  //--------------------------------------------------------------------------------------------------
  LLF11XS = Born * Factor * Jac * FactorLL;
  // cout<<"born="<<Born<<" fact="<<FactorLL<<" res="<<LLF11XS<<endl;
  if (LLF11XS < 0)
    proc.event.weightProc = -1.;
  LLF11XS = abs(LLF11XS);
  //--------------------------------------------------------------------------------------------------
  return LLF11XS;
}
////////////////////////////////////////////////////////////////////////////////////////////////////
double Integrand::LLF22(int nDim, double *Xarg) {
  int ktype(3);
  double LLF22XS = 0.;
  double Xl[3], Xu[3], Z[3];
  double Factor = 1.;
  double Cth3, Phi3;
  double X1, X2;
  double Jac;
  double Sth3, Cph3, Sph3;
  double Betai, Betaf;
  double Beta, beta12;
  double Pf3, Enf1, Enf2, Enf3, Enf4;
  double S, S_2, sqS, T, U, Qs, Qt, Qu, S1;
  double n_sm, n_dm;
  double Cth13, Cth14, Pt3, Pt4, M34;
  double Born, Soft, Hard, Sigma;
  double FactorLL, S0;
  proc.event.weightProc = 1.;
  //--------------------------------------------------------------------------------------------------
  Xl[0] = -1.;
  Xu[0] = 1.;
  Xl[1] = 0.;
  Xu[1] = 2. * consts_.pi;
  Xl[2] = 0.;
  Xu[2] = 1. - info.DeltaLL;
  for (int i = 0; i < 3; i++) {
    Z[i] = Xl[i] + (Xu[i] - Xl[i]) * Xarg[i];
    Factor *= Xu[i] - Xl[i];
  }
  //--------------------------------------------------------------------------------------------------
  Cth3 = Z[0];
  Phi3 = Z[1];
  X1 = 1.;
  X2 = Z[2];
  //--------------------------------------------------------------------------------------------------
  Sth3 = sqrt(1. - Cth3 * Cth3);
  Cph3 = cos(Phi3);
  Sph3 = sin(Phi3);
  S = proc.S;
  S1 = S * X2;
  if (S1 < (Mf3 + Mf4) * (Mf3 + Mf4))
    return 0.0;
  sqS = sqrt(S);
  S_2 = pow2(S);
  Betai = sqrt((S - pow2(Mf1 + Mf2)) * (S - pow2(Mf1 - Mf2))) / S;
  Betaf = sqrt((S - pow2(Mf3 + Mf4)) * (S - pow2(Mf3 - Mf4))) / S;
  Beta = (1. - X2) / (1. + X2);
  Pf3 = sqrt((S - pow2(Mf3 + Mf4)) * (S - pow2(Mf3 - Mf4))) / 2. / sqS;
  Enf1 = (S + Mf1_2 - Mf2_2) / 2. / sqS;
  Enf2 = (S + Mf2_2 - Mf1_2) / 2. / sqS;
  Enf3 = (S + Mf3_2 - Mf4_2) / 2. / sqS;
  Enf4 = (S + Mf4_2 - Mf3_2) / 2. / sqS;
  n_sm = sm / S;
  n_dm = dm / S_2;
  T = -0.5 * S * (1. + n_dm - n_sm + Betai * Betaf * Cth3);
  U = -0.5 * S * (1. - n_dm - n_sm - Betai * Betaf * Cth3);
  Jac = 1. / 2. / consts_.pi;
  //--------------------------------------------------------------------------------------------------
  // P_com of hard process
  *P_com[1] = Vec4(0., 0., Betai * sqS / 2., Enf1, Mf1);
  *P_com[2] = Vec4(0., 0., -Betai * sqS / 2., Enf2, Mf2);
  *P_com[3] = Vec4(0., 0., Pf3, Enf3, Mf3).rot(Sth3, Cth3, Sph3, Cph3);
  *P_com[4] = Vec4(0., 0., -Pf3, Enf4, Mf4).rot(Sth3, Cth3, Sph3, Cph3);
  *P_com[5] = Vec4();
  *P_lab[1] = Vec4(0., 0., proc.beta1 * proc.E1, proc.E1, Mf1);
  *P_lab[2] = Vec4(0., 0., -proc.beta2 * proc.E2, proc.E2, Mf2);
  *P_lab[3] = Vec4(0., 0., sqrt(pow2(X1 * Enf3) - Mf3_2), X1 * Enf3, Mf3)
                  .rot(Sth3, Cth3, Sph3, Cph3)
                  .bstZ(beta12);
  *P_lab[4] = Vec4(0., 0., -sqrt(pow2(X2 * Enf4) - Mf4_2), X2 * Enf4, Mf4)
                  .rot(Sth3, Cth3, Sph3, Cph3)
                  .bstZ(beta12);
  *P_lab[5] = Vec4();
  //--------------------------------------------------------------------------------------------------
  if (!proc.passCuts())
    return 0.0;
  //--------------------------------------------------------------------------------------------------
  lla_factor_(&ktype, &info.Iqedllf, &Mf3, &S, &X1, &X2, &FactorLL);
  //--------------------------------------------------------------------------------------------------
  Qs = -S;
  Qt = -T;
  Qu = -U;
  flags_.iborn = 0;
  //--------------------------------------------------------------------------------------------------
  proc.born(&Qs, &Qt, &Qu, &Born, &Soft, &Hard);
  //--------------------------------------------------------------------------------------------------
  LLF22XS = Born * Factor * Jac * FactorLL;
  if (LLF22XS < 0)
    proc.event.weightProc = -1.;
  LLF22XS = abs(LLF22XS);
  //--------------------------------------------------------------------------------------------------
  return LLF22XS;
}
////////////////////////////////////////////////////////////////////////////////////////////////////
double Integrand::LLF12(int nDim, double *Xarg) {
  int ktype(4);
  double LLF12XS = 0.;
  double Xl[4], Xu[4], Z[4];
  double Factor = 1.;
  double Cth3, Phi3;
  double X1, X2;
  double Jac;
  double Sth3, Cph3, Sph3;
  double Betai, Betaf, Betai0;
  double Beta, beta12;
  double Pf3, Enf1, Enf2, Enf3, Enf4;
  double S, S_2, sqS, T, U, Qs, Qt, Qu, S1;
  double n_sm, n_dm;
  double Cth13, Cth14, Pt3, Pt4, M34;
  double Born, Soft, Hard, Sigma;
  double FactorLL, S0;
  proc.event.weightProc = 1.;
  //--------------------------------------------------------------------------------------------------
  Xl[0] = -1.;
  Xu[0] = 1.;
  Xl[1] = 0.;
  Xu[1] = 2. * consts_.pi;
  Xl[2] = 0.;
  Xu[2] = 1. - info.DeltaLL;
  Xl[3] = 0.;
  Xu[3] = 1. - info.DeltaLL;
  for (int i = 0; i < 4; i++) {
    Z[i] = Xl[i] + (Xu[i] - Xl[i]) * Xarg[i];
    Factor *= Xu[i] - Xl[i];
  }
  //--------------------------------------------------------------------------------------------------
  Cth3 = Z[0];
  Phi3 = Z[1];
  X1 = Z[2];
  X2 = Z[3];
  //--------------------------------------------------------------------------------------------------
  Sth3 = sqrt(1. - Cth3 * Cth3);
  Cph3 = cos(Phi3);
  Sph3 = sin(Phi3);
  S = proc.S;
  S1 = S * X1 * X2;
  if (S1 < (Mf3 + Mf4) * (Mf3 + Mf4))
    return 0.0;
  sqS = sqrt(S);
  S_2 = pow2(S);
  Betai = sqrt((S - pow2(Mf1 + Mf2)) * (S - pow2(Mf1 - Mf2))) / S;
  Betaf = sqrt((S - pow2(Mf3 + Mf4)) * (S - pow2(Mf3 - Mf4))) / S;
  Beta = (X1 - X2) / (X1 + X2);
  Pf3 = sqrt((S - pow2(Mf3 + Mf4)) * (S - pow2(Mf3 - Mf4))) / 2. / sqS;
  Enf1 = (S + Mf1_2 - Mf2_2) / 2. / sqS;
  Enf2 = (S + Mf2_2 - Mf1_2) / 2. / sqS;
  Enf3 = (S + Mf3_2 - Mf4_2) / 2. / sqS;
  Enf4 = (S + Mf4_2 - Mf3_2) / 2. / sqS;
  n_sm = sm / S;
  n_dm = dm / S_2;
  T = -0.5 * S * (1. + n_dm - n_sm + Betai * Betaf * Cth3);
  U = -0.5 * S * (1. - n_dm - n_sm - Betai * Betaf * Cth3);
  Jac = 1. / 2. / consts_.pi;
  //--------------------------------------------------------------------------------------------------
  // P_com of hard process
  *P_com[1] = Vec4(0., 0., Betai * sqS / 2., Enf1, Mf1);
  *P_com[2] = Vec4(0., 0., -Betai * sqS / 2., Enf2, Mf2);
  *P_com[3] = Vec4(0., 0., Pf3, Enf3, Mf3).rot(Sth3, Cth3, Sph3, Cph3);
  *P_com[4] = Vec4(0., 0., -Pf3, Enf4, Mf4).rot(Sth3, Cth3, Sph3, Cph3);
  *P_com[5] = Vec4();
  *P_lab[1] = Vec4(0., 0., proc.beta1 * proc.E1, proc.E1, Mf1);
  *P_lab[2] = Vec4(0., 0., -proc.beta2 * proc.E2, proc.E2, Mf2);
  *P_lab[3] = Vec4(0., 0., sqrt(pow2(X1 * Enf3) - Mf3_2), X1 * Enf3, Mf3)
                  .rot(Sth3, Cth3, Sph3, Cph3)
                  .bstZ(beta12);
  *P_lab[4] = Vec4(0., 0., -sqrt(pow2(X2 * Enf4) - Mf4_2), X2 * Enf4, Mf4)
                  .rot(Sth3, Cth3, Sph3, Cph3)
                  .bstZ(beta12);
  *P_lab[5] = Vec4();
  //--------------------------------------------------------------------------------------------------
  if (!proc.passCuts())
    return 0.0;
  //--------------------------------------------------------------------------------------------------
  lla_factor_(&ktype, &info.Iqedllf, &Mf3, &S, &X1, &X2, &FactorLL);
  //--------------------------------------------------------------------------------------------------
  Qs = -S;
  Qt = -T;
  Qu = -U;
  flags_.iborn = 0;
  //--------------------------------------------------------------------------------------------------
  proc.born(&Qs, &Qt, &Qu, &Born, &Soft, &Hard);
  //--------------------------------------------------------------------------------------------------
  LLF12XS = Born * Factor * Jac * FactorLL;
  if (LLF12XS < 0)
    proc.event.weightProc = -1.;
  LLF12XS = abs(LLF12XS);
  if (LLF12XS != LLF12XS)
    LLF12XS = 0.;
  //--------------------------------------------------------------------------------------------------
  return LLF12XS;
}
////////////////////////////////////////////////////////////////////////////////////////////////////
double Integrand::Loop(int nDim, double *Xarg) {
  double LoopXS(0.);
  double Xl[5], Xu[5], Z[6];
  double Factor = 1.;
  double FactorBorn = 1.;
  double Spr, Eta3, Phi3, Eta5, Phi5;
  double Jac;
  double Cth3, Sth3, Cph3, Sph3, Cth5, Sth5, Cph5, Sph5;
  double Beta34, beta12, Betai, Betaf;
  double Pf3, Enf1, Enf2, Enf3, Enf4;
  double S, sqS, Sqspr, Qs, Qt, Qu, Tn, Un;
  double Cth13, Cth14, Theta13, Theta14, Pt3, Pt4;
  double Egamma;
  double Born(0.), Soft(0.), Hard(0.), Sigma(0.);
  proc.event.weightProc = 1.;
  if ((proc.sqS < Mf1 + Mf2) || (proc.sqS < Mf3 + Mf4))
    return 0.0;
  //--------------------------------------------------------------------------------------------------
  S = proc.S;
  sqS = proc.sqS;
  Z[5] = Xarg[5];
  if (Z[5] < 0.5) {
    Xl[1] = -1.0;
    Xu[1] = 1.0;
    Xl[4] = 0.0;
    Xu[4] = 2.0 * consts_.pi;
  } else {
    Xl[0] = log(info.Ome);
    Xu[0] = log(1. - (Mf3 + Mf4) * (Mf3 + Mf4) / S);
    Xl[1] = -100.0;
    Xu[1] = 100.0;
    Xl[2] = 0.0;
    Xu[2] = 2.0 * consts_.pi;
    Xl[3] = -100.0;
    Xu[3] = 100.0;
    Xl[4] = 0.0;
    Xu[4] = 2.0 * consts_.pi;
  }
  for (int i = 0; i < 5; i++) {
    Z[i] = Xl[i] + (Xu[i] - Xl[i]) * Xarg[i];
    Factor *= Xu[i] - Xl[i];
    if (i == 1 || i == 4)
      FactorBorn *= Xu[i] - Xl[i];
  }
  //--------------------------------------------------------------------------------------------------
  Spr = S * (1. - exp(Z[0]));
  Eta3 = Z[1];
  Phi3 = Z[2];
  Eta5 = Z[3];
  Phi5 = Z[4];
  //--------------------------------------------------------------------------------------------------
  if (Z[5] < 0.5) {
    Cth3 = Z[1];
    Sth3 = sqrt(1. - Cth3 * Cth3);
    Spr = S;
    Sth5 = 0.;
    Cth5 = 1.;
    Sph3 = 1.;
    Cph3 = 0.;
    Egamma = 0.;
  } else {
    Cth3 = (exp(2.0 * Eta3) - 1.0) / (exp(2.0 * Eta3) + 1.0);
    Sth3 = 2.0 * exp(Eta3) / (exp(2.0 * Eta3) + 1.0);
    Cph3 = cos(Phi3);
    Sph3 = sin(Phi3);
    Cth5 = (exp(2.0 * Eta5) - 1.0) / (exp(2.0 * Eta5) + 1.0);
    Sth5 = 2.0 * exp(Eta5) / (exp(2.0 * Eta5) + 1.0);
    Egamma = proc.sqS * exp(Z[0]) / 2.0;
  }
  Cph5 = cos(Phi5);
  Sph5 = sin(Phi5);
  beta12 = (proc.beta1 * proc.E1 - proc.beta2 * proc.E2) / (proc.E1 + proc.E2);
  Sqspr = sqrt(Spr);
  Pf3 = sqrt((Spr - pow2(Mf3 + Mf4)) * (Spr - pow2(Mf3 - Mf4))) / 2. / Sqspr;
  Enf1 = (S + Mf1_2 - Mf2_2) / 2. / sqS;
  Enf2 = (S + Mf2_2 - Mf1_2) / 2. / sqS;
  Enf3 = (Spr + Mf3_2 - Mf4_2) / 2. / Sqspr;
  Enf4 = (Spr + Mf4_2 - Mf3_2) / 2. / Sqspr;
  if (Z[5] < 0.5) {
    Jac = 1. / 2. / consts_.pi;
    Beta34 = 0.;
  } else {
    Jac = Sth3 * Sth3 * Sth5 * Sth5 / 2. / consts_.pi * S * exp(Z[0]);
    Beta34 = exp(Z[0]) / (2. - exp(Z[0]));
  }
  //--------------------------------------------------------------------------------------------------
  // NOTE: Because SANC use special reference frame,
  // such as phi3=phi3'+pi/2 and th5 is photon`s angle,
  // we need replace Sph3->-Cph3, Cph3->Sph3 and boost in opposite direction
  *P_lab[1] = Vec4(0., 0., proc.beta1 * proc.E1, proc.E1, Mf1);
  *P_lab[2] = Vec4(0., 0., -proc.beta2 * proc.E2, proc.E2, Mf2);
  *P_lab[3] = Vec4(0., 0., Pf3, Enf3, Mf3)
                  .rot(Sth3, Cth3, -Cph3, Sph3)
                  .bstZ(-Beta34)
                  .rot(Sth5, Cth5, Sph5, Cph5)
                  .bstZ(beta12);
  *P_lab[4] = Vec4(0., 0., -Pf3, Enf4, Mf4)
                  .rot(Sth3, Cth3, -Cph3, Sph3)
                  .bstZ(-Beta34)
                  .rot(Sth5, Cth5, Sph5, Cph5)
                  .bstZ(beta12);
  *P_lab[5] = Vec4(0., 0., Egamma, Egamma, 0.).rot(Sth5, Cth5, Sph5, Cph5).bstZ(beta12);
  *P_com[1] = Vec4(0., 0., Betai * sqS / 2., Enf1, Mf1);
  *P_com[2] = Vec4(0., 0., -Betai * sqS / 2., Enf2, Mf2);
  *P_com[3] = Vec4(0., 0., Pf3, Enf3, Mf3)
                  .rot(Sth3, Cth3, -Cph3, Sph3)
                  .bstZ(-Beta34)
                  .rot(Sth5, Cth5, Sph5, Cph5);
  *P_com[4] = Vec4(0., 0., -Pf3, Enf4, Mf4)
                  .rot(Sth3, Cth3, -Cph3, Sph3)
                  .bstZ(-Beta34)
                  .rot(Sth5, Cth5, Sph5, Cph5);
  *P_com[5] = Vec4(0., 0., Egamma, Egamma, 0.).rot(Sth5, Cth5, Sph5, Cph5);
  //--------------------------------------------------------------------------------------------------
  Tn = t(*P_lab[1], *P_lab[4]);
  Un = t(*P_lab[1], *P_lab[3]);
  //--------------------------------------------------------------------------------------------------
  if (!proc.passCuts())
    return 0.0;
  if (Z[5] >= 0.5) {
    if (Egamma < scales_.omega)
      return 0.0;
  }
  //--------------------------------------------------------------------------------------------------
  Qs = -S;
  Qt = -Tn;
  Qu = -Un;
  flags_.iborn = 0;
  //--------------------------------------------------------------------------------------------------
  if (Z[5] >= 0.5) {
    proc.hard(&S, &Spr, &Phi3, &Eta3, &Eta5, &Hard);
  } else {
    proc.born(&Qs, &Qt, &Qu, &Born, &Soft, &Hard);
    proc.virt(&S, &Tn, &Un, &Sigma);
  }
  //--------------------------------------------------------------------------------------------------
  if (Z[5] >= 0.5) {
    LoopXS = 2. * Hard * Factor * Jac;
  } else {
    LoopXS = 2. * (Sigma + Soft) * FactorBorn * Jac;
  }
  if (LoopXS < 0)
    proc.event.weightProc = -1.;
  LoopXS = abs(LoopXS);
  if (LoopXS != LoopXS) {
    cout << "Error:" << Z[0] << " " << Z[1] << " " << Z[2] << " " << Z[3] << " " << Z[4] << " "
         << Z[5] << endl;
    cout << Sigma << " " << Soft << " " << Hard << " " << endl;
    cout << S << " " << Spr << " " << Phi3 << " " << Eta3 << " " << Eta5 << endl;
  }
  //--------------------------------------------------------------------------------------------------
  return LoopXS;
}
