#include "Info.h"
#include "OF_LHEF.h"
#include "Process_pp.h"

using namespace SANC;

OF_LHEF::OF_LHEF(Info &_info, Process &_proc) : OutputFormat(_info, _proc), lhef(LHEF(info)) {
  lhef.heprup.idbmup[0] = proc.idup[1];
  lhef.heprup.idbmup[1] = proc.idup[2];
  lhef.heprup.ebmup[0] = proc.E1;
  lhef.heprup.ebmup[1] = proc.E2;
  lhef.heprup.pdfgup[0] = 3;
  lhef.heprup.pdfgup[1] = 3;
  lhef.heprup.pdfsup[0] = proc.pdfID;
  lhef.heprup.pdfsup[1] = proc.pdfID;
  lhef.heprup.idwtup = -3;
  lhef.heprup.nprup = 1;
  lhef.heprup.xsecup = info.Sigma;
  lhef.heprup.xerrup = info.SigmaErr;
  lhef.heprup.xmaxup = 1.0;
  lhef.heprup.lprup = 10001;
  //_______________________________________________________

  // lhef.hepeup.nup = 5;
  lhef.hepeup.idprup = 10001;
  lhef.hepeup.aqedup = 1. / info.Alphai;
  lhef.hepeup.aqcdup = info.Alphas;

  lhef.hepeup.istup[0] = -1;
  lhef.hepeup.istup[1] = -1;
  lhef.hepeup.istup[2] = 1;
  lhef.hepeup.istup[3] = 1;
  lhef.hepeup.istup[4] = 1;

  lhef.hepeup.mothup[0][0] = 0;
  lhef.hepeup.mothup[1][0] = 0;
  lhef.hepeup.mothup[2][0] = 1;
  lhef.hepeup.mothup[3][0] = 1;
  lhef.hepeup.mothup[4][0] = 1;

  lhef.hepeup.mothup[0][1] = 0;
  lhef.hepeup.mothup[1][1] = 0;
  lhef.hepeup.mothup[2][1] = 2;
  lhef.hepeup.mothup[3][1] = 2;
  lhef.hepeup.mothup[4][1] = 2;

  lhef.hepeup.vtimup[0] = 1.0;
  lhef.hepeup.vtimup[1] = 1.0;
  lhef.hepeup.vtimup[2] = 1.0;
  lhef.hepeup.vtimup[3] = 1.0;
  lhef.hepeup.vtimup[4] = 1.0;

  lhef.hepeup.spinup[0] = 9.0;
  lhef.hepeup.spinup[1] = 9.0;
  lhef.hepeup.spinup[2] = 9.0;
  lhef.hepeup.spinup[3] = 9.0;
  lhef.hepeup.spinup[4] = 9.0;
}

void OF_LHEF::reinit() {
  lhef.heprup.xsecup = info.Sigma;
  lhef.heprup.xerrup = info.SigmaErr;
}

void OF_LHEF::start(std::string _dirName, std::string _fileName) {
  dirName = _dirName;
  fileName = _fileName;
  output.open(dirName + "/" + fileName + ".lhe");
  lhef.printInit(output);
}

void OF_LHEF::writeEvent() {
  lhef.hepeup.xwgtup = proc.event.weight();
  lhef.hepeup.scalup = proc.scale;
  lhef.hepeup.nup = proc.nup;

  lhef.hepeup.idup[0] = proc.idup[1];
  lhef.hepeup.idup[1] = proc.idup[2];
  lhef.hepeup.idup[2] = proc.idup[3];
  lhef.hepeup.idup[3] = proc.idup[4];
  lhef.hepeup.idup[4] = proc.idup[5];

  lhef.hepeup.icolup[0][0] = proc.icolup[0][0];
  lhef.hepeup.icolup[1][0] = proc.icolup[1][0];
  lhef.hepeup.icolup[2][0] = proc.icolup[2][0];
  lhef.hepeup.icolup[3][0] = proc.icolup[3][0];
  lhef.hepeup.icolup[4][0] = proc.icolup[4][0];

  lhef.hepeup.icolup[0][1] = proc.icolup[0][1];
  lhef.hepeup.icolup[1][1] = proc.icolup[1][1];
  lhef.hepeup.icolup[2][1] = proc.icolup[2][1];
  lhef.hepeup.icolup[3][1] = proc.icolup[3][1];
  lhef.hepeup.icolup[4][1] = proc.icolup[4][1];

  lhef.hepeup.pup[0][0] = proc.event.P_lab(1).px();
  lhef.hepeup.pup[1][0] = proc.event.P_lab(2).px();
  lhef.hepeup.pup[2][0] = proc.event.P_lab(3).px();
  lhef.hepeup.pup[3][0] = proc.event.P_lab(4).px();
  lhef.hepeup.pup[4][0] = proc.event.P_lab(5).px();

  lhef.hepeup.pup[0][1] = proc.event.P_lab(1).py();
  lhef.hepeup.pup[1][1] = proc.event.P_lab(2).py();
  lhef.hepeup.pup[2][1] = proc.event.P_lab(3).py();
  lhef.hepeup.pup[3][1] = proc.event.P_lab(4).py();
  lhef.hepeup.pup[4][1] = proc.event.P_lab(5).py();

  lhef.hepeup.pup[0][2] = proc.event.P_lab(1).pz();
  lhef.hepeup.pup[1][2] = proc.event.P_lab(2).pz();
  lhef.hepeup.pup[2][2] = proc.event.P_lab(3).pz();
  lhef.hepeup.pup[3][2] = proc.event.P_lab(4).pz();
  lhef.hepeup.pup[4][2] = proc.event.P_lab(5).pz();

  lhef.hepeup.pup[0][3] = proc.event.P_lab(1).e();
  lhef.hepeup.pup[1][3] = proc.event.P_lab(2).e();
  lhef.hepeup.pup[2][3] = proc.event.P_lab(3).e();
  lhef.hepeup.pup[3][3] = proc.event.P_lab(4).e();
  lhef.hepeup.pup[4][3] = proc.event.P_lab(5).e();

  lhef.hepeup.pup[0][4] = proc.event.P_lab(1).m();
  lhef.hepeup.pup[1][4] = proc.event.P_lab(2).m();
  lhef.hepeup.pup[2][4] = proc.event.P_lab(3).m();
  lhef.hepeup.pup[3][4] = proc.event.P_lab(4).m();
  lhef.hepeup.pup[4][4] = proc.event.P_lab(5).m();
  lhef.printEvent(output);
}

void OF_LHEF::finish() {
  lhef.printFinish(output);
  // Rewrite header to update cross-section
  output.seekp(0);
  reinit();
  lhef.printInit(output);
  output.close();
}