#include "ReneSANCe_pp.h"
#include "TRandom3.h"
#include <complex>
#include <fstream>
#include <iomanip>
#include <iostream>
#include <sys/stat.h>
using namespace std;
typedef complex<double> double_complex;
#include "DataSaver.h"
#include "Info.h"
#include "Integrand.h"
#include "ModulesInterface.h"
#include "PartonDidtributionsLHAPDF.h"
#include "Process_pp.h"
#include "TFile.h"
#include "TFoam.h"
#include "TTree.h"
#include "Time.h"
#include "clooptools.h"

extern void LHEInit(void);

using namespace SANC;

#define SP12 setprecision(12) << setw(21)
#define SW18 setw(18)
#define SW3 setw(3)
#define SW6 setw(6)

ReneSANCe_pp::ReneSANCe_pp(Settings &_cfg, Info &_info, Process &_proc, PDF *_pdf,
                           ModulesInterface &_mod, Time &_time, DataSaver &_ds)
    : cfg(_cfg), timing(_time), info(_info), proc(_proc), pdf(_pdf), modules(_mod), ds(_ds) {
  PseRan = new TRandom3();
  PseRan->SetSeed(info.RanSeed);
  ffini();
  //    pdf = new PartonDistributionsLHAPDF();
  //    pdf->init(info.PDFname, info.PDFmember);
}

void ReneSANCe_pp::generateGrid() {}

void ReneSANCe_pp::generateEvents() {
  TFoam *FoamBorn, *FoamVirt, *FoamHard, *FoamBrdq, *FoamIbaa, *FoamIbaq, *FoamIbs1, *FoamIbs2;
  TFoamIntegrand *Density0, *Density1, *Density2, *Density3, *Density4, *Density5, *Density6,
      *Density7;
  TFile *fileBorn, *fileVirt, *fileHard, *fileBrdq, *fileIbaa, *fileIbaq, *fileIbs1, *fileIbs2;
  double xDiv[1] = {0.5};
  double xDivBorn[9] = {0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9};
  double xDivHard[19] = {0.05, 0.1, 0.15, 0.2, 0.25, 0.3, 0.35, 0.4, 0.45, 0.5,
                         0.55, 0.6, 0.65, 0.7, 0.75, 0.8, 0.85, 0.9, 0.95};
  double xDivIbaq[39] = {0.025, 0.05, 0.75,  0.1,  0.125, 0.15, 0.175, 0.2,  0.225, 0.25,
                         0.275, 0.3,  0.325, 0.35, 0.375, 0.4,  0.425, 0.45, 0.475, 0.5,
                         0.525, 0.55, 0.575, 0.6,  0.625, 0.65, 0.675, 0.7,  0.725, 0.75,
                         0.775, 0.8,  0.825, 0.85, 0.875, 0.9,  0.925, 0.95, 0.975};
  double xDivIbs1[39] = {0.025, 0.05, 0.75,  0.1,  0.125, 0.15, 0.175, 0.2,  0.225, 0.25,
                         0.275, 0.3,  0.325, 0.35, 0.375, 0.4,  0.425, 0.45, 0.475, 0.5,
                         0.525, 0.55, 0.575, 0.6,  0.625, 0.65, 0.675, 0.7,  0.725, 0.75,
                         0.775, 0.8,  0.825, 0.85, 0.875, 0.9,  0.925, 0.95, 0.975};
  double xDivIbs2[19] = {0.05, 0.1, 0.15, 0.2, 0.25, 0.3, 0.35, 0.4, 0.45, 0.5,
                         0.55, 0.6, 0.65, 0.7, 0.75, 0.8, 0.85, 0.9, 0.95};
  bool TOTCALC = (info.Iborn != 1);
  bool BORNCALC = (info.Iborn != -2);
  bool VIRTCALC = (info.Iborn != 1 && ((info.Iqcd != 0) || (info.Iqed != 0) || (info.Iew != 0)));
  bool HARDCALC = (((info.Iqed != 0) || (info.Iqcd != 0)) && (info.Iborn != 1));
  bool BRDQCALC =
      ((info.Iqed == 1 || info.Iqed == 2 || info.Iqed == 6 || info.Iqcd != 0) && info.Iborn != 1);
  bool IBAACALC = ((info.Pid <= 203) && (info.Iph == 1 || info.Iph == 2) && (info.Iborn != 1));
  bool IBAQCALC = (((info.Iph >= 2) || (info.Iqcd != 0)) && (info.Iborn != 1));
  bool IBS1CALC = (((info.Iph >= 2) || (info.Iqcd != 0)) && (info.Iborn != 1));
  bool IBS2CALC = ((info.Pid <= 203) && (info.Iph >= 2) && (info.Iborn != 1));
  if (info.IEXPLBORN && BORNCALC) {
    FoamBorn = new TFoam("FoamBorn");                 // Create Simulator
    Density0 = new Integrand_pp(info, proc, pdf, 10); // Create integrand function
    FoamBorn->SetkDim(info.kDimBorn);
    FoamBorn->SetnCells(info.nCellsBorn);
    FoamBorn->SetnSampl(info.nSamplBorn);
    FoamBorn->SetnBin(info.nBinBorn);
    FoamBorn->SetEvPerBin(info.EvPerBinBorn);
    FoamBorn->SetOptRej(info.OptRej);
    FoamBorn->SetOptDrive(info.OptDrive);
    FoamBorn->SetMaxWtRej(info.MaxWtRejBorn);
    FoamBorn->SetChat(info.Chat);
    FoamBorn->SetRho(Density0);
    FoamBorn->SetPseRan(PseRan);
    FoamBorn->SetInhiDiv(3, 1);
    FoamBorn->SetInhiDiv(4, 1);
    FoamBorn->SetXdivPRD(4, 9, xDivBorn);
    FoamBorn->Initialize();
    TFile RootBornFile("FoamBorn.root", "RECREATE", "Born");
    FoamBorn->Write("FoamBorn"); // Writing Foam on the disk
  } else if (BORNCALC) {
    fileBorn = new TFile("FoamBorn.root");            // connect disk file
    FoamBorn = (TFoam *)fileBorn->Get("FoamBorn");    // find object
    Density0 = new Integrand_pp(info, proc, pdf, 10); // Create integrand function
    FoamBorn->SetPseRan(PseRan);
    FoamBorn->SetRho(Density0);
    FoamBorn->SetMaxWtRej(info.MaxWtRejBorn);
    FoamBorn->LinkCells(); // restore pointers of the binary tree of cells
    FoamBorn->GetTotDim();
  }
  if (info.IEXPLVIRT && VIRTCALC) {
    FoamVirt = new TFoam("FoamVirt");                 // Create Simulator
    Density1 = new Integrand_pp(info, proc, pdf, 11); // Create integrand function
    FoamVirt->SetkDim(info.kDimVirt);
    FoamVirt->SetnCells(info.nCellsVirt);
    FoamVirt->SetnSampl(info.nSamplVirt);
    FoamVirt->SetnBin(info.nBinVirt);
    FoamVirt->SetEvPerBin(info.EvPerBinVirt);
    FoamVirt->SetOptRej(info.OptRej);
    FoamVirt->SetOptDrive(info.OptDrive);
    FoamVirt->SetMaxWtRej(info.MaxWtRejVirt);
    FoamVirt->SetChat(info.Chat);
    FoamVirt->SetRho(Density1);
    FoamVirt->SetPseRan(PseRan);
    FoamVirt->SetInhiDiv(3, 1);
    FoamVirt->SetInhiDiv(4, 1);
    //        FoamVirt->SetXdivPRD(4, 1, xDiv);
    FoamVirt->SetXdivPRD(4, 9, xDivBorn);
    FoamVirt->Initialize();
    TFile RootVirtFile("FoamVirt.root", "RECREATE", "Virt");
    FoamVirt->Write("FoamVirt"); // Writing Foam on the disk
  } else if (VIRTCALC) {
    fileVirt = new TFile("FoamVirt.root");            // connect disk file
    FoamVirt = (TFoam *)fileVirt->Get("FoamVirt");    // find object
    Density1 = new Integrand_pp(info, proc, pdf, 11); // Create integrand function
    FoamVirt->SetPseRan(PseRan);
    FoamVirt->SetRho(Density1);
    FoamVirt->SetMaxWtRej(info.MaxWtRejVirt);
    FoamVirt->LinkCells(); // restore pointers of the binary tree of cells
    FoamVirt->GetTotDim();
  }
  if (info.IEXPLHARD && HARDCALC) {
    FoamHard = new TFoam("FoamHard");                 // Create Simulator
    Density2 = new Integrand_pp(info, proc, pdf, 12); // Create integrand function
    FoamHard->SetkDim(info.kDimHard);
    FoamHard->SetnCells(info.nCellsHard);
    FoamHard->SetnSampl(info.nSamplHard);
    FoamHard->SetnBin(info.nBinHard);
    FoamHard->SetEvPerBin(info.EvPerBinHard);
    FoamHard->SetOptRej(info.OptRej);
    FoamHard->SetOptDrive(info.OptDrive);
    FoamHard->SetMaxWtRej(info.MaxWtRejHard);
    FoamHard->SetChat(info.Chat);
    FoamHard->SetRho(Density2);
    FoamHard->SetPseRan(PseRan);
    FoamHard->SetInhiDiv(6, 1);
    FoamHard->SetInhiDiv(7, 1);
    //        FoamHard->SetXdivPRD(7, 1, xDiv);
    FoamHard->SetXdivPRD(7, 19, xDivHard);
    FoamHard->Initialize();
    TFile RootHardFile("FoamHard.root", "RECREATE", "Hard");
    FoamHard->Write("FoamHard"); // Writing Foam on the disk
  } else if (HARDCALC) {
    fileHard = new TFile("FoamHard.root");            // connect disk file
    FoamHard = (TFoam *)fileHard->Get("FoamHard");    // find object
    Density2 = new Integrand_pp(info, proc, pdf, 12); // Create integrand function
    FoamHard->SetPseRan(PseRan);
    FoamHard->SetRho(Density2);
    FoamHard->SetMaxWtRej(info.MaxWtRejHard);
    FoamHard->LinkCells(); // restore pointers of the binary tree of cells
    FoamHard->GetTotDim();
  }
  if (info.IEXPLBRDQ && BRDQCALC) {
    FoamBrdq = new TFoam("FoamBrdq");                 // Create Simulator
    Density3 = new Integrand_pp(info, proc, pdf, 13); // Create integrand function
    FoamBrdq->SetkDim(info.kDimBrdq);
    FoamBrdq->SetnCells(info.nCellsBrdq);
    FoamBrdq->SetnSampl(info.nSamplBrdq);
    FoamBrdq->SetnBin(info.nBinBrdq);
    FoamBrdq->SetEvPerBin(info.EvPerBinBrdq);
    FoamBrdq->SetOptRej(info.OptRej);
    FoamBrdq->SetOptDrive(info.OptDrive);
    FoamBrdq->SetMaxWtRej(info.MaxWtRejBrdq);
    FoamBrdq->SetChat(info.Chat);
    FoamBrdq->SetRho(Density3);
    FoamBrdq->SetPseRan(PseRan);
    FoamBrdq->SetInhiDiv(4, 1);
    FoamBrdq->SetInhiDiv(5, 1);
    FoamBrdq->SetXdivPRD(5, 9, xDivBorn);
    FoamBrdq->Initialize();
    TFile RootBrdqFile("FoamBrdq.root", "RECREATE", "Brdq");
    FoamBrdq->Write("FoamBrdq"); // Writing Foam on the disk
  } else if (BRDQCALC) {
    fileBrdq = new TFile("FoamBrdq.root");            // connect disk file
    FoamBrdq = (TFoam *)fileBrdq->Get("FoamBrdq");    // find object
    Density3 = new Integrand_pp(info, proc, pdf, 13); // Create integrand function
    FoamBrdq->SetPseRan(PseRan);
    FoamBrdq->SetRho(Density3);
    FoamBrdq->SetMaxWtRej(info.MaxWtRejBrdq);
    FoamBrdq->LinkCells(); // restore pointers of the binary tree of cells
    FoamBrdq->GetTotDim();
  }
  if (info.IEXPLIBAA && IBAACALC) {
    FoamIbaa = new TFoam("FoamIbaa");                 // Create Simulator
    Density4 = new Integrand_pp(info, proc, pdf, 14); // Create integrand function
    FoamIbaa->SetkDim(info.kDimIbaa);
    FoamIbaa->SetnCells(info.nCellsIbaa);
    FoamIbaa->SetnSampl(info.nSamplIbaa);
    FoamIbaa->SetnBin(info.nBinIbaa);
    FoamIbaa->SetEvPerBin(info.EvPerBinIbaa);
    FoamIbaa->SetOptRej(info.OptRej);
    FoamIbaa->SetOptDrive(info.OptDrive);
    FoamIbaa->SetMaxWtRej(info.MaxWtRejIbaa);
    FoamIbaa->SetChat(info.Chat);
    FoamIbaa->SetRho(Density4);
    FoamIbaa->SetPseRan(PseRan);
    FoamIbaa->SetInhiDiv(3, 1);
    FoamIbaa->SetInhiDiv(4, 1);
    FoamIbaa->SetXdivPRD(4, 1, xDiv);
    FoamIbaa->Initialize();
    TFile RootIbaaFile("FoamIbaa.root", "RECREATE", "Ibaa");
    FoamIbaa->Write("FoamIbaa"); // Writing Foam on the disk
  } else if (IBAACALC) {
    fileIbaa = new TFile("FoamIbaa.root");            // connect disk file
    FoamIbaa = (TFoam *)fileIbaa->Get("FoamIbaa");    // find object
    Density4 = new Integrand_pp(info, proc, pdf, 14); // Create integrand function
    FoamIbaa->SetPseRan(PseRan);
    FoamIbaa->SetRho(Density4);
    FoamIbaa->SetMaxWtRej(info.MaxWtRejIbaa);
    FoamIbaa->LinkCells(); // restore pointers of the binary tree of cells
    FoamIbaa->GetTotDim();
  }
  if (info.IEXPLIBAQ && IBAQCALC) {
    FoamIbaq = new TFoam("FoamIbaq");                 // Create Simulator
    Density5 = new Integrand_pp(info, proc, pdf, 15); // Create integrand function
    FoamIbaq->SetkDim(info.kDimIbaq);
    FoamIbaq->SetnCells(info.nCellsIbaq);
    FoamIbaq->SetnSampl(info.nSamplIbaq);
    FoamIbaq->SetnBin(info.nBinIbaq);
    FoamIbaq->SetEvPerBin(info.EvPerBinIbaq);
    FoamIbaq->SetOptRej(info.OptRej);
    FoamIbaq->SetOptDrive(info.OptDrive);
    FoamIbaq->SetMaxWtRej(info.MaxWtRejIbaq);
    FoamIbaq->SetChat(info.Chat);
    FoamIbaq->SetRho(Density5);
    FoamIbaq->SetPseRan(PseRan);
    FoamIbaq->SetInhiDiv(6, 1);
    FoamIbaq->SetInhiDiv(7, 1);
    FoamIbaq->SetXdivPRD(7, 39, xDivIbaq);
    FoamIbaq->Initialize();
    TFile RootIbaqFile("FoamIbaq.root", "RECREATE", "Ibaq");
    FoamIbaq->Write("FoamIbaq"); // Writing Foam on the disk
  } else if (IBAQCALC) {
    fileIbaq = new TFile("FoamIbaq.root");            // connect disk file
    FoamIbaq = (TFoam *)fileIbaq->Get("FoamIbaq");    // find object
    Density5 = new Integrand_pp(info, proc, pdf, 15); // Create integrand function
    FoamIbaq->SetPseRan(PseRan);
    FoamIbaq->SetRho(Density5);
    FoamIbaq->SetMaxWtRej(info.MaxWtRejIbaq);
    FoamIbaq->LinkCells(); // restore pointers of the binary tree of cells
    FoamIbaq->GetTotDim();
  }
  if (info.IEXPLIBS1 && IBS1CALC) {
    FoamIbs1 = new TFoam("FoamIbs1");                 // Create Simulator
    Density6 = new Integrand_pp(info, proc, pdf, 16); // Create integrand function
    FoamIbs1->SetkDim(info.kDimIbs1);
    FoamIbs1->SetnCells(info.nCellsIbs1);
    FoamIbs1->SetnSampl(info.nSamplIbs1);
    FoamIbs1->SetnBin(info.nBinIbs1);
    FoamIbs1->SetEvPerBin(info.EvPerBinIbs1);
    FoamIbs1->SetOptRej(info.OptRej);
    FoamIbs1->SetOptDrive(info.OptDrive);
    FoamIbs1->SetMaxWtRej(info.MaxWtRejIbs1);
    FoamIbs1->SetChat(info.Chat);
    FoamIbs1->SetRho(Density6);
    FoamIbs1->SetPseRan(PseRan);
    FoamIbs1->SetInhiDiv(4, 1);
    FoamIbs1->SetInhiDiv(5, 1);
    FoamIbaq->SetXdivPRD(5, 39, xDivIbs1);
    FoamIbs1->Initialize();
    TFile RootIbs1File("FoamIbs1.root", "RECREATE", "Ibs1");
    FoamIbs1->Write("FoamIbs1"); // Writing Foam on the disk
  } else if (IBS1CALC) {
    fileIbs1 = new TFile("FoamIbs1.root");            // connect disk file
    FoamIbs1 = (TFoam *)fileIbs1->Get("FoamIbs1");    // find object
    Density6 = new Integrand_pp(info, proc, pdf, 16); // Create integrand function
    FoamIbs1->SetPseRan(PseRan);
    FoamIbs1->SetRho(Density6);
    FoamIbs1->SetMaxWtRej(info.MaxWtRejIbs1);
    FoamIbs1->LinkCells(); // restore pointers of the binary tree of cells
    FoamIbs1->GetTotDim();
  }
  if (info.IEXPLIBS2 && IBS2CALC) {
    FoamIbs2 = new TFoam("FoamIbs2");                 // Create Simulator
    Density7 = new Integrand_pp(info, proc, pdf, 17); // Create integrand function
    FoamIbs2->SetkDim(info.kDimIbs2);
    FoamIbs2->SetnCells(info.nCellsIbs2);
    FoamIbs2->SetnSampl(info.nSamplIbs2);
    FoamIbs2->SetnBin(info.nBinIbs2);
    FoamIbs2->SetEvPerBin(info.EvPerBinIbs2);
    FoamIbs2->SetOptRej(info.OptRej);
    FoamIbs2->SetOptDrive(info.OptDrive);
    FoamIbs2->SetMaxWtRej(info.MaxWtRejIbs2);
    FoamIbs2->SetChat(info.Chat);
    FoamIbs2->SetRho(Density7);
    FoamIbs2->SetPseRan(PseRan);
    FoamIbs2->SetInhiDiv(4, 1);
    FoamIbs2->SetInhiDiv(5, 1);
    FoamIbs2->SetXdivPRD(5, 19, xDivIbs2);
    FoamIbs2->Initialize();
    TFile RootIbs2File("FoamIbs2.root", "RECREATE", "Ibs2");
    FoamIbs2->Write("FoamIbs2"); // Writing Foam on the disk
  } else if (IBS2CALC) {
    fileIbs2 = new TFile("FoamIbs2.root");            // connect disk file
    FoamIbs2 = (TFoam *)fileIbs2->Get("FoamIbs2");    // find object
    Density7 = new Integrand_pp(info, proc, pdf, 17); // Create integrand function
    FoamIbs2->SetPseRan(PseRan);
    FoamIbs2->SetRho(Density7);
    FoamIbs2->SetMaxWtRej(info.MaxWtRejIbs2);
    FoamIbs2->LinkCells(); // restore pointers of the binary tree of cells
    FoamIbs2->GetTotDim();
  }
  cout << "====== Initialization done, entering MC loop" << '\n';
  //--------------------------------------------------------------------------------------------------
  double *MCvectBorn = new double[info.kDimBorn]; // vector generated in the MC run
  double *MCvectVirt = new double[info.kDimVirt]; // vector generated in the MC run
  double *MCvectHard = new double[info.kDimHard]; // vector generated in the MC run
  double *MCvectBrdq = new double[info.kDimBrdq]; // vector generated in the MC run
  double *MCvectIbaa = new double[info.kDimIbaa]; // vector generated in the MC run
  double *MCvectIbaq = new double[info.kDimIbaq]; // vector generated in the MC run
  double *MCvectIbs1 = new double[info.kDimIbs1]; // vector generated in the MC run
  double *MCvectIbs2 = new double[info.kDimIbs2]; // vector generated in the MC run
  //--------------------------------------------------------------------------------------------------
  int iBornPWt1 = 0, iBornNWt1 = 0;
  int iBornPWtN1 = 0, iBornNWtN1 = 0;
  int iVirtPWt1 = 0, iVirtNWt1 = 0;
  int iVirtPWtN1 = 0, iVirtNWtN1 = 0;
  int iHardPWt1 = 0, iHardNWt1 = 0;
  int iHardPWtN1 = 0, iHardNWtN1 = 0;
  int iBrdqPWt1 = 0, iBrdqNWt1 = 0;
  int iBrdqPWtN1 = 0, iBrdqNWtN1 = 0;
  int iIbaaPWt1 = 0, iIbaaNWt1 = 0;
  int iIbaaPWtN1 = 0, iIbaaNWtN1 = 0;
  int iIbaqPWt1 = 0, iIbaqNWt1 = 0;
  int iIbaqPWtN1 = 0, iIbaqNWtN1 = 0;
  int iIbs1PWt1 = 0, iIbs1NWt1 = 0;
  int iIbs1PWtN1 = 0, iIbs1NWtN1 = 0;
  int iIbs2PWt1 = 0, iIbs2NWt1 = 0;
  int iIbs2PWtN1 = 0, iIbs2NWtN1 = 0;
  //--------------------------------------------------------------------------------------------------
  mkdir(info.outputDir.c_str(), S_IRWXU | S_IRWXG | S_IROTH | S_IXOTH);
  //--------------------------------------------------------------------------------------------------
  TFile *fborn = nullptr;
  if (info.PrintROOT) {
    fborn = new TFile((info.outputDir + "/events_LO.root").c_str(), "recreate");
  }
  TTree *tborn = new TTree("events_born", "born events");
  Double_t weight_born[1], px_born[3], py_born[3], pz_born[3], E_born[3];
  tborn->Branch("weight_born", weight_born, "weight_born[1]/D");
  tborn->Branch("px_born", px_born, "px_born[3]/D");
  tborn->Branch("py_born", py_born, "py_born[3]/D");
  tborn->Branch("pz_born", pz_born, "pz_born[3]/D");
  tborn->Branch("E_born", E_born, "E_born[3]/D");
  //--------------------------------------------------------------------------------------------------
  Double_t weight_var[1], var[8];
  TFile *fbornvar = nullptr;
  if (info.PrintDEBUG) {
    fbornvar = new TFile((info.outputDir + "/bornvar.root").c_str(), "recreate");
  }
  TTree *tbornvar = new TTree("events_var", "tot events");
  tbornvar->Branch("weight_var", weight_var, "weight_var[1]/D");
  tbornvar->Branch("var", var, "var[5]/D");
  //--------------------------------------------------------------------------------------------------
  if (BORNCALC) {
    ds.start(info.outputDir, "events_LO");
    for (loop = 0; loop < info.NevBorn; loop++) {
      FoamBorn->MakeEvent(); // generate Born MC event
      FoamBorn->GetMCvect(MCvectBorn);
      MCwt = FoamBorn->GetMCwt();
      if (MCwt == 1.0) {
        proc.nup = 4;
        if (info.PrintLHE)
          ds.writeEvent();
        xwgtup = proc.event.weight();
        weight_born[0] = proc.event.weight();
        px_born[0] = proc.event.P_lab(3).px();
        px_born[1] = proc.event.P_lab(4).px();
        px_born[2] = proc.event.P_lab(5).px();
        py_born[0] = proc.event.P_lab(3).py();
        py_born[1] = proc.event.P_lab(4).py();
        py_born[2] = proc.event.P_lab(5).py();
        pz_born[0] = proc.event.P_lab(3).pz();
        pz_born[1] = proc.event.P_lab(4).pz();
        pz_born[2] = proc.event.P_lab(5).pz();
        E_born[0] = proc.event.P_lab(3).e();
        E_born[1] = proc.event.P_lab(4).e();
        E_born[2] = proc.event.P_lab(5).e();
        if (info.PrintROOT == 1) {
          tborn->Fill();
        }
        weight_var[0] = proc.event.weight();
        for (int i = 0; i < info.kDimBorn; i++) {
          var[i] = MCvectBorn[i];
        }
        if (info.PrintDEBUG == 1) {
          tbornvar->Fill();
        }
        if (xwgtup > 0.0)
          iBornPWt1++;
        if (xwgtup < 0.0)
          iBornNWt1++;
        if ((info.NevBorn >= 100 &&
             ((loop + 1) % (info.NevBorn / 100) == 0 || loop == info.NevBorn - 1)) ||
            info.NevBorn < 100) {
          cout << "Generating Born event: " << setw(12) << loop + 1 << "; progress: " << setw(5)
               << 100 * (loop + 1) / (info.NevBorn) << "\%" << flush << "\r";
        }
      } else if (MCwt > 1.0) {
        xwgtup = proc.event.weight();
        if (xwgtup > 0.0)
          iBornPWtN1++;
        if (xwgtup < 0.0) {
          iBornNWtN1++;
          MCwt = -MCwt;
        }
        loop--;
        //		cout << "Born " << "MCwt   = " << SP12 << MCwt << '\n';
      }
    }
    cout << endl;
    if (info.PrintROOT)
      fborn->Write();
    if (info.PrintDEBUG)
      fbornvar->Write();
    FoamBorn->GetIntegMC(MCresult, MCerror); // get MC integral
    info.Sigma = MCresult;
    info.SigmaErr = MCerror;
    ds.finish();
  }
  //--------------------------------------------------------------------------------------------------
  if (VIRTCALC) {
    for (loop = 0; loop < info.NevVirt; loop++) {
      FoamVirt->MakeEvent(); // generate Virt MC event
      FoamVirt->GetMCvect(MCvectVirt);
      MCwt = FoamVirt->GetMCwt();
      if (MCwt == 1.0) {
        xwgtup = proc.event.weight();
        if ((info.NevVirt >= 100 &&
             ((loop + 1) % (info.NevVirt / 100) == 0 || loop == info.NevVirt - 1)) ||
            info.NevVirt < 100) {
          cout << "Generating Virt event: " << setw(12) << loop + 1 << "; progress: " << setw(5)
               << 100 * (loop + 1) / (info.NevVirt) << "\%" << flush << "\r";
        }
      } else if (MCwt > 1.0) {
        xwgtup = proc.event.weight();
        //		cout << "Virt " << "MCwt   = " << SP12 << MCwt << '\n';
      }
    }
    cout << endl;
  }
  //--------------------------------------------------------------------------------------------------
  if (HARDCALC) {
    for (loop = 0; loop < info.NevHard; loop++) {
      FoamHard->MakeEvent(); // generate Hard MC event
      FoamHard->GetMCvect(MCvectHard);
      MCwt = FoamHard->GetMCwt();
      if (MCwt == 1.0) {
        xwgtup = proc.event.weight();
        if ((info.NevHard >= 100 &&
             ((loop + 1) % (info.NevHard / 100) == 0 || loop == info.NevHard - 1)) ||
            info.NevHard < 100) {
          cout << "Generating Hard event: " << setw(12) << loop + 1 << "; progress: " << setw(5)
               << 100 * (loop + 1) / (info.NevHard) << "\%" << flush << "\r";
        }
      } else if (MCwt > 1.0) {
        xwgtup = proc.event.weight();
        //		cout << "Hard " << "MCwt   = " << SP12 << MCwt << '\n';
      }
    }
    cout << endl;
  }
  //--------------------------------------------------------------------------------------------------
  if (BRDQCALC) {
    for (loop = 0; loop < info.NevBrdq; loop++) {
      FoamBrdq->MakeEvent(); // generate Brdq MC event
      FoamBrdq->GetMCvect(MCvectBrdq);
      MCwt = FoamBrdq->GetMCwt();
      if (MCwt == 1.0) {
        xwgtup = proc.event.weight();
        if ((info.NevBrdq >= 100 &&
             ((loop + 1) % (info.NevBrdq / 100) == 0 || loop == info.NevBrdq - 1)) ||
            info.NevBrdq < 100) {
          cout << "Generating Brdq event: " << setw(12) << loop + 1 << "; progress: " << setw(5)
               << 100 * (loop + 1) / (info.NevBrdq) << "\%" << flush << "\r";
        }
      } else if (MCwt > 1.0) {
        xwgtup = proc.event.weight();
        //		cout << "Brdq " << "MCwt   = " << SP12 << MCwt << '\n';
      }
    }
    cout << endl;
  }
  //--------------------------------------------------------------------------------------------------
  if (IBAACALC) {
    for (loop = 0; loop < info.NevIbaa; loop++) {
      FoamIbaa->MakeEvent(); // generate Ibaa MC event
      FoamIbaa->GetMCvect(MCvectIbaa);
      MCwt = FoamIbaa->GetMCwt();
      if (MCwt == 1.0) {
        xwgtup = proc.event.weight();
        if ((info.NevIbaa >= 100 &&
             ((loop + 1) % (info.NevIbaa / 100) == 0 || loop == info.NevIbaa - 1)) ||
            info.NevIbaa < 100) {
          cout << "Generating Ibaa event: " << setw(12) << loop + 1 << "; progress: " << setw(5)
               << 100 * (loop + 1) / (info.NevIbaa) << "\%" << flush << "\r";
        }
      } else if (MCwt > 1.0) {
        xwgtup = proc.event.weight();
        //		cout << "Ibaa " << "MCwt   = " << SP12 << MCwt << '\n';
      }
    }
    cout << endl;
  }
  //--------------------------------------------------------------------------------------------------
  if (IBAQCALC) {
    for (loop = 0; loop < info.NevIbaq; loop++) {
      FoamIbaq->MakeEvent(); // generate Ibaq MC event
      FoamIbaq->GetMCvect(MCvectIbaq);
      MCwt = FoamIbaq->GetMCwt();
      if (MCwt == 1.0) {
        xwgtup = proc.event.weight();
        if ((info.NevIbaq >= 100 &&
             ((loop + 1) % (info.NevIbaq / 100) == 0 || loop == info.NevIbaq - 1)) ||
            info.NevIbaq < 100) {
          cout << "Generating Ibaq event: " << setw(12) << loop + 1 << "; progress: " << setw(5)
               << 100 * (loop + 1) / (info.NevIbaq) << "\%" << flush << "\r";
        }
      } else if (MCwt > 1.0) {
        xwgtup = proc.event.weight();
        //		cout << "Ibaq " << "MCwt   = " << SP12 << MCwt << '\n';
      }
    }
    cout << endl;
  }
  //--------------------------------------------------------------------------------------------------
  if (IBS1CALC) {
    for (loop = 0; loop < info.NevIbs1; loop++) {
      FoamIbs1->MakeEvent(); // generate Ibs1 MC event
      FoamIbs1->GetMCvect(MCvectIbs1);
      MCwt = FoamIbs1->GetMCwt();
      if (MCwt == 1.0) {
        xwgtup = proc.event.weight();
        if ((info.NevIbs1 >= 100 &&
             ((loop + 1) % (info.NevIbs1 / 100) == 0 || loop == info.NevIbs1 - 1)) ||
            info.NevIbs1 < 100) {
          cout << "Generating Ibs1 event: " << setw(12) << loop + 1 << "; progress: " << setw(5)
               << 100 * (loop + 1) / (info.NevIbs1) << "\%" << flush << "\r";
        }
      } else if (MCwt > 1.0) {
        xwgtup = proc.event.weight();
        //		cout << "Ibs1 " << "MCwt   = " << SP12 << MCwt << '\n';
      }
    }
    cout << endl;
  }
  //--------------------------------------------------------------------------------------------------
  if (IBS2CALC) {
    for (loop = 0; loop < info.NevIbs2; loop++) {
      FoamIbs2->MakeEvent(); // generate Ibs2 MC event
      FoamIbs2->GetMCvect(MCvectIbs2);
      MCwt = FoamIbs2->GetMCwt();
      if (MCwt == 1.0) {
        xwgtup = proc.event.weight();
        if ((info.NevIbs2 >= 100 &&
             ((loop + 1) % (info.NevIbs2 / 100) == 0 || loop == info.NevIbs2 - 1)) ||
            info.NevIbs2 < 100) {
          cout << "Generating Ibs2 event: " << setw(12) << loop + 1 << "; progress: " << setw(5)
               << 100 * (loop + 1) / (info.NevIbs2) << "\%" << flush << "\r";
        }
      } else if (MCwt > 1.0) {
        xwgtup = proc.event.weight();
        //		cout << "Ibs2 " << "MCwt   = " << SP12 << MCwt << '\n';
      }
    }
    cout << endl;
  }
  //--------------------------------------------------------------------------------------------------
  for (int i = 0; i < 8; i++) {
    branch[i] = 0.;
    branch_err[i] = 0.;
  }
  if (BORNCALC) {
    FoamBorn->GetIntegMC(MCresult, MCerror); // get MC integral
    branch[0] = MCresult;
    branch_err[0] = MCerror;
  }
  if (VIRTCALC) {
    FoamVirt->GetIntegMC(MCresult, MCerror); // get MC integral
    branch[1] = MCresult;
    branch_err[1] = MCerror;
  }
  if (HARDCALC) {
    FoamHard->GetIntegMC(MCresult, MCerror); // get MC integral
    branch[2] = MCresult;
    branch_err[2] = MCerror;
  }
  if (BRDQCALC) {
    FoamBrdq->GetIntegMC(MCresult, MCerror); // get MC integral
    branch[3] = MCresult;
    branch_err[3] = MCerror;
  }
  if (IBAACALC) {
    FoamIbaa->GetIntegMC(MCresult, MCerror); // get MC integral
    branch[4] = MCresult;
    branch_err[4] = MCerror;
  }
  if (IBAQCALC) {
    FoamIbaq->GetIntegMC(MCresult, MCerror); // get MC integral
    branch[5] = MCresult;
    branch_err[5] = MCerror;
  }
  if (IBS1CALC) {
    FoamIbs1->GetIntegMC(MCresult, MCerror); // get MC integral
    branch[6] = MCresult;
    branch_err[6] = MCerror;
  }
  if (IBS2CALC) {
    FoamIbs2->GetIntegMC(MCresult, MCerror); // get MC integral
    branch[7] = MCresult;
    branch_err[7] = MCerror;
  }
  //--------------------------------------------------------------------------------------------------
  info.SigmaBorn = branch[0];
  info.SigmaVirt = branch[1];
  info.SigmaHard = branch[2];
  info.SigmaBrdq = branch[3];
  info.SigmaIbaa = branch[4];
  info.SigmaIbaq = branch[5];
  info.SigmaIbs1 = branch[6];
  info.SigmaIbs2 = branch[7];
  info.SigmaTot = 0.;
  if (info.Iborn == -1) {
    info.SigmaTot += branch[0];
  }
  for (int i = 1; i < 8; i++) {
    info.SigmaTot += branch[i];
  }
  //--------------------------------------------------------------------------------------------------
  cout << "-------------------" << '\n';
  cout << "Branching weights:" << '\n';
  cout << "Born = " << branch[0] << " +- " << branch_err[0] << '\n';
  cout << "Virt = " << branch[1] << " +- " << branch_err[1] << '\n';
  cout << "Hard = " << branch[2] << " +- " << branch_err[2] << '\n';
  cout << "Brdq = " << branch[3] << " +- " << branch_err[3] << '\n';
  cout << "Ibaa = " << branch[4] << " +- " << branch_err[4] << '\n';
  cout << "Ibaq = " << branch[5] << " +- " << branch_err[5] << '\n';
  cout << "Ibs1 = " << branch[6] << " +- " << branch_err[6] << '\n';
  cout << "Ibs2 = " << branch[7] << " +- " << branch_err[7] << '\n';
  cout << "-------------------" << endl;
  //--------------------------------------------------------------------------------------------------
  double rBr;
  double Br[6];
  Br[0] = branch[1] / info.SigmaTot;
  for (int i = 1; i < 6; i++) {
    Br[i] = Br[i - 1] + branch[i + 1] / info.SigmaTot;
  }
  //--------------------------------------------------------------------------------------------------
  if (TOTCALC) {
    TFile *ftot = nullptr;
    if (info.PrintROOT) {
      ftot = new TFile((info.outputDir + "/events_NLO.root").c_str(), "recreate");
    }
    TTree *ttot = new TTree("events_tot", "tot events");
    Double_t weight_tot[1], px_tot[3], py_tot[3], pz_tot[3], E_tot[3];
    ttot->Branch("weight_tot", weight_tot, "weight_tot[1]/D");
    ttot->Branch("px_tot", px_tot, "px_tot[3]/D");
    ttot->Branch("py_tot", py_tot, "py_tot[3]/D");
    ttot->Branch("pz_tot", pz_tot, "pz_tot[3]/D");
    ttot->Branch("E_tot", E_tot, "E_tot[3]/D");
    //--------------------------------------------------------------------------------------------------
    TFile *fvirtvar = nullptr;
    if (info.PrintDEBUG) {
      fvirtvar = new TFile((info.outputDir + "/virtvar.root").c_str(), "recreate");
    }
    TTree *tvirtvar = new TTree("events_var", "tot events");
    tvirtvar->Branch("weight_var", weight_var, "weight_var[1]/D");
    tvirtvar->Branch("var", var, "var[5]/D");

    TFile *fhardvar = nullptr;
    if (info.PrintDEBUG) {
      fhardvar = new TFile((info.outputDir + "/hardvar.root").c_str(), "recreate");
    }
    TTree *thardvar = new TTree("events_var", "tot events");
    thardvar->Branch("weight_var", weight_var, "weight_var[1]/D");
    thardvar->Branch("var", var, "var[8]/D");

    TFile *fbrdqvar = nullptr;
    if (info.PrintDEBUG) {
      fbrdqvar = new TFile((info.outputDir + "/brdqvar.root").c_str(), "recreate");
    }
    TTree *tbrdqvar = new TTree("events_var", "tot events");
    tbrdqvar->Branch("weight_var", weight_var, "weight_var[1]/D");
    tbrdqvar->Branch("var", var, "var[6]/D");

    TFile *fibaavar = nullptr;
    if (info.PrintDEBUG) {
      fibaavar = new TFile((info.outputDir + "/ibaavar.root").c_str(), "recreate");
    }
    TTree *tibaavar = new TTree("events_var", "tot events");
    tibaavar->Branch("weight_var", weight_var, "weight_var[1]/D");
    tibaavar->Branch("var", var, "var[5]/D");

    TFile *fibaqvar = nullptr;
    if (info.PrintDEBUG) {
      fibaqvar = new TFile((info.outputDir + "/ibaqvar.root").c_str(), "recreate");
    }
    TTree *tibaqvar = new TTree("events_var", "tot events");
    tibaqvar->Branch("weight_var", weight_var, "weight_var[1]/D");
    tibaqvar->Branch("var", var, "var[8]/D");

    TFile *fibs1var = nullptr;
    if (info.PrintDEBUG) {
      fibs1var = new TFile((info.outputDir + "/ibs1var.root").c_str(), "recreate");
    }
    TTree *tibs1var = new TTree("events_var", "tot events");
    tibs1var->Branch("weight_var", weight_var, "weight_var[1]/D");
    tibs1var->Branch("var", var, "var[6]/D");

    TFile *fibs2var = nullptr;
    if (info.PrintDEBUG) {
      fibs2var = new TFile((info.outputDir + "/ibs2var.root").c_str(), "recreate");
    }
    TTree *tibs2var = new TTree("events_var", "tot events");
    tibs2var->Branch("weight_var", weight_var, "weight_var[1]/D");
    tibs2var->Branch("var", var, "var[6]/D");
    //--------------------------------------------------------------------------------------------------
    ds.start(info.outputDir, "events_NLO");
    //--------------------------------------------------------------------------------------------------
    for (loop = 0; loop < info.NevTot; loop++) {
      rBr = (double)random() / RAND_MAX;
      //--------------------------------------------------------------------------------------------------
      if (rBr <= Br[0] && VIRTCALC) {
        FoamVirt->MakeEvent(); // generate Virt MC event
        FoamVirt->GetMCvect(MCvectVirt);
        MCwt = FoamVirt->GetMCwt();
        if (MCwt == 1.0) {
          proc.nup = 4;
          if (info.PrintLHE)
            ds.writeEvent();
          xwgtup = proc.event.weight();
          //		    std::cout << "xwgtup " << xwgtup << std::endl;
          weight_tot[0] = proc.event.weight();
          px_tot[0] = proc.event.P_lab(3).px();
          px_tot[1] = proc.event.P_lab(4).px();
          px_tot[2] = proc.event.P_lab(5).px();
          py_tot[0] = proc.event.P_lab(3).py();
          py_tot[1] = proc.event.P_lab(4).py();
          py_tot[2] = proc.event.P_lab(5).py();
          pz_tot[0] = proc.event.P_lab(3).pz();
          pz_tot[1] = proc.event.P_lab(4).pz();
          pz_tot[2] = proc.event.P_lab(5).pz();
          E_tot[0] = proc.event.P_lab(3).e();
          E_tot[1] = proc.event.P_lab(4).e();
          E_tot[2] = proc.event.P_lab(5).e();
          if (info.PrintROOT == 1) {
            ttot->Fill();
          }
          weight_var[0] = proc.event.weight();
          for (int i = 0; i < info.kDimVirt; i++) {
            var[i] = MCvectVirt[i];
          }
          if (info.PrintDEBUG == 1) {
            tvirtvar->Fill();
          }
          if (xwgtup > 0.0)
            iVirtPWt1++;
          if (xwgtup < 0.0)
            iVirtNWt1++;
          if ((info.NevTot >= 100 &&
               ((loop + 1) % (info.NevTot / 100) == 0 || loop == info.NevTot - 1)) ||
              info.NevTot < 100) {
            cout << "Generating Tot event: " << setw(12) << loop + 1 << "; progress: " << setw(5)
                 << 100 * (loop + 1) / (info.NevTot) << "\%" << flush << "\r";
          }
        }
        if (MCwt > 1.0) {
          xwgtup = proc.event.weight();
          if (xwgtup > 0.0)
            iVirtPWtN1++;
          if (xwgtup < 0.0) {
            iVirtNWtN1++;
            MCwt = -MCwt;
          }
          loop--;
          cout << "Virt "
               << "MCwt   = " << SP12 << MCwt << '\n';
        }
      }
      //--------------------------------------------------------------------------------------------------
      else if (rBr <= Br[1] && HARDCALC) {
        FoamHard->MakeEvent(); // generate Hard MC event
        FoamHard->GetMCvect(MCvectHard);
        MCwt = FoamHard->GetMCwt();
        if (MCwt == 1.0) {
          proc.nup = 5;
          if (info.PrintLHE)
            ds.writeEvent();
          xwgtup = proc.event.weight();
          weight_tot[0] = proc.event.weight();
          px_tot[0] = proc.event.P_lab(3).px();
          px_tot[1] = proc.event.P_lab(4).px();
          px_tot[2] = proc.event.P_lab(5).px();
          py_tot[0] = proc.event.P_lab(3).py();
          py_tot[1] = proc.event.P_lab(4).py();
          py_tot[2] = proc.event.P_lab(5).py();
          pz_tot[0] = proc.event.P_lab(3).pz();
          pz_tot[1] = proc.event.P_lab(4).pz();
          pz_tot[2] = proc.event.P_lab(5).pz();
          E_tot[0] = proc.event.P_lab(3).e();
          E_tot[1] = proc.event.P_lab(4).e();
          E_tot[2] = proc.event.P_lab(5).e();
          if (info.PrintROOT == 1) {
            ttot->Fill();
          }
          weight_var[0] = proc.event.weight();
          for (int i = 0; i < info.kDimHard; i++) {
            var[i] = MCvectHard[i];
          }
          if (info.PrintDEBUG == 1) {
            thardvar->Fill();
          }
          if (xwgtup > 0.0)
            iHardPWt1++;
          if (xwgtup < 0.0)
            iHardNWt1++;
          if ((info.NevTot >= 100 &&
               ((loop + 1) % (info.NevTot / 100) == 0 || loop == info.NevTot - 1)) ||
              info.NevTot < 100) {
            cout << "Generating Tot event: " << setw(12) << loop + 1 << "; progress: " << setw(5)
                 << 100 * (loop + 1) / (info.NevTot) << "\%" << flush << "\r";
          }
        }
        if (MCwt > 1.0) {
          xwgtup = proc.event.weight();
          if (xwgtup > 0.0)
            iHardPWtN1++;
          if (xwgtup < 0.0) {
            iHardNWtN1++;
            MCwt = -MCwt;
          }
          loop--;
          cout << "Hard "
               << "MCwt   = " << SP12 << MCwt << '\n';
        }
      }
      //--------------------------------------------------------------------------------------------------
      else if (rBr <= Br[2] && BRDQCALC) {
        FoamBrdq->MakeEvent(); // generate Brdq MC event
        FoamBrdq->GetMCvect(MCvectBrdq);
        MCwt = FoamBrdq->GetMCwt();
        if (MCwt == 1.0) {
          proc.nup = 4;
          if (info.PrintLHE)
            ds.writeEvent();
          xwgtup = proc.event.weight();
          weight_tot[0] = proc.event.weight();
          px_tot[0] = proc.event.P_lab(3).px();
          px_tot[1] = proc.event.P_lab(4).px();
          px_tot[2] = proc.event.P_lab(5).px();
          py_tot[0] = proc.event.P_lab(3).py();
          py_tot[1] = proc.event.P_lab(4).py();
          py_tot[2] = proc.event.P_lab(5).py();
          pz_tot[0] = proc.event.P_lab(3).pz();
          pz_tot[1] = proc.event.P_lab(4).pz();
          pz_tot[2] = proc.event.P_lab(5).pz();
          E_tot[0] = proc.event.P_lab(3).e();
          E_tot[1] = proc.event.P_lab(4).e();
          E_tot[2] = proc.event.P_lab(5).e();
          if (info.PrintROOT == 1) {
            ttot->Fill();
          }
          weight_var[0] = proc.event.weight();
          for (int i = 0; i < info.kDimBrdq; i++) {
            var[i] = MCvectBrdq[i];
          }
          if (info.PrintDEBUG == 1) {
            tbrdqvar->Fill();
          }
          if (xwgtup > 0.0)
            iBrdqPWt1++;
          if (xwgtup < 0.0)
            iBrdqNWt1++;
          if ((info.NevTot >= 100 &&
               ((loop + 1) % (info.NevTot / 100) == 0 || loop == info.NevTot - 1)) ||
              info.NevTot < 100) {
            cout << "Generating Tot event: " << setw(12) << loop + 1 << "; progress: " << setw(5)
                 << 100 * (loop + 1) / (info.NevTot) << "\%" << flush << "\r";
          }
        }
        if (MCwt > 1.0) {
          xwgtup = proc.event.weight();
          if (xwgtup > 0.0)
            iBrdqPWtN1++;
          if (xwgtup < 0.0) {
            iBrdqNWtN1++;
            MCwt = -MCwt;
          }
          loop--;
          cout << "Brdq "
               << "MCwt   = " << SP12 << MCwt << '\n';
        }
      }
      //--------------------------------------------------------------------------------------------------
      else if (rBr <= Br[3] && IBAACALC) {
        FoamIbaa->MakeEvent(); // generate Ibaa MC event
        FoamIbaa->GetMCvect(MCvectIbaa);
        MCwt = FoamIbaa->GetMCwt();
        if (MCwt == 1.0) {
          proc.nup = 4;
          if (info.PrintLHE)
            ds.writeEvent();
          xwgtup = proc.event.weight();
          weight_tot[0] = proc.event.weight();
          px_tot[0] = proc.event.P_lab(3).px();
          px_tot[1] = proc.event.P_lab(4).px();
          px_tot[2] = proc.event.P_lab(5).px();
          py_tot[0] = proc.event.P_lab(3).py();
          py_tot[1] = proc.event.P_lab(4).py();
          py_tot[2] = proc.event.P_lab(5).py();
          pz_tot[0] = proc.event.P_lab(3).pz();
          pz_tot[1] = proc.event.P_lab(4).pz();
          pz_tot[2] = proc.event.P_lab(5).pz();
          E_tot[0] = proc.event.P_lab(3).e();
          E_tot[1] = proc.event.P_lab(4).e();
          E_tot[2] = proc.event.P_lab(5).e();
          if (info.PrintROOT == 1) {
            ttot->Fill();
          }
          weight_var[0] = proc.event.weight();
          for (int i = 0; i < info.kDimIbaa; i++) {
            var[i] = MCvectIbaa[i];
          }
          if (info.PrintDEBUG == 1) {
            tibaavar->Fill();
          }
          if (xwgtup > 0.0)
            iIbaaPWt1++;
          if (xwgtup < 0.0)
            iIbaaNWt1++;
          if ((info.NevTot >= 100 &&
               ((loop + 1) % (info.NevTot / 100) == 0 || loop == info.NevTot - 1)) ||
              info.NevTot < 100) {
            cout << "Generating Tot event: " << setw(12) << loop + 1 << "; progress: " << setw(5)
                 << 100 * (loop + 1) / (info.NevTot) << "\%" << flush << "\r";
          }
        }
        if (MCwt > 1.0) {
          xwgtup = proc.event.weight();
          if (xwgtup > 0.0)
            iIbaaPWtN1++;
          if (xwgtup < 0.0) {
            iIbaaNWtN1++;
            MCwt = -MCwt;
          }
          loop--;
          cout << "Ibaa "
               << "MCwt   = " << SP12 << MCwt << '\n';
        }
      }
      //--------------------------------------------------------------------------------------------------
      else if (rBr <= Br[4] && IBAQCALC) {
        FoamIbaq->MakeEvent(); // generate Ibaq MC event
        FoamIbaq->GetMCvect(MCvectIbaq);
        MCwt = FoamIbaq->GetMCwt();
        if (MCwt == 1.0) {
          proc.nup = 5;
          if (info.PrintLHE)
            ds.writeEvent();
          xwgtup = proc.event.weight();
          weight_tot[0] = proc.event.weight();
          px_tot[0] = proc.event.P_lab(3).px();
          px_tot[1] = proc.event.P_lab(4).px();
          px_tot[2] = proc.event.P_lab(5).px();
          py_tot[0] = proc.event.P_lab(3).py();
          py_tot[1] = proc.event.P_lab(4).py();
          py_tot[2] = proc.event.P_lab(5).py();
          pz_tot[0] = proc.event.P_lab(3).pz();
          pz_tot[1] = proc.event.P_lab(4).pz();
          pz_tot[2] = proc.event.P_lab(5).pz();
          E_tot[0] = proc.event.P_lab(3).e();
          E_tot[1] = proc.event.P_lab(4).e();
          E_tot[2] = proc.event.P_lab(5).e();
          if (info.PrintROOT == 1) {
            ttot->Fill();
          }
          weight_var[0] = proc.event.weight();
          for (int i = 0; i < info.kDimIbaq; i++) {
            var[i] = MCvectIbaq[i];
          }
          if (info.PrintDEBUG == 1) {
            tibaqvar->Fill();
          }
          if (xwgtup > 0.0)
            iIbaqPWt1++;
          if (xwgtup < 0.0)
            iIbaqNWt1++;
          if ((info.NevTot >= 100 &&
               ((loop + 1) % (info.NevTot / 100) == 0 || loop == info.NevTot - 1)) ||
              info.NevTot < 100) {
            cout << "Generating Tot event: " << setw(12) << loop + 1 << "; progress: " << setw(5)
                 << 100 * (loop + 1) / (info.NevTot) << "\%" << flush << "\r";
          }
        }
        if (MCwt > 1.0) {
          xwgtup = proc.event.weight();
          if (xwgtup > 0.0)
            iIbaqPWtN1++;
          if (xwgtup < 0.0) {
            iIbaqNWtN1++;
            MCwt = -MCwt;
          }
          loop--;
          cout << "Ibaq "
               << "MCwt   = " << SP12 << MCwt << '\n';
        }
      }
      //--------------------------------------------------------------------------------------------------
      else if (rBr <= Br[5] && IBS1CALC) {
        FoamIbs1->MakeEvent(); // generate Ibs1 MC event
        FoamIbs1->GetMCvect(MCvectIbs1);
        MCwt = FoamIbs1->GetMCwt();
        if (MCwt == 1.0) {
          proc.nup = 5;
          if (info.PrintLHE)
            ds.writeEvent();
          xwgtup = proc.event.weight();
          weight_tot[0] = proc.event.weight();
          px_tot[0] = proc.event.P_lab(3).px();
          px_tot[1] = proc.event.P_lab(4).px();
          px_tot[2] = proc.event.P_lab(5).px();
          py_tot[0] = proc.event.P_lab(3).py();
          py_tot[1] = proc.event.P_lab(4).py();
          py_tot[2] = proc.event.P_lab(5).py();
          pz_tot[0] = proc.event.P_lab(3).pz();
          pz_tot[1] = proc.event.P_lab(4).pz();
          pz_tot[2] = proc.event.P_lab(5).pz();
          E_tot[0] = proc.event.P_lab(3).e();
          E_tot[1] = proc.event.P_lab(4).e();
          E_tot[2] = proc.event.P_lab(5).e();
          if (info.PrintROOT == 1) {
            ttot->Fill();
          }
          weight_var[0] = proc.event.weight();
          for (int i = 0; i < info.kDimIbs1; i++) {
            var[i] = MCvectIbs1[i];
          }
          if (info.PrintDEBUG == 1) {
            tibs1var->Fill();
          }
          if (xwgtup > 0.0)
            iIbs1PWt1++;
          if (xwgtup < 0.0)
            iIbs1NWt1++;
          if ((info.NevTot >= 100 &&
               ((loop + 1) % (info.NevTot / 100) == 0 || loop == info.NevTot - 1)) ||
              info.NevTot < 100) {
            cout << "Generating Tot event: " << setw(12) << loop + 1 << "; progress: " << setw(5)
                 << 100 * (loop + 1) / (info.NevTot) << "\%" << flush << "\r";
          }
        }
        if (MCwt > 1.0) {
          xwgtup = proc.event.weight();
          if (xwgtup > 0.0)
            iIbs1PWtN1++;
          if (xwgtup < 0.0) {
            iIbs1NWtN1++;
            MCwt = -MCwt;
          }
          loop--;
          cout << "Ibs1 "
               << "MCwt   = " << SP12 << MCwt << '\n';
        }
      }
      //--------------------------------------------------------------------------------------------------
      else if (IBS2CALC) {
        FoamIbs2->MakeEvent(); // generate Ibs2 MC event
        FoamIbs2->GetMCvect(MCvectIbs2);
        MCwt = FoamIbs2->GetMCwt();
        if (MCwt == 1.0) {
          proc.nup = 5;
          if (info.PrintLHE)
            ds.writeEvent();
          xwgtup = proc.event.weight();
          weight_tot[0] = proc.event.weight();
          px_tot[0] = proc.event.P_lab(3).px();
          px_tot[1] = proc.event.P_lab(4).px();
          px_tot[2] = proc.event.P_lab(5).px();
          py_tot[0] = proc.event.P_lab(3).py();
          py_tot[1] = proc.event.P_lab(4).py();
          py_tot[2] = proc.event.P_lab(5).py();
          pz_tot[0] = proc.event.P_lab(3).pz();
          pz_tot[1] = proc.event.P_lab(4).pz();
          pz_tot[2] = proc.event.P_lab(5).pz();
          E_tot[0] = proc.event.P_lab(3).e();
          E_tot[1] = proc.event.P_lab(4).e();
          E_tot[2] = proc.event.P_lab(5).e();
          if (info.PrintROOT == 1) {
            ttot->Fill();
          }
          weight_var[0] = proc.event.weight();
          for (int i = 0; i < info.kDimIbs2; i++) {
            var[i] = MCvectIbs2[i];
          }
          if (info.PrintDEBUG == 1) {
            tibs2var->Fill();
          }
          if (xwgtup > 0.0)
            iIbs2PWt1++;
          if (xwgtup < 0.0)
            iIbs2NWt1++;
          if ((info.NevTot >= 100 &&
               ((loop + 1) % (info.NevTot / 100) == 0 || loop == info.NevTot - 1)) ||
              info.NevTot < 100) {
            cout << "Generating Tot event: " << setw(12) << loop + 1 << "; progress: " << setw(5)
                 << 100 * (loop + 1) / (info.NevTot) << "\%" << flush << "\r";
          }
        }
        if (MCwt > 1.0) {
          xwgtup = proc.event.weight();
          if (xwgtup > 0.0)
            iIbs2PWtN1++;
          if (xwgtup < 0.0) {
            iIbs2NWtN1++;
            MCwt = -MCwt;
          }
          loop--;
          cout << "Ibs2 "
               << "MCwt   = " << SP12 << MCwt << '\n';
        }
      }
      //--------------------------------------------------------------------------------------------------
    }
    cout << endl;
    if (info.PrintROOT)
      ftot->Write();
    if (info.PrintDEBUG) {
      fvirtvar->Write();
      fhardvar->Write();
      fbrdqvar->Write();
      fibaavar->Write();
      fibaqvar->Write();
      fibs1var->Write();
      fibs2var->Write();
    }
    //--------------------------------------------------------------------------------------------------
  }
  //--------------------------------------------------------------------------------------------------
  double BornF = 1.0;
  double VirtF = 1.0;
  double HardF = 1.0;
  double BrdqF = 1.0;
  double IbaaF = 1.0;
  double IbaqF = 1.0;
  double Ibs1F = 1.0;
  double Ibs2F = 1.0;
  if ((iBornPWt1 + iBornNWt1) > 0)
    BornF = (double)(iBornPWt1 - iBornNWt1) / (iBornPWt1 + iBornNWt1);
  if ((iVirtPWt1 + iVirtNWt1) > 0)
    VirtF = (double)(iVirtPWt1 - iVirtNWt1) / (iVirtPWt1 + iVirtNWt1);
  if ((iHardPWt1 + iHardNWt1) > 0)
    HardF = (double)(iHardPWt1 - iHardNWt1) / (iHardPWt1 + iHardNWt1);
  if ((iBrdqPWt1 + iBrdqNWt1) > 0)
    BrdqF = (double)(iBrdqPWt1 - iBrdqNWt1) / (iBrdqPWt1 + iBrdqNWt1);
  if ((iIbaaPWt1 + iIbaaNWt1) > 0)
    IbaaF = (double)(iIbaaPWt1 - iIbaaNWt1) / (iIbaaPWt1 + iIbaaNWt1);
  if ((iIbaqPWt1 + iIbaqNWt1) > 0)
    IbaqF = (double)(iIbaqPWt1 - iIbaqNWt1) / (iIbaqPWt1 + iIbaqNWt1);
  if ((iIbs1PWt1 + iIbs1NWt1) > 0)
    Ibs1F = (double)(iIbs1PWt1 - iIbs1NWt1) / (iIbs1PWt1 + iIbs1NWt1);
  if ((iIbs2PWt1 + iIbs2NWt1) > 0)
    Ibs2F = (double)(iIbs2PWt1 - iIbs2NWt1) / (iIbs2PWt1 + iIbs2NWt1);
  //--------------------------------------------------------------------------------------------------
  cout << "====== Events generated, entering Finalize" << '\n';
  Double_t IntNorm, Errel;
  if (BORNCALC)
    FoamBorn->Finalize(IntNorm, Errel);
  if (VIRTCALC)
    FoamVirt->Finalize(IntNorm, Errel);
  if (HARDCALC)
    FoamHard->Finalize(IntNorm, Errel);
  if (BRDQCALC)
    FoamBrdq->Finalize(IntNorm, Errel);
  if (IBAACALC)
    FoamIbaa->Finalize(IntNorm, Errel);
  if (IBAQCALC)
    FoamIbaq->Finalize(IntNorm, Errel);
  if (IBS1CALC)
    FoamIbs1->Finalize(IntNorm, Errel);
  if (IBS2CALC)
    FoamIbs2->Finalize(IntNorm, Errel);
  //--------------------------------------------------------------------------------------------------
  double ErrBorn = 0.;
  double SigmaBornAbs = 0.;
  if (BORNCALC) {
    FoamBorn->GetIntegMC(MCresult, MCerror); // get MC integral
    info.SigmaBorn = BornF * MCresult;
    ErrBorn = MCerror;
    SigmaBornAbs = MCresult;
    cout << "================================================================" << '\n';
    cout << "        MCresult (Born) = " << info.SigmaBorn << " +- " << ErrBorn
         << " RelErr = " << ErrBorn / info.SigmaBorn << '\n';
    delete[] MCvectBorn;
  }
  //--------------------------------------------------------------------------------------------------
  double ErrVirt = 0.;
  double SigmaVirtAbs = 0.;
  if (VIRTCALC) {
    FoamVirt->GetIntegMC(MCresult, MCerror); // get MC integral
    info.SigmaVirt = VirtF * MCresult;
    ErrVirt = MCerror;
    SigmaVirtAbs = MCresult;
    cout << "        MCresult (Virt) = " << info.SigmaVirt << " +- " << ErrVirt
         << " RelErr = " << ErrVirt / info.SigmaVirt << '\n';
    delete[] MCvectVirt;
  }
  //--------------------------------------------------------------------------------------------------
  double ErrHard = 0.;
  double SigmaHardAbs = 0.;
  if (HARDCALC) {
    FoamHard->GetIntegMC(MCresult, MCerror); // get MC integral
    info.SigmaHard = HardF * MCresult;
    ErrHard = MCerror;
    SigmaHardAbs = MCresult;
    cout << "        MCresult (Hard) = " << info.SigmaHard << " +- " << ErrHard
         << " RelErr = " << ErrHard / info.SigmaHard << '\n';
    delete[] MCvectHard;
  }
  //--------------------------------------------------------------------------------------------------
  double ErrBrdq = 0.;
  double SigmaBrdqAbs = 0.;
  if (BRDQCALC) {
    FoamBrdq->GetIntegMC(MCresult, MCerror); // get MC integral
    info.SigmaBrdq = BrdqF * MCresult;
    ErrBrdq = MCerror;
    SigmaBrdqAbs = MCresult;
    cout << "        MCresult (Brdq) = " << info.SigmaBrdq << " +- " << ErrBrdq
         << " RelErr = " << ErrBrdq / info.SigmaBrdq << '\n';
    delete[] MCvectBrdq;
  }
  //--------------------------------------------------------------------------------------------------
  double ErrIbaa = 0.;
  double SigmaIbaaAbs = 0.;
  if (IBAACALC) {
    FoamIbaa->GetIntegMC(MCresult, MCerror); // get MC integral
    info.SigmaIbaa = IbaaF * MCresult;
    ErrIbaa = MCerror;
    SigmaIbaaAbs = MCresult;
    cout << "        MCresult (Ibaa) = " << info.SigmaIbaa << " +- " << ErrIbaa
         << " RelErr = " << ErrIbaa / info.SigmaIbaa << '\n';
    delete[] MCvectIbaa;
  }
  //--------------------------------------------------------------------------------------------------
  double ErrIbaq = 0.;
  double SigmaIbaqAbs = 0.;
  if (IBAQCALC) {
    FoamIbaq->GetIntegMC(MCresult, MCerror); // get MC integral
    info.SigmaIbaq = IbaqF * MCresult;
    ErrIbaq = MCerror;
    SigmaIbaqAbs = MCresult;
    cout << "        MCresult (Ibaq) = " << info.SigmaIbaq << " +- " << ErrIbaq
         << " RelErr = " << ErrIbaq / info.SigmaIbaq << '\n';
    delete[] MCvectIbaq;
  }
  //--------------------------------------------------------------------------------------------------
  double ErrIbs1 = 0.;
  double SigmaIbs1Abs = 0.;
  if (IBS1CALC) {
    FoamIbs1->GetIntegMC(MCresult, MCerror); // get MC integral
    info.SigmaIbs1 = Ibs1F * MCresult;
    ErrIbs1 = MCerror;
    SigmaIbs1Abs = MCresult;
    cout << "        MCresult (Ibs1) = " << info.SigmaIbs1 << " +- " << ErrIbs1
         << " RelErr = " << ErrIbs1 / info.SigmaIbs1 << '\n';
    delete[] MCvectIbs1;
  }
  //--------------------------------------------------------------------------------------------------
  double ErrIbs2 = 0.;
  double SigmaIbs2Abs = 0.;
  if (IBS2CALC) {
    FoamIbs2->GetIntegMC(MCresult, MCerror); // get MC integral
    info.SigmaIbs2 = Ibs2F * MCresult;
    ErrIbs2 = MCerror;
    SigmaIbs2Abs = MCresult;
    cout << "        MCresult (Ibs2) = " << info.SigmaIbs2 << " +- " << ErrIbs2
         << " RelErr = " << ErrIbs2 / info.SigmaIbs2 << '\n';
    delete[] MCvectIbs2;
  }
  //--------------------------------------------------------------------------------------------------
  info.SigmaTot = info.SigmaVirt + info.SigmaHard + info.SigmaBrdq + info.SigmaIbaa +
                  info.SigmaIbaq + info.SigmaIbs1 + info.SigmaIbs2;
  double SigmaTotAbs = SigmaVirtAbs + SigmaHardAbs + SigmaBrdqAbs + SigmaIbaaAbs + SigmaIbaqAbs +
                       SigmaIbs1Abs + SigmaIbs2Abs;
  if (info.Iborn == -1) {
    info.SigmaTot += info.SigmaBorn;
    SigmaTotAbs += SigmaBornAbs;
  }
  double SigmaDel = info.SigmaTot - info.SigmaBorn;
  double errBorn_ = (info.Iborn == -1)?ErrBorn*ErrBorn:0.;
  double ErrTot =
      sqrt(errBorn_ + ErrVirt * ErrVirt + ErrHard * ErrHard + ErrBrdq * ErrBrdq + ErrIbaa * ErrIbaa +
           ErrIbaq * ErrIbaq + ErrIbs1 * ErrIbs1 + ErrIbs2 * ErrIbs2);
  double ErrDel =
      sqrt(ErrVirt * ErrVirt + ErrHard * ErrHard + ErrBrdq * ErrBrdq + ErrIbaa * ErrIbaa +
           ErrIbaq * ErrIbaq + ErrIbs1 * ErrIbs1 + ErrIbs2 * ErrIbs2 + ErrBorn * ErrBorn);
  double Delta = SigmaDel / info.SigmaBorn;
  double ErrDelta = fabs(Delta) * sqrt(ErrDel / SigmaDel * ErrDel / SigmaDel +
                                       ErrBorn / info.SigmaBorn * ErrBorn / info.SigmaBorn);
  cout << "        MCresult (Tot)  = " << info.SigmaTot << " +- " << ErrTot
       << " RelErr = " << ErrTot / info.SigmaTot << '\n';
  cout << "        MCresult (Delta)  = " << Delta << " +- " << ErrDelta
       << " RelErr = " << ErrDelta / Delta << '\n';
  cout << "================================================================" << '\n';
  if (info.PrintROOT) {
    ofstream sigma_brn;
    sigma_brn.open(info.outputDir + "/events_LO.dat");
    sigma_brn << setprecision(10) << SigmaBornAbs << '\n';
    sigma_brn.close();
    if (TOTCALC) {
      ofstream sigma_tot;
      sigma_tot.open(info.outputDir + "/events_NLO.dat");
      sigma_tot << setprecision(10) << SigmaTotAbs << '\n';
      sigma_tot.close();
    }
  }
  info.Sigma = info.SigmaTot;
  info.SigmaErr = ErrTot;
  if (info.PrintLHE) {
    if (TOTCALC) {
      ds.finish();
    }
  }
  //--------------------------------------------------------------------------------------------------
  cout << "Total number of Born events: " << iBornPWt1 + iBornPWtN1 << " pos. "
       << iBornNWt1 + iBornNWtN1 << " neg." << '\n';
  cout << "Total number of Virt events: " << iVirtPWt1 + iVirtPWtN1 << " pos. "
       << iVirtNWt1 + iVirtNWtN1 << " neg." << '\n';
  cout << "Total number of Hard events: " << iHardPWt1 + iHardPWtN1 << " pos. "
       << iHardNWt1 + iHardNWtN1 << " neg." << '\n';
  cout << "Total number of Brdq events: " << iBrdqPWt1 + iBrdqPWtN1 << " pos. "
       << iBrdqNWt1 + iBrdqNWtN1 << " neg." << '\n';
  cout << "Total number of Ibaa events: " << iIbaaPWt1 + iIbaaPWtN1 << " pos. "
       << iIbaaNWt1 + iIbaaNWtN1 << " neg." << '\n';
  cout << "Total number of Ibaq events: " << iIbaqPWt1 + iIbaqPWtN1 << " pos. "
       << iIbaqNWt1 + iIbaqNWtN1 << " neg." << '\n';
  cout << "Total number of Ibs1 events: " << iIbs1PWt1 + iIbs1PWtN1 << " pos. "
       << iIbs1NWt1 + iIbs1NWtN1 << " neg." << '\n';
  cout << "Total number of Ibs2 events: " << iIbs2PWt1 + iIbs2PWtN1 << " pos. "
       << iIbs2NWt1 + iIbs2NWtN1 << " neg." << '\n';
  cout << "================================================================" << '\n';
  cout << "Number of Born events with Wt > 1: " << iBornPWtN1 << " pos. " << iBornNWtN1 << " neg."
       << '\n';
  cout << "Number of Virt events with Wt > 1: " << iVirtPWtN1 << " pos. " << iVirtNWtN1 << " neg."
       << '\n';
  cout << "Number of Hard events with Wt > 1: " << iHardPWtN1 << " pos. " << iHardNWtN1 << " neg."
       << '\n';
  cout << "Number of Brdq events with Wt > 1: " << iBrdqPWtN1 << " pos. " << iBrdqNWtN1 << " neg."
       << '\n';
  cout << "Number of Ibaa events with Wt > 1: " << iIbaaPWtN1 << " pos. " << iIbaaNWtN1 << " neg."
       << '\n';
  cout << "Number of Ibaq events with Wt > 1: " << iIbaqPWtN1 << " pos. " << iIbaqNWtN1 << " neg."
       << '\n';
  cout << "Number of Ibs1 events with Wt > 1: " << iIbs1PWtN1 << " pos. " << iIbs1NWtN1 << " neg."
       << '\n';
  cout << "Number of Ibs2 events with Wt > 1: " << iIbs2PWtN1 << " pos. " << iIbs2NWtN1 << " neg."
       << '\n';
  cout << "================================================================" << '\n';
  cout << "Relative number of Born events with Wt > 1: "
       << (double)(iBornPWtN1 + iBornNWtN1) / (iBornPWt1 + iBornNWt1 + iBornPWtN1 + iBornNWtN1)
       << '\n';
  cout << "Relative number of Virt events with Wt > 1: "
       << (double)(iVirtPWtN1 + iVirtNWtN1) / (iVirtPWt1 + iVirtNWt1 + iVirtPWtN1 + iVirtNWtN1)
       << '\n';
  cout << "Relative number of Hard events with Wt > 1: "
       << (double)(iHardPWtN1 + iHardNWtN1) / (iHardPWt1 + iHardNWt1 + iHardPWtN1 + iHardNWtN1)
       << '\n';
  cout << "Relative number of Brdq events with Wt > 1: "
       << (double)(iBrdqPWtN1 + iBrdqNWtN1) / (iBrdqPWt1 + iBrdqNWt1 + iBrdqPWtN1 + iBrdqNWtN1)
       << '\n';
  cout << "Relative number of Ibaa events with Wt > 1: "
       << (double)(iIbaaPWtN1 + iIbaaNWtN1) / (iIbaaPWt1 + iIbaaNWt1 + iIbaaPWtN1 + iIbaaNWtN1)
       << '\n';
  cout << "Relative number of Ibaq events with Wt > 1: "
       << (double)(iIbaqPWtN1 + iIbaqNWtN1) / (iIbaqPWt1 + iIbaqNWt1 + iIbaqPWtN1 + iIbaqNWtN1)
       << '\n';
  cout << "Relative number of Ibs1 events with Wt > 1: "
       << (double)(iIbs1PWtN1 + iIbs1NWtN1) / (iIbs1PWt1 + iIbs1NWt1 + iIbs1PWtN1 + iIbs1NWtN1)
       << '\n';
  cout << "Relative number of Ibs2 events with Wt > 1: "
       << (double)(iIbs2PWtN1 + iIbs2NWtN1) / (iIbs2PWt1 + iIbs2NWt1 + iIbs2PWtN1 + iIbs2NWtN1)
       << '\n';
  cout << "***** End of Program *****" << '\n';
}
